from typing import List, Optional, Dict, Iterable, Any, overload
import io
import collections.abc
from collections.abc import Sequence
from datetime import datetime
from aspose.pyreflection import Type
import aspose.pycore
import aspose.pydrawing
from uuid import UUID
import aspose.gis
import aspose.gis.common
import aspose.gis.common.formats
import aspose.gis.common.formats.dbase
import aspose.gis.common.formats.gdbtable
import aspose.gis.common.formats.mapinfo
import aspose.gis.common.formats.mapinfo.graphicalobjects
import aspose.gis.common.formats.mapinfo.interchangeformat
import aspose.gis.common.formats.mapinfo.styling
import aspose.gis.common.formats.mapinfo.tabformat
import aspose.gis.common.formats.mapinfo.tabformat.map
import aspose.gis.common.formats.wkb
import aspose.gis.common.formats.wkt
import aspose.gis.common.formats.xml
import aspose.gis.common.io
import aspose.gis.epsg
import aspose.gis.formats
import aspose.gis.formats.bmpw
import aspose.gis.formats.csv
import aspose.gis.formats.database
import aspose.gis.formats.database.dataediting
import aspose.gis.formats.database.fromdefinition
import aspose.gis.formats.esriascii
import aspose.gis.formats.esrijson
import aspose.gis.formats.filegdb
import aspose.gis.formats.gdal
import aspose.gis.formats.geojson
import aspose.gis.formats.geojsonseq
import aspose.gis.formats.geotiff
import aspose.gis.formats.gml
import aspose.gis.formats.gpx
import aspose.gis.formats.infile
import aspose.gis.formats.inmemory
import aspose.gis.formats.jpegw
import aspose.gis.formats.kml
import aspose.gis.formats.kml.styles
import aspose.gis.formats.mapinfointerchange
import aspose.gis.formats.mapinfotab
import aspose.gis.formats.osmxml
import aspose.gis.formats.pngw
import aspose.gis.formats.postgis
import aspose.gis.formats.shapefile
import aspose.gis.formats.sqlserver
import aspose.gis.formats.tiffw
import aspose.gis.formats.topojson
import aspose.gis.formats.worldfile
import aspose.gis.formats.xyztile
import aspose.gis.geometries
import aspose.gis.geotools
import aspose.gis.geotools.extensions
import aspose.gis.geotools.layersmap
import aspose.gis.geotools.mapbuilder
import aspose.gis.geotools.wayanalyzer
import aspose.gis.imagemetadata
import aspose.gis.indexing
import aspose.gis.indexing.bplustree
import aspose.gis.indexing.qixtree
import aspose.gis.indexing.rtree
import aspose.gis.labeling
import aspose.gis.labeling.line
import aspose.gis.painting
import aspose.gis.projections
import aspose.gis.raster
import aspose.gis.raster.web
import aspose.gis.relationship
import aspose.gis.relationship.joins
import aspose.gis.rendering
import aspose.gis.rendering.colorizers
import aspose.gis.rendering.formats
import aspose.gis.rendering.formats.bmp
import aspose.gis.rendering.formats.jpeg
import aspose.gis.rendering.formats.png
import aspose.gis.rendering.formats.svg
import aspose.gis.rendering.labelings
import aspose.gis.rendering.sld
import aspose.gis.rendering.symbolizers
import aspose.gis.spatialreferencing
import aspose.gis.topology
import aspose.gis.topology.algorithms
import aspose.gis.topology.buffer
import aspose.gis.topology.graph

class CircularString(Curve):
    '''A multi-vertex curve with circular interpolation between points.'''
    
    @overload
    @staticmethod
    def from_text(wkt : str) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Text representation.
        
        :param wkt: Well-Known Text representation of a geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_text(wkt : str, spatial_reference_system : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Text representation.
        
        :param wkt: Well-Known Text representation of a geometry.
        :param spatial_reference_system: Spatial Reference System to be assigned to the geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_binary(wkb : List[int]) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Binary representation.
        
        :param wkb: Well-Known Binary representation of a geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_binary(wkb : List[int], spatial_reference_system : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Binary representation.
        
        :param wkb: Well-Known Binary representation of a geometry.
        :param spatial_reference_system: Spatial Reference System to be assigned to the geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self) -> aspose.gis.geometries.ILineString:
        '''Gets approximate or equivalent non-curve version of this geometry using the default ``tolerance``.
        
        :returns: A :py:class:`aspose.gis.geometries.ILineString` that approximates or equivalent to this curve.
        This is the equivalent of :py:func:`aspose.gis.geometries.ICurve.to_linear_geometry` with
        default ``tolerance``. Default ``tolerance``s value is dependent on :py:class:`aspose.gis.spatialreferencing.SpatialReferenceSystem`
        of this geometry:
        
        *
        
        *
        
        *
        
        For more details on what transformations are applied refer to :py:func:`aspose.gis.geometries.ICurve.to_linear_geometry` specification.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self, tolerance : float) -> aspose.gis.geometries.ILineString:
        '''Gets approximate or equivalent non-curve version of this geometry using the specified ``tolerance``.
        
        :param tolerance: The ``tolerance`` to use. The result is guaranteed to be less than ``tolerance`` away from the
        curved geometry, unless the number of points needed to linearize the geometry exceeds the per-quadrant maximum,
        currently equal to 10000 points.
        :returns: A :py:class:`aspose.gis.geometries.ILineString` that approximates or equivalent to this curve:
        
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : aspose.gis.AbstractPath, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : str, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> io.RawIOBase:
        '''Export this geometry to an image representation.
        
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.
        :returns: The image as stream'''
        raise NotImplementedError()
    
    @overload
    def as_text(self) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant, format : aspose.gis.NumericFormat) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :param format: Coordinate format for conversion to string. See the :py:class:`aspose.gis.NumericFormat` to get it.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self, variant : aspose.gis.geometries.WkbVariant) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :param variant: Well-Known Binary variant to use.
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def within(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry is within a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry is within extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def within(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is within a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially within" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry intersects a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry intersects the extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry intersects.
        
        :param other: A geometry.
        :returns: if this geometry "spatially intersects" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def add_point(self, point : aspose.gis.geometries.IPoint) -> None:
        '''Adds a point to the end of the circular string.
        
        :param point: The point to add.'''
        raise NotImplementedError()
    
    @overload
    def add_point(self, x : float, y : float) -> None:
        '''Adds a point to the end of the circular string.
        
        :param x: The value for X coordinate.
        :param y: The value for Y coordinate.'''
        raise NotImplementedError()
    
    @overload
    def add_point(self, x : float, y : float, z : float) -> None:
        '''Adds a point to the end of the circular string.
        
        :param x: The value for X coordinate.
        :param y: The value for Y coordinate.
        :param z: The value for Z coordinate.'''
        raise NotImplementedError()
    
    @overload
    def add_point(self, x : float, y : float, z : float, m : float) -> None:
        '''Adds a point to the end of the circular string.
        
        :param x: The value for X coordinate.
        :param y: The value for Y coordinate.
        :param z: The value for Z coordinate.
        :param m: The value for M coordinate.'''
        raise NotImplementedError()
    
    def to_editable(self) -> aspose.gis.geometries.CircularString:
        '''Gets an editable copy of this geometry.
        
        :returns: An editable copy of this geometry.'''
        raise NotImplementedError()
    
    def replace_polygons_by_lines(self) -> aspose.gis.geometries.IGeometry:
        '''Gets polygons represented as lines of this geometry.
        
        :returns: A geometry, that has no polygon geometries. The following transformation are applied:
        
        *
        
        *'''
        raise NotImplementedError()
    
    def to_svg(self, extent : aspose.gis.Extent) -> str:
        '''Translates this geometry to Svg representation.
        
        :param extent: Extent for translation this geometry to Svg
        :returns: The Svg representation.'''
        raise NotImplementedError()
    
    def set_empty(self) -> None:
        '''Makes this :py:class:`aspose.gis.geometries.Geometry` empty.'''
        raise NotImplementedError()
    
    def clone(self) -> aspose.gis.geometries.Geometry:
        '''Clones this instance.
        
        :returns: The clone of this instance'''
        raise NotImplementedError()
    
    def round_xy(self, digits : int) -> None:
        '''Rounds X and Y coordinates to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def round_z(self, digits : int) -> None:
        '''Rounds Z coordinate to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def round_m(self, digits : int) -> None:
        '''Rounds M coordinate to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def get_extent(self) -> aspose.gis.Extent:
        '''Computes and returns a bounding extent of this geometry.
        
        :returns: A bounding extent of this geometry.'''
        raise NotImplementedError()
    
    def get_area(self) -> float:
        '''Computes the area of this geometry.
        
        :returns: The area of this geometry.
        Sum of areas of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_length(self) -> float:
        '''Computes the length of this geometry.
        
        :returns: The length of this geometry.
        Perimeter if this is a :py:class:`aspose.gis.geometries.Polygon`.
        Sum of lengths of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_distance_to(self, other : aspose.gis.geometries.IGeometry) -> float:
        '''Computes the minimum distance between this geometry and a specified geometry.
        
        :param other: A geometry to find distance to.
        :returns: If both geometries are not :py:attr:`aspose.gis.geometries.Geometry.is_empty` - a distance between closest points of the geometries.
        If at least one geometry is empty -1 is returned.'''
        raise NotImplementedError()
    
    def get_convex_hull(self) -> aspose.gis.geometries.IGeometry:
        '''Computes the convex hull of this geometry.
        
        :returns: A geometry that represents a convex hull of this geometry.
        If this geometry has no points then the result is :py:attr:`aspose.gis.geometries.Geometry.null`.
        If this geometry has only one point then the result is this point.
        If this geometry has only two points then the result is :py:class:`aspose.gis.geometries.ILineString` with the points.
        If this geometry has three or more points then the result is :py:class:`aspose.gis.geometries.ILinearRing` that represents a convex
        hull around all geometries points.'''
        raise NotImplementedError()
    
    def get_centroid(self) -> aspose.gis.geometries.IPoint:
        '''Computes the centroid of this geometry.
        
        :returns: The centroid of this geometry. If this geometry is empty an empty point returned.
        The centroid is equal to the centroid of the highest dimension geometries in this geometry
        (e.g. if both points and lines are contained in the geometry, only lines contribute to centroid).'''
        raise NotImplementedError()
    
    def get_buffer(self, distance : float, quadrant_segments : int) -> aspose.gis.geometries.IGeometry:
        '''Computes a buffer region around this geometry.
        
        :param distance: The buffer region width.
        :param quadrant_segments: Number of segments used to approximate a 90 degree of curvature.
        The larger this number is the better approximation of curves is produced.
        Default is 30.
        :returns: A geometry that represents all points that are within a specified distance from
        this geometry.
        The type of result is either :py:attr:`aspose.gis.geometries.Geometry.null`, :py:class:`aspose.gis.geometries.IPolygon` or :py:class:`aspose.gis.geometries.IMultiPolygon`.'''
        raise NotImplementedError()
    
    def spatially_equals(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry spatially equal to a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry "spatially equals" to specified geometry.  otherwise.'''
        raise NotImplementedError()
    
    def disjoint(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry is disjoint from a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially disjoint" from another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def touches(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry touch.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially touches" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def crosses(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry cross.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially crosses" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def spatially_contains(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry spatially contains a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially contains" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def overlaps(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry overlap with a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially overlaps" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covers(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry covers a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covers" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covered_by(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is covered by a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covered by" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def relate(self, other : aspose.gis.geometries.IGeometry, intersection_pattern_matrix : str) -> bool:
        '''Determines if DE-9IM intersection matrix of this geometry and a specified geometry matches provided pattern.
        
        :param other: A geometry.
        :param intersection_pattern_matrix: A patter to match with.
        This should be a string with length equal to 9.
        Each character of the string represent expected dimension of an intersection:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        Possible values of each characters are:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        For example, an intersection pattern "F0*******" means, that there should not be intersection between geometries interiors
        and intersection between geometries boundaries must be a point.
        See OpenGIS Simple Features Specification for more details about intersection matrix pattern.
        :returns: if this intersection matrix matches patter;  otherwise.'''
        raise NotImplementedError()
    
    def intersection(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds an intersection between this geometry and a specified geometry.
        
        :param other: A geometry to compute intersection with.
        :returns: A geometry that represents an intersection of this geometry and an argument. The result geometry contain
        point set that present in both this geometry and an argument.'''
        raise NotImplementedError()
    
    def union(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Unites this geometry and a specified geometry.
        
        :param other: A geometry to unite with.
        :returns: A geometry that represents a union of this geometry and an argument. The result geometry contains
        point set that present in this geometry or in an argument.'''
        raise NotImplementedError()
    
    def difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Subtracts a specified geometry from this geometry.
        
        :param other: A geometry to subtract.
        :returns: A geometry that represents a difference of this geometry and an argument. The result geometry contains
        point set that present in this geometry but not present in an argument.'''
        raise NotImplementedError()
    
    def sym_difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds a symmetric difference between this geometry and a specified geometry.
        
        :param other: A geometry to compute symmetric difference with.
        :returns: A geometry that represents a symmetric difference of this geometry and an argument. The result geometry contains
        point set that present in one of the geometries but not present in both of them.'''
        raise NotImplementedError()
    
    def reverse(self) -> None:
        '''Reverses order of points in this :py:class:`aspose.gis.geometries.CircularString`.'''
        raise NotImplementedError()
    
    def equals(self, other : aspose.gis.geometries.ICircularString) -> bool:
        '''Indicates whether the current object is equal to another object of the same type.
        
        :param other: An object to compare with this object.
        :returns: true if the current object is equal to the ``other`` parameter; otherwise, false.'''
        raise NotImplementedError()
    
    @property
    def dimension(self) -> aspose.gis.geometries.GeometryDimension:
        '''Gets the topological dimension of this :py:class:`aspose.gis.geometries.Geometry`.'''
        raise NotImplementedError()
    
    null : aspose.gis.geometries.IGeometry
    '''Gets an instance of null geometry.'''
    @property
    def coordinate_dimension(self) -> int:
        '''Gets the number of coordinate dimensions for this :py:class:`aspose.gis.geometries.Geometry`.'''
        raise NotImplementedError()
    
    @property
    def is_empty(self) -> bool:
        '''Gets a value indicating whether this instance is empty.'''
        raise NotImplementedError()
    
    @property
    def is_simple(self) -> bool:
        '''Gets a value indicating whether this instance is simple from SFA point of view.'''
        raise NotImplementedError()
    
    @property
    def is_valid(self) -> bool:
        '''Gets a value indicating whether this instance is valid.'''
        raise NotImplementedError()
    
    @property
    def has_m(self) -> bool:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @has_m.setter
    def has_m(self, value : bool) -> None:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_z(self) -> bool:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @has_z.setter
    def has_z(self, value : bool) -> None:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_curve_geometry(self) -> bool:
        '''Gets a value indicating whether this geometry is or contains curve (not linear) geometry.'''
        raise NotImplementedError()
    
    @property
    def geometry_type(self) -> aspose.gis.geometries.GeometryType:
        '''Gets the type of the geometry.'''
        raise NotImplementedError()
    
    @property
    def spatial_reference_system(self) -> aspose.gis.spatialreferencing.SpatialReferenceSystem:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , if SpatialReferenceSystem is unset.
        Assigning new SpatialReferenceSystem will not perform any coordinate transformation, only reference will change.'''
        raise NotImplementedError()
    
    @spatial_reference_system.setter
    def spatial_reference_system(self, value : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> None:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , if SpatialReferenceSystem is unset.
        Assigning new SpatialReferenceSystem will not perform any coordinate transformation, only reference will change.'''
        raise NotImplementedError()
    
    @property
    def start_point(self) -> aspose.gis.geometries.IPoint:
        '''Returns a copy of the starting point of the curve.'''
        raise NotImplementedError()
    
    @property
    def end_point(self) -> aspose.gis.geometries.IPoint:
        '''Returns a copy of the end point of the curve.'''
        raise NotImplementedError()
    
    @property
    def is_closed(self) -> bool:
        '''Gets a values indicating whether a curve is closed.
        A curve is closed if its start point is equal to its end point.'''
        raise NotImplementedError()
    
    def __getitem__(self, key : int) -> aspose.gis.geometries.IPoint:
        '''Gets or sets the :py:class:`aspose.gis.geometries.IPoint` at the specified index.'''
        raise NotImplementedError()
    
    def __setitem__(self, key : int, value : aspose.gis.geometries.IPoint):
        raise NotImplementedError()
    

class CompoundCurve(Curve):
    '''A curve that represents a sequence of contiguous curves such that adjacent curves are joined at their end points.'''
    
    @overload
    @staticmethod
    def from_text(wkt : str) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Text representation.
        
        :param wkt: Well-Known Text representation of a geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_text(wkt : str, spatial_reference_system : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Text representation.
        
        :param wkt: Well-Known Text representation of a geometry.
        :param spatial_reference_system: Spatial Reference System to be assigned to the geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_binary(wkb : List[int]) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Binary representation.
        
        :param wkb: Well-Known Binary representation of a geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_binary(wkb : List[int], spatial_reference_system : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Binary representation.
        
        :param wkb: Well-Known Binary representation of a geometry.
        :param spatial_reference_system: Spatial Reference System to be assigned to the geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self) -> aspose.gis.geometries.ILineString:
        '''Gets approximate or equivalent non-curve version of this geometry using the default ``tolerance``.
        
        :returns: A :py:class:`aspose.gis.geometries.ILineString` that approximates or equivalent to this curve.
        This is the equivalent of :py:func:`aspose.gis.geometries.ICurve.to_linear_geometry` with
        default ``tolerance``. Default ``tolerance``s value is dependent on :py:class:`aspose.gis.spatialreferencing.SpatialReferenceSystem`
        of this geometry:
        
        *
        
        *
        
        *
        
        For more details on what transformations are applied refer to :py:func:`aspose.gis.geometries.ICurve.to_linear_geometry` specification.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self, tolerance : float) -> aspose.gis.geometries.ILineString:
        '''Gets approximate or equivalent non-curve version of this geometry using the specified ``tolerance``.
        
        :param tolerance: The ``tolerance`` to use. The result is guaranteed to be less than ``tolerance`` away from the
        curved geometry, unless the number of points needed to linearize the geometry exceeds the per-quadrant maximum,
        currently equal to 10000 points.
        :returns: A :py:class:`aspose.gis.geometries.ILineString` that approximates or equivalent to this curve:
        
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : aspose.gis.AbstractPath, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : str, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> io.RawIOBase:
        '''Export this geometry to an image representation.
        
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.
        :returns: The image as stream'''
        raise NotImplementedError()
    
    @overload
    def as_text(self) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant, format : aspose.gis.NumericFormat) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :param format: Coordinate format for conversion to string. See the :py:class:`aspose.gis.NumericFormat` to get it.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self, variant : aspose.gis.geometries.WkbVariant) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :param variant: Well-Known Binary variant to use.
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def within(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry is within a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry is within extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def within(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is within a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially within" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry intersects a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry intersects the extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry intersects.
        
        :param other: A geometry.
        :returns: if this geometry "spatially intersects" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def to_editable(self) -> aspose.gis.geometries.CompoundCurve:
        '''Gets an editable copy of this geometry.
        
        :returns: An editable copy of this geometry.'''
        raise NotImplementedError()
    
    def replace_polygons_by_lines(self) -> aspose.gis.geometries.IGeometry:
        '''Gets polygons represented as lines of this geometry.
        
        :returns: A geometry, that has no polygon geometries. The following transformation are applied:
        
        *
        
        *'''
        raise NotImplementedError()
    
    def to_svg(self, extent : aspose.gis.Extent) -> str:
        '''Translates this geometry to Svg representation.
        
        :param extent: Extent for translation this geometry to Svg
        :returns: The Svg representation.'''
        raise NotImplementedError()
    
    def set_empty(self) -> None:
        '''Makes this :py:class:`aspose.gis.geometries.Geometry` empty.'''
        raise NotImplementedError()
    
    def clone(self) -> aspose.gis.geometries.Geometry:
        '''Clones this instance.
        
        :returns: The clone of this instance'''
        raise NotImplementedError()
    
    def round_xy(self, digits : int) -> None:
        '''Rounds X and Y coordinates to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def round_z(self, digits : int) -> None:
        '''Rounds Z coordinate to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def round_m(self, digits : int) -> None:
        '''Rounds M coordinate to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def get_extent(self) -> aspose.gis.Extent:
        '''Computes and returns a bounding extent of this geometry.
        
        :returns: A bounding extent of this geometry.'''
        raise NotImplementedError()
    
    def get_area(self) -> float:
        '''Computes the area of this geometry.
        
        :returns: The area of this geometry.
        Sum of areas of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_length(self) -> float:
        '''Computes the length of this geometry.
        
        :returns: The length of this geometry.
        Perimeter if this is a :py:class:`aspose.gis.geometries.Polygon`.
        Sum of lengths of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_distance_to(self, other : aspose.gis.geometries.IGeometry) -> float:
        '''Computes the minimum distance between this geometry and a specified geometry.
        
        :param other: A geometry to find distance to.
        :returns: If both geometries are not :py:attr:`aspose.gis.geometries.Geometry.is_empty` - a distance between closest points of the geometries.
        If at least one geometry is empty -1 is returned.'''
        raise NotImplementedError()
    
    def get_convex_hull(self) -> aspose.gis.geometries.IGeometry:
        '''Computes the convex hull of this geometry.
        
        :returns: A geometry that represents a convex hull of this geometry.
        If this geometry has no points then the result is :py:attr:`aspose.gis.geometries.Geometry.null`.
        If this geometry has only one point then the result is this point.
        If this geometry has only two points then the result is :py:class:`aspose.gis.geometries.ILineString` with the points.
        If this geometry has three or more points then the result is :py:class:`aspose.gis.geometries.ILinearRing` that represents a convex
        hull around all geometries points.'''
        raise NotImplementedError()
    
    def get_centroid(self) -> aspose.gis.geometries.IPoint:
        '''Computes the centroid of this geometry.
        
        :returns: The centroid of this geometry. If this geometry is empty an empty point returned.
        The centroid is equal to the centroid of the highest dimension geometries in this geometry
        (e.g. if both points and lines are contained in the geometry, only lines contribute to centroid).'''
        raise NotImplementedError()
    
    def get_buffer(self, distance : float, quadrant_segments : int) -> aspose.gis.geometries.IGeometry:
        '''Computes a buffer region around this geometry.
        
        :param distance: The buffer region width.
        :param quadrant_segments: Number of segments used to approximate a 90 degree of curvature.
        The larger this number is the better approximation of curves is produced.
        Default is 30.
        :returns: A geometry that represents all points that are within a specified distance from
        this geometry.
        The type of result is either :py:attr:`aspose.gis.geometries.Geometry.null`, :py:class:`aspose.gis.geometries.IPolygon` or :py:class:`aspose.gis.geometries.IMultiPolygon`.'''
        raise NotImplementedError()
    
    def spatially_equals(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry spatially equal to a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry "spatially equals" to specified geometry.  otherwise.'''
        raise NotImplementedError()
    
    def disjoint(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry is disjoint from a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially disjoint" from another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def touches(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry touch.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially touches" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def crosses(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry cross.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially crosses" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def spatially_contains(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry spatially contains a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially contains" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def overlaps(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry overlap with a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially overlaps" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covers(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry covers a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covers" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covered_by(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is covered by a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covered by" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def relate(self, other : aspose.gis.geometries.IGeometry, intersection_pattern_matrix : str) -> bool:
        '''Determines if DE-9IM intersection matrix of this geometry and a specified geometry matches provided pattern.
        
        :param other: A geometry.
        :param intersection_pattern_matrix: A patter to match with.
        This should be a string with length equal to 9.
        Each character of the string represent expected dimension of an intersection:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        Possible values of each characters are:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        For example, an intersection pattern "F0*******" means, that there should not be intersection between geometries interiors
        and intersection between geometries boundaries must be a point.
        See OpenGIS Simple Features Specification for more details about intersection matrix pattern.
        :returns: if this intersection matrix matches patter;  otherwise.'''
        raise NotImplementedError()
    
    def intersection(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds an intersection between this geometry and a specified geometry.
        
        :param other: A geometry to compute intersection with.
        :returns: A geometry that represents an intersection of this geometry and an argument. The result geometry contain
        point set that present in both this geometry and an argument.'''
        raise NotImplementedError()
    
    def union(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Unites this geometry and a specified geometry.
        
        :param other: A geometry to unite with.
        :returns: A geometry that represents a union of this geometry and an argument. The result geometry contains
        point set that present in this geometry or in an argument.'''
        raise NotImplementedError()
    
    def difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Subtracts a specified geometry from this geometry.
        
        :param other: A geometry to subtract.
        :returns: A geometry that represents a difference of this geometry and an argument. The result geometry contains
        point set that present in this geometry but not present in an argument.'''
        raise NotImplementedError()
    
    def sym_difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds a symmetric difference between this geometry and a specified geometry.
        
        :param other: A geometry to compute symmetric difference with.
        :returns: A geometry that represents a symmetric difference of this geometry and an argument. The result geometry contains
        point set that present in one of the geometries but not present in both of them.'''
        raise NotImplementedError()
    
    def reverse(self) -> None:
        '''Reverses this :py:class:`aspose.gis.geometries.CompoundCurve`. That is - reverse order of curves and every curve inside this compound curve.'''
        raise NotImplementedError()
    
    def add_curve(self, curve : aspose.gis.geometries.ICurve) -> None:
        '''Adds a curve to the end of this :py:class:`aspose.gis.geometries.CompoundCurve`.
        
        :param curve: Curve to add.'''
        raise NotImplementedError()
    
    def equals(self, other : aspose.gis.geometries.ICompoundCurve) -> bool:
        '''Indicates whether the current object is equal to another object of the same type.
        
        :param other: An object to compare with this object.
        :returns: true if the current object is equal to the ``other`` parameter; otherwise, false.'''
        raise NotImplementedError()
    
    @property
    def dimension(self) -> aspose.gis.geometries.GeometryDimension:
        '''Gets the topological dimension of this :py:class:`aspose.gis.geometries.Geometry`.'''
        raise NotImplementedError()
    
    null : aspose.gis.geometries.IGeometry
    '''Gets an instance of null geometry.'''
    @property
    def coordinate_dimension(self) -> int:
        '''Gets the number of coordinate dimensions for this :py:class:`aspose.gis.geometries.Geometry`.'''
        raise NotImplementedError()
    
    @property
    def is_empty(self) -> bool:
        '''Gets a value indicating whether this instance is empty.'''
        raise NotImplementedError()
    
    @property
    def is_simple(self) -> bool:
        '''Gets a value indicating whether this instance is simple from SFA point of view.'''
        raise NotImplementedError()
    
    @property
    def is_valid(self) -> bool:
        '''Gets a value indicating whether this instance is valid.'''
        raise NotImplementedError()
    
    @property
    def has_m(self) -> bool:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @has_m.setter
    def has_m(self, value : bool) -> None:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_z(self) -> bool:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @has_z.setter
    def has_z(self, value : bool) -> None:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_curve_geometry(self) -> bool:
        '''Gets a value indicating whether this geometry is or contains curve (not linear) geometry.'''
        raise NotImplementedError()
    
    @property
    def geometry_type(self) -> aspose.gis.geometries.GeometryType:
        '''Gets the type of the geometry.'''
        raise NotImplementedError()
    
    @property
    def spatial_reference_system(self) -> aspose.gis.spatialreferencing.SpatialReferenceSystem:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , if SpatialReferenceSystem is unset.
        Assigning new SpatialReferenceSystem will not perform any coordinate transformation, only reference will change.'''
        raise NotImplementedError()
    
    @spatial_reference_system.setter
    def spatial_reference_system(self, value : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> None:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , if SpatialReferenceSystem is unset.
        Assigning new SpatialReferenceSystem will not perform any coordinate transformation, only reference will change.'''
        raise NotImplementedError()
    
    @property
    def start_point(self) -> aspose.gis.geometries.IPoint:
        '''Returns a copy of the starting point of the curve.'''
        raise NotImplementedError()
    
    @property
    def end_point(self) -> aspose.gis.geometries.IPoint:
        '''Returns a copy of the end point of the curve.'''
        raise NotImplementedError()
    
    @property
    def is_closed(self) -> bool:
        '''Gets a values indicating whether a curve is closed.
        A curve is closed if its start point is equal to its end point.'''
        raise NotImplementedError()
    
    @property
    def count(self) -> int:
        '''Gets the number of curves in the :py:class:`aspose.gis.geometries.ICompoundCurve`.'''
        raise NotImplementedError()
    
    def __getitem__(self, key : int) -> aspose.gis.geometries.ICurve:
        '''Gets the :py:class:`aspose.gis.geometries.ICurve` at the specified index.'''
        raise NotImplementedError()
    

class Curve(Geometry):
    '''A :py:class:`aspose.gis.geometries.Curve` is a sequence of points.'''
    
    @overload
    @staticmethod
    def from_text(wkt : str) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Text representation.
        
        :param wkt: Well-Known Text representation of a geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_text(wkt : str, spatial_reference_system : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Text representation.
        
        :param wkt: Well-Known Text representation of a geometry.
        :param spatial_reference_system: Spatial Reference System to be assigned to the geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_binary(wkb : List[int]) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Binary representation.
        
        :param wkb: Well-Known Binary representation of a geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_binary(wkb : List[int], spatial_reference_system : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Binary representation.
        
        :param wkb: Well-Known Binary representation of a geometry.
        :param spatial_reference_system: Spatial Reference System to be assigned to the geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self) -> aspose.gis.geometries.ILineString:
        '''Gets approximate or equivalent non-curve version of this geometry using the default ``tolerance``.
        
        :returns: A :py:class:`aspose.gis.geometries.ILineString` that approximates or equivalent to this curve.
        This is the equivalent of :py:func:`aspose.gis.geometries.ICurve.to_linear_geometry` with
        default ``tolerance``. Default ``tolerance``s value is dependent on :py:class:`aspose.gis.spatialreferencing.SpatialReferenceSystem`
        of this geometry:
        
        *
        
        *
        
        *
        
        For more details on what transformations are applied refer to :py:func:`aspose.gis.geometries.ICurve.to_linear_geometry` specification.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self, tolerance : float) -> aspose.gis.geometries.ILineString:
        '''Gets approximate or equivalent non-curve version of this geometry using the specified ``tolerance``.
        
        :param tolerance: The ``tolerance`` to use. The result is guaranteed to be less than ``tolerance`` away from the
        curved geometry, unless the number of points needed to linearize the geometry exceeds the per-quadrant maximum,
        currently equal to 10000 points.
        :returns: A :py:class:`aspose.gis.geometries.ILineString` that approximates or equivalent to this curve:
        
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : aspose.gis.AbstractPath, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : str, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> io.RawIOBase:
        '''Export this geometry to an image representation.
        
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.
        :returns: The image as stream'''
        raise NotImplementedError()
    
    @overload
    def as_text(self) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant, format : aspose.gis.NumericFormat) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :param format: Coordinate format for conversion to string. See the :py:class:`aspose.gis.NumericFormat` to get it.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self, variant : aspose.gis.geometries.WkbVariant) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :param variant: Well-Known Binary variant to use.
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def within(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry is within a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry is within extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def within(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is within a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially within" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry intersects a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry intersects the extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry intersects.
        
        :param other: A geometry.
        :returns: if this geometry "spatially intersects" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def to_editable(self) -> aspose.gis.geometries.Curve:
        '''Gets an editable copy of this geometry.
        
        :returns: An editable copy of this geometry.'''
        raise NotImplementedError()
    
    def replace_polygons_by_lines(self) -> aspose.gis.geometries.IGeometry:
        '''Gets polygons represented as lines of this geometry.
        
        :returns: A geometry, that has no polygon geometries. The following transformation are applied:
        
        *
        
        *'''
        raise NotImplementedError()
    
    def to_svg(self, extent : aspose.gis.Extent) -> str:
        '''Translates this geometry to Svg representation.
        
        :param extent: Extent for translation this geometry to Svg
        :returns: The Svg representation.'''
        raise NotImplementedError()
    
    def set_empty(self) -> None:
        '''Makes this :py:class:`aspose.gis.geometries.Geometry` empty.'''
        raise NotImplementedError()
    
    def clone(self) -> aspose.gis.geometries.Geometry:
        '''Clones this instance.
        
        :returns: The clone of this instance'''
        raise NotImplementedError()
    
    def round_xy(self, digits : int) -> None:
        '''Rounds X and Y coordinates to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def round_z(self, digits : int) -> None:
        '''Rounds Z coordinate to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def round_m(self, digits : int) -> None:
        '''Rounds M coordinate to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def get_extent(self) -> aspose.gis.Extent:
        '''Computes and returns a bounding extent of this geometry.
        
        :returns: A bounding extent of this geometry.'''
        raise NotImplementedError()
    
    def get_area(self) -> float:
        '''Computes the area of this geometry.
        
        :returns: The area of this geometry.
        Sum of areas of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_length(self) -> float:
        '''Computes the length of this geometry.
        
        :returns: The length of this geometry.
        Perimeter if this is a :py:class:`aspose.gis.geometries.Polygon`.
        Sum of lengths of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_distance_to(self, other : aspose.gis.geometries.IGeometry) -> float:
        '''Computes the minimum distance between this geometry and a specified geometry.
        
        :param other: A geometry to find distance to.
        :returns: If both geometries are not :py:attr:`aspose.gis.geometries.Geometry.is_empty` - a distance between closest points of the geometries.
        If at least one geometry is empty -1 is returned.'''
        raise NotImplementedError()
    
    def get_convex_hull(self) -> aspose.gis.geometries.IGeometry:
        '''Computes the convex hull of this geometry.
        
        :returns: A geometry that represents a convex hull of this geometry.
        If this geometry has no points then the result is :py:attr:`aspose.gis.geometries.Geometry.null`.
        If this geometry has only one point then the result is this point.
        If this geometry has only two points then the result is :py:class:`aspose.gis.geometries.ILineString` with the points.
        If this geometry has three or more points then the result is :py:class:`aspose.gis.geometries.ILinearRing` that represents a convex
        hull around all geometries points.'''
        raise NotImplementedError()
    
    def get_centroid(self) -> aspose.gis.geometries.IPoint:
        '''Computes the centroid of this geometry.
        
        :returns: The centroid of this geometry. If this geometry is empty an empty point returned.
        The centroid is equal to the centroid of the highest dimension geometries in this geometry
        (e.g. if both points and lines are contained in the geometry, only lines contribute to centroid).'''
        raise NotImplementedError()
    
    def get_buffer(self, distance : float, quadrant_segments : int) -> aspose.gis.geometries.IGeometry:
        '''Computes a buffer region around this geometry.
        
        :param distance: The buffer region width.
        :param quadrant_segments: Number of segments used to approximate a 90 degree of curvature.
        The larger this number is the better approximation of curves is produced.
        Default is 30.
        :returns: A geometry that represents all points that are within a specified distance from
        this geometry.
        The type of result is either :py:attr:`aspose.gis.geometries.Geometry.null`, :py:class:`aspose.gis.geometries.IPolygon` or :py:class:`aspose.gis.geometries.IMultiPolygon`.'''
        raise NotImplementedError()
    
    def spatially_equals(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry spatially equal to a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry "spatially equals" to specified geometry.  otherwise.'''
        raise NotImplementedError()
    
    def disjoint(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry is disjoint from a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially disjoint" from another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def touches(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry touch.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially touches" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def crosses(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry cross.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially crosses" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def spatially_contains(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry spatially contains a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially contains" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def overlaps(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry overlap with a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially overlaps" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covers(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry covers a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covers" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covered_by(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is covered by a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covered by" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def relate(self, other : aspose.gis.geometries.IGeometry, intersection_pattern_matrix : str) -> bool:
        '''Determines if DE-9IM intersection matrix of this geometry and a specified geometry matches provided pattern.
        
        :param other: A geometry.
        :param intersection_pattern_matrix: A patter to match with.
        This should be a string with length equal to 9.
        Each character of the string represent expected dimension of an intersection:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        Possible values of each characters are:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        For example, an intersection pattern "F0*******" means, that there should not be intersection between geometries interiors
        and intersection between geometries boundaries must be a point.
        See OpenGIS Simple Features Specification for more details about intersection matrix pattern.
        :returns: if this intersection matrix matches patter;  otherwise.'''
        raise NotImplementedError()
    
    def intersection(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds an intersection between this geometry and a specified geometry.
        
        :param other: A geometry to compute intersection with.
        :returns: A geometry that represents an intersection of this geometry and an argument. The result geometry contain
        point set that present in both this geometry and an argument.'''
        raise NotImplementedError()
    
    def union(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Unites this geometry and a specified geometry.
        
        :param other: A geometry to unite with.
        :returns: A geometry that represents a union of this geometry and an argument. The result geometry contains
        point set that present in this geometry or in an argument.'''
        raise NotImplementedError()
    
    def difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Subtracts a specified geometry from this geometry.
        
        :param other: A geometry to subtract.
        :returns: A geometry that represents a difference of this geometry and an argument. The result geometry contains
        point set that present in this geometry but not present in an argument.'''
        raise NotImplementedError()
    
    def sym_difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds a symmetric difference between this geometry and a specified geometry.
        
        :param other: A geometry to compute symmetric difference with.
        :returns: A geometry that represents a symmetric difference of this geometry and an argument. The result geometry contains
        point set that present in one of the geometries but not present in both of them.'''
        raise NotImplementedError()
    
    def reverse(self) -> None:
        '''Reverses this curve.'''
        raise NotImplementedError()
    
    @property
    def dimension(self) -> aspose.gis.geometries.GeometryDimension:
        '''Gets the topological dimension of this :py:class:`aspose.gis.geometries.Geometry`.'''
        raise NotImplementedError()
    
    null : aspose.gis.geometries.IGeometry
    '''Gets an instance of null geometry.'''
    @property
    def coordinate_dimension(self) -> int:
        '''Gets the number of coordinate dimensions for this :py:class:`aspose.gis.geometries.Geometry`.'''
        raise NotImplementedError()
    
    @property
    def is_empty(self) -> bool:
        '''Gets a value indicating whether this instance is empty.'''
        raise NotImplementedError()
    
    @property
    def is_simple(self) -> bool:
        '''Gets a value indicating whether this instance is simple from SFA point of view.'''
        raise NotImplementedError()
    
    @property
    def is_valid(self) -> bool:
        '''Gets a value indicating whether this instance is valid.'''
        raise NotImplementedError()
    
    @property
    def has_m(self) -> bool:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @has_m.setter
    def has_m(self, value : bool) -> None:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_z(self) -> bool:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @has_z.setter
    def has_z(self, value : bool) -> None:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_curve_geometry(self) -> bool:
        '''Gets a value indicating whether this geometry is or contains curve (not linear) geometry.'''
        raise NotImplementedError()
    
    @property
    def geometry_type(self) -> aspose.gis.geometries.GeometryType:
        '''Gets the type of the geometry.'''
        raise NotImplementedError()
    
    @property
    def spatial_reference_system(self) -> aspose.gis.spatialreferencing.SpatialReferenceSystem:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , is SpatialReferenceSystem is unknown.
        Assigning new SpatialReferenceSystem will not perform any coordinate transformation, only reference will change.'''
        raise NotImplementedError()
    
    @spatial_reference_system.setter
    def spatial_reference_system(self, value : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> None:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , is SpatialReferenceSystem is unknown.
        Assigning new SpatialReferenceSystem will not perform any coordinate transformation, only reference will change.'''
        raise NotImplementedError()
    
    @property
    def start_point(self) -> aspose.gis.geometries.IPoint:
        '''Returns a copy of the starting point of the curve.'''
        raise NotImplementedError()
    
    @property
    def end_point(self) -> aspose.gis.geometries.IPoint:
        '''Returns a copy of the end point of the curve.'''
        raise NotImplementedError()
    
    @property
    def is_closed(self) -> bool:
        '''Gets a values indicating whether a curve is closed.
        A curve is closed if its start point is equal to its end point.'''
        raise NotImplementedError()
    

class CurvePolygon(Surface):
    '''A planar surface, defined by 1 exterior boundary and 0 or more interior boundaries.'''
    
    @overload
    @staticmethod
    def from_text(wkt : str) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Text representation.
        
        :param wkt: Well-Known Text representation of a geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_text(wkt : str, spatial_reference_system : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Text representation.
        
        :param wkt: Well-Known Text representation of a geometry.
        :param spatial_reference_system: Spatial Reference System to be assigned to the geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_binary(wkb : List[int]) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Binary representation.
        
        :param wkb: Well-Known Binary representation of a geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_binary(wkb : List[int], spatial_reference_system : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Binary representation.
        
        :param wkb: Well-Known Binary representation of a geometry.
        :param spatial_reference_system: Spatial Reference System to be assigned to the geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self) -> aspose.gis.geometries.IPolygon:
        '''Gets approximate or equivalent non-curve version of this geometry using the default ``tolerance``.
        
        :returns: A :py:class:`aspose.gis.geometries.IPolygon` that approximates or equivalent to this ``ISurface``.
        This is the equivalent of :py:func:`aspose.gis.geometries.ISurface.to_linear_geometry` with
        default ``tolerance``. Default ``tolerance``s value is dependent on :py:class:`aspose.gis.spatialreferencing.SpatialReferenceSystem`
        of this geometry:
        
        *
        
        *
        
        *
        
        For more details on what transformations are applied refer to :py:func:`aspose.gis.geometries.ISurface.to_linear_geometry` specification.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self, tolerance : float) -> aspose.gis.geometries.IPolygon:
        '''Gets approximate or equivalent non-curve version of this geometry using the specified ``tolerance``.
        
        :param tolerance: The ``tolerance`` to use. The result is guaranteed to be less than ``tolerance`` away from the
        curved geometry, unless the number of points needed to linearize the geometry exceeds the per-quadrant maximum,
        currently equal to 10000 points.
        :returns: A :py:class:`aspose.gis.geometries.IPolygon` that approximates or equivalent to this ``ISurface``:
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : aspose.gis.AbstractPath, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : str, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> io.RawIOBase:
        '''Export this geometry to an image representation.
        
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.
        :returns: The image as stream'''
        raise NotImplementedError()
    
    @overload
    def as_text(self) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant, format : aspose.gis.NumericFormat) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :param format: Coordinate format for conversion to string. See the :py:class:`aspose.gis.NumericFormat` to get it.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self, variant : aspose.gis.geometries.WkbVariant) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :param variant: Well-Known Binary variant to use.
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def within(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry is within a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry is within extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def within(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is within a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially within" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry intersects a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry intersects the extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry intersects.
        
        :param other: A geometry.
        :returns: if this geometry "spatially intersects" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def to_editable(self) -> aspose.gis.geometries.CurvePolygon:
        '''Gets an editable copy of this geometry.
        
        :returns: An editable copy of this geometry.'''
        raise NotImplementedError()
    
    def replace_polygons_by_lines(self) -> aspose.gis.geometries.IGeometry:
        '''Gets polygons represented as lines of this geometry.
        
        :returns: A geometry, that has no polygon geometries. The following transformation are applied:
        
        *
        
        *'''
        raise NotImplementedError()
    
    def to_svg(self, extent : aspose.gis.Extent) -> str:
        '''Translates this geometry to Svg representation.
        
        :param extent: Extent for translation this geometry to Svg
        :returns: The Svg representation.'''
        raise NotImplementedError()
    
    def set_empty(self) -> None:
        '''Makes this :py:class:`aspose.gis.geometries.Geometry` empty.'''
        raise NotImplementedError()
    
    def clone(self) -> aspose.gis.geometries.Geometry:
        '''Clones this instance.
        
        :returns: The clone of this instance'''
        raise NotImplementedError()
    
    def round_xy(self, digits : int) -> None:
        '''Rounds X and Y coordinates to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def round_z(self, digits : int) -> None:
        '''Rounds Z coordinate to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def round_m(self, digits : int) -> None:
        '''Rounds M coordinate to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def get_extent(self) -> aspose.gis.Extent:
        '''Computes and returns a bounding extent of this geometry.
        
        :returns: A bounding extent of this geometry.'''
        raise NotImplementedError()
    
    def get_area(self) -> float:
        '''Computes the area of this geometry.
        
        :returns: The area of this geometry.
        Sum of areas of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_length(self) -> float:
        '''Computes the length of this geometry.
        
        :returns: The length of this geometry.
        Perimeter if this is a :py:class:`aspose.gis.geometries.Polygon`.
        Sum of lengths of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_distance_to(self, other : aspose.gis.geometries.IGeometry) -> float:
        '''Computes the minimum distance between this geometry and a specified geometry.
        
        :param other: A geometry to find distance to.
        :returns: If both geometries are not :py:attr:`aspose.gis.geometries.Geometry.is_empty` - a distance between closest points of the geometries.
        If at least one geometry is empty -1 is returned.'''
        raise NotImplementedError()
    
    def get_convex_hull(self) -> aspose.gis.geometries.IGeometry:
        '''Computes the convex hull of this geometry.
        
        :returns: A geometry that represents a convex hull of this geometry.
        If this geometry has no points then the result is :py:attr:`aspose.gis.geometries.Geometry.null`.
        If this geometry has only one point then the result is this point.
        If this geometry has only two points then the result is :py:class:`aspose.gis.geometries.ILineString` with the points.
        If this geometry has three or more points then the result is :py:class:`aspose.gis.geometries.ILinearRing` that represents a convex
        hull around all geometries points.'''
        raise NotImplementedError()
    
    def get_centroid(self) -> aspose.gis.geometries.IPoint:
        '''Computes the centroid of this geometry.
        
        :returns: The centroid of this geometry. If this geometry is empty an empty point returned.
        The centroid is equal to the centroid of the highest dimension geometries in this geometry
        (e.g. if both points and lines are contained in the geometry, only lines contribute to centroid).'''
        raise NotImplementedError()
    
    def get_buffer(self, distance : float, quadrant_segments : int) -> aspose.gis.geometries.IGeometry:
        '''Computes a buffer region around this geometry.
        
        :param distance: The buffer region width.
        :param quadrant_segments: Number of segments used to approximate a 90 degree of curvature.
        The larger this number is the better approximation of curves is produced.
        Default is 30.
        :returns: A geometry that represents all points that are within a specified distance from
        this geometry.
        The type of result is either :py:attr:`aspose.gis.geometries.Geometry.null`, :py:class:`aspose.gis.geometries.IPolygon` or :py:class:`aspose.gis.geometries.IMultiPolygon`.'''
        raise NotImplementedError()
    
    def spatially_equals(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry spatially equal to a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry "spatially equals" to specified geometry.  otherwise.'''
        raise NotImplementedError()
    
    def disjoint(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry is disjoint from a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially disjoint" from another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def touches(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry touch.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially touches" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def crosses(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry cross.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially crosses" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def spatially_contains(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry spatially contains a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially contains" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def overlaps(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry overlap with a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially overlaps" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covers(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry covers a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covers" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covered_by(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is covered by a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covered by" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def relate(self, other : aspose.gis.geometries.IGeometry, intersection_pattern_matrix : str) -> bool:
        '''Determines if DE-9IM intersection matrix of this geometry and a specified geometry matches provided pattern.
        
        :param other: A geometry.
        :param intersection_pattern_matrix: A patter to match with.
        This should be a string with length equal to 9.
        Each character of the string represent expected dimension of an intersection:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        Possible values of each characters are:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        For example, an intersection pattern "F0*******" means, that there should not be intersection between geometries interiors
        and intersection between geometries boundaries must be a point.
        See OpenGIS Simple Features Specification for more details about intersection matrix pattern.
        :returns: if this intersection matrix matches patter;  otherwise.'''
        raise NotImplementedError()
    
    def intersection(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds an intersection between this geometry and a specified geometry.
        
        :param other: A geometry to compute intersection with.
        :returns: A geometry that represents an intersection of this geometry and an argument. The result geometry contain
        point set that present in both this geometry and an argument.'''
        raise NotImplementedError()
    
    def union(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Unites this geometry and a specified geometry.
        
        :param other: A geometry to unite with.
        :returns: A geometry that represents a union of this geometry and an argument. The result geometry contains
        point set that present in this geometry or in an argument.'''
        raise NotImplementedError()
    
    def difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Subtracts a specified geometry from this geometry.
        
        :param other: A geometry to subtract.
        :returns: A geometry that represents a difference of this geometry and an argument. The result geometry contains
        point set that present in this geometry but not present in an argument.'''
        raise NotImplementedError()
    
    def sym_difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds a symmetric difference between this geometry and a specified geometry.
        
        :param other: A geometry to compute symmetric difference with.
        :returns: A geometry that represents a symmetric difference of this geometry and an argument. The result geometry contains
        point set that present in one of the geometries but not present in both of them.'''
        raise NotImplementedError()
    
    def get_point_on_surface(self) -> aspose.gis.geometries.IPoint:
        '''Finds a point that is guaranteed to be on this curved polygon.
        
        :returns: A point on this curved polygon. An empty point if this curved polygon has no interior.'''
        raise NotImplementedError()
    
    def get_interior_ring(self, index : int) -> aspose.gis.geometries.ICurve:
        '''Gets the interior ring by its index.
        
        :param index: The index.
        :returns: The interior ring.'''
        raise NotImplementedError()
    
    def add_interior_ring(self, ring : aspose.gis.geometries.ICurve) -> None:
        '''Adds an interior ring.
        
        :param ring: The ring to add.'''
        raise NotImplementedError()
    
    def equals(self, other : aspose.gis.geometries.ICurvePolygon) -> bool:
        '''Indicates whether the current object is equal to another object of the same type.
        
        :param other: An object to compare with this object.
        :returns: true if the current object is equal to the ``other`` parameter; otherwise, false.'''
        raise NotImplementedError()
    
    @property
    def dimension(self) -> aspose.gis.geometries.GeometryDimension:
        '''Gets the topological dimension of this :py:class:`aspose.gis.geometries.Geometry`.'''
        raise NotImplementedError()
    
    null : aspose.gis.geometries.IGeometry
    '''Gets an instance of null geometry.'''
    @property
    def coordinate_dimension(self) -> int:
        '''Gets the number of coordinate dimensions for this :py:class:`aspose.gis.geometries.Geometry`.'''
        raise NotImplementedError()
    
    @property
    def is_empty(self) -> bool:
        '''Gets a value indicating whether this instance is empty.'''
        raise NotImplementedError()
    
    @property
    def is_simple(self) -> bool:
        '''Gets a value indicating whether this instance is simple from SFA point of view.'''
        raise NotImplementedError()
    
    @property
    def is_valid(self) -> bool:
        '''Gets a value indicating whether this instance is valid.'''
        raise NotImplementedError()
    
    @property
    def has_m(self) -> bool:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @has_m.setter
    def has_m(self, value : bool) -> None:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_z(self) -> bool:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @has_z.setter
    def has_z(self, value : bool) -> None:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_curve_geometry(self) -> bool:
        '''Gets a value indicating whether this geometry is or contains curve (not linear) geometry.'''
        raise NotImplementedError()
    
    @property
    def geometry_type(self) -> aspose.gis.geometries.GeometryType:
        '''Gets the type of the geometry.'''
        raise NotImplementedError()
    
    @property
    def spatial_reference_system(self) -> aspose.gis.spatialreferencing.SpatialReferenceSystem:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , is SpatialReferenceSystem is unknown.
        Assigning new SpatialReferenceSystem will not perform any coordinate transformation, only reference will change.'''
        raise NotImplementedError()
    
    @spatial_reference_system.setter
    def spatial_reference_system(self, value : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> None:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , is SpatialReferenceSystem is unknown.
        Assigning new SpatialReferenceSystem will not perform any coordinate transformation, only reference will change.'''
        raise NotImplementedError()
    
    @property
    def exterior_ring(self) -> aspose.gis.geometries.ICurve:
        '''Gets the exterior ring.'''
        raise NotImplementedError()
    
    @exterior_ring.setter
    def exterior_ring(self, value : aspose.gis.geometries.ICurve) -> None:
        '''Gets the exterior ring.'''
        raise NotImplementedError()
    
    @property
    def interior_rings_count(self) -> int:
        '''Gets the number of interior rings.'''
        raise NotImplementedError()
    

class Geometry(IGeometry):
    '''The abstract root class of the geometries hierarchy.'''
    
    @overload
    @staticmethod
    def from_text(wkt : str) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Text representation.
        
        :param wkt: Well-Known Text representation of a geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_text(wkt : str, spatial_reference_system : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Text representation.
        
        :param wkt: Well-Known Text representation of a geometry.
        :param spatial_reference_system: Spatial Reference System to be assigned to the geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_binary(wkb : List[int]) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Binary representation.
        
        :param wkb: Well-Known Binary representation of a geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_binary(wkb : List[int], spatial_reference_system : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Binary representation.
        
        :param wkb: Well-Known Binary representation of a geometry.
        :param spatial_reference_system: Spatial Reference System to be assigned to the geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self) -> aspose.gis.geometries.IGeometry:
        '''Gets approximate or equivalent non-curve version of this geometry using the default ``tolerance``.
        
        :returns: A geometry that has no curve geometries. This is the equivalent of :py:func:`aspose.gis.geometries.IGeometry.to_linear_geometry` with
        default ``tolerance``. Default ``tolerance`` is defined by :py:attr:`aspose.gis.geometries.IGeometry.spatial_reference_system`
        of this geometry:
        
        *
        
        *
        
        *
        
        For more details on what transformations are applied refer to :py:func:`aspose.gis.geometries.IGeometry.to_linear_geometry` specification.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self, tolerance : float) -> aspose.gis.geometries.IGeometry:
        '''Gets approximate or equivalent non-curve version of this geometry using the specified ``tolerance``.
        
        :param tolerance: The ``tolerance`` to use. The result is guaranteed to be less than ``tolerance`` away from the
        curved geometry, unless the number of points needed to linearize the geometry exceeds the per-quadrant maximum
        which is currently equal to 10000 points.
        :returns: A geometry, that has no curve geometries. The following transformations are applied:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        As a result, :py:attr:`aspose.gis.geometries.IGeometry.has_curve_geometry` of output geometry is .'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : aspose.gis.AbstractPath, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : str, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> io.RawIOBase:
        '''Export this geometry to an image representation.
        
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.
        :returns: The image as stream'''
        raise NotImplementedError()
    
    @overload
    def as_text(self) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant, format : aspose.gis.NumericFormat) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :param format: Coordinate format for conversion to string. See the :py:class:`aspose.gis.NumericFormat` to get it.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self, variant : aspose.gis.geometries.WkbVariant) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :param variant: Well-Known Binary variant to use.
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def within(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry is within a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry is within extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def within(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is within a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially within" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry intersects a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry intersects the extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry intersects.
        
        :param other: A geometry.
        :returns: if this geometry "spatially intersects" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def to_editable(self) -> aspose.gis.geometries.Geometry:
        '''Gets an editable copy of this geometry.
        
        :returns: An editable copy of this geometry.'''
        raise NotImplementedError()
    
    def replace_polygons_by_lines(self) -> aspose.gis.geometries.IGeometry:
        '''Gets polygons represented as lines of this geometry.
        
        :returns: A geometry, that has no polygon geometries. The following transformation are applied:
        
        *
        
        *'''
        raise NotImplementedError()
    
    def to_svg(self, extent : aspose.gis.Extent) -> str:
        '''Translates this geometry to Svg representation.
        
        :param extent: Extent for translation this geometry to Svg
        :returns: The Svg representation.'''
        raise NotImplementedError()
    
    def set_empty(self) -> None:
        '''Makes this :py:class:`aspose.gis.geometries.Geometry` empty.'''
        raise NotImplementedError()
    
    def clone(self) -> aspose.gis.geometries.Geometry:
        '''Clones this instance.
        
        :returns: The clone of this instance'''
        raise NotImplementedError()
    
    def round_xy(self, digits : int) -> None:
        '''Rounds X and Y coordinates to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def round_z(self, digits : int) -> None:
        '''Rounds Z coordinate to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def round_m(self, digits : int) -> None:
        '''Rounds M coordinate to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def get_extent(self) -> aspose.gis.Extent:
        '''Computes and returns a bounding extent of this geometry.
        
        :returns: A bounding extent of this geometry.'''
        raise NotImplementedError()
    
    def get_area(self) -> float:
        '''Computes the area of this geometry.
        
        :returns: The area of this geometry.
        Sum of areas of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_length(self) -> float:
        '''Computes the length of this geometry.
        
        :returns: The length of this geometry.
        Perimeter if this is a :py:class:`aspose.gis.geometries.Polygon`.
        Sum of lengths of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_distance_to(self, other : aspose.gis.geometries.IGeometry) -> float:
        '''Computes the minimum distance between this geometry and a specified geometry.
        
        :param other: A geometry to find distance to.
        :returns: If both geometries are not :py:attr:`aspose.gis.geometries.Geometry.is_empty` - a distance between closest points of the geometries.
        If at least one geometry is empty -1 is returned.'''
        raise NotImplementedError()
    
    def get_convex_hull(self) -> aspose.gis.geometries.IGeometry:
        '''Computes the convex hull of this geometry.
        
        :returns: A geometry that represents a convex hull of this geometry.
        If this geometry has no points then the result is :py:attr:`aspose.gis.geometries.Geometry.null`.
        If this geometry has only one point then the result is this point.
        If this geometry has only two points then the result is :py:class:`aspose.gis.geometries.ILineString` with the points.
        If this geometry has three or more points then the result is :py:class:`aspose.gis.geometries.ILinearRing` that represents a convex
        hull around all geometries points.'''
        raise NotImplementedError()
    
    def get_centroid(self) -> aspose.gis.geometries.IPoint:
        '''Computes the centroid of this geometry.
        
        :returns: The centroid of this geometry. If this geometry is empty an empty point returned.
        The centroid is equal to the centroid of the highest dimension geometries in this geometry
        (e.g. if both points and lines are contained in the geometry, only lines contribute to centroid).'''
        raise NotImplementedError()
    
    def get_buffer(self, distance : float, quadrant_segments : int) -> aspose.gis.geometries.IGeometry:
        '''Computes a buffer region around this geometry.
        
        :param distance: The buffer region width.
        :param quadrant_segments: Number of segments used to approximate a 90 degree of curvature.
        The larger this number is the better approximation of curves is produced.
        Default is 30.
        :returns: A geometry that represents all points that are within a specified distance from
        this geometry.
        The type of result is either :py:attr:`aspose.gis.geometries.Geometry.null`, :py:class:`aspose.gis.geometries.IPolygon` or :py:class:`aspose.gis.geometries.IMultiPolygon`.'''
        raise NotImplementedError()
    
    def spatially_equals(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry spatially equal to a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry "spatially equals" to specified geometry.  otherwise.'''
        raise NotImplementedError()
    
    def disjoint(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry is disjoint from a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially disjoint" from another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def touches(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry touch.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially touches" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def crosses(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry cross.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially crosses" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def spatially_contains(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry spatially contains a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially contains" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def overlaps(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry overlap with a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially overlaps" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covers(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry covers a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covers" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covered_by(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is covered by a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covered by" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def relate(self, other : aspose.gis.geometries.IGeometry, intersection_pattern_matrix : str) -> bool:
        '''Determines if DE-9IM intersection matrix of this geometry and a specified geometry matches provided pattern.
        
        :param other: A geometry.
        :param intersection_pattern_matrix: A patter to match with.
        This should be a string with length equal to 9.
        Each character of the string represent expected dimension of an intersection:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        Possible values of each characters are:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        For example, an intersection pattern "F0*******" means, that there should not be intersection between geometries interiors
        and intersection between geometries boundaries must be a point.
        See OpenGIS Simple Features Specification for more details about intersection matrix pattern.
        :returns: if this intersection matrix matches patter;  otherwise.'''
        raise NotImplementedError()
    
    def intersection(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds an intersection between this geometry and a specified geometry.
        
        :param other: A geometry to compute intersection with.
        :returns: A geometry that represents an intersection of this geometry and an argument. The result geometry contain
        point set that present in both this geometry and an argument.'''
        raise NotImplementedError()
    
    def union(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Unites this geometry and a specified geometry.
        
        :param other: A geometry to unite with.
        :returns: A geometry that represents a union of this geometry and an argument. The result geometry contains
        point set that present in this geometry or in an argument.'''
        raise NotImplementedError()
    
    def difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Subtracts a specified geometry from this geometry.
        
        :param other: A geometry to subtract.
        :returns: A geometry that represents a difference of this geometry and an argument. The result geometry contains
        point set that present in this geometry but not present in an argument.'''
        raise NotImplementedError()
    
    def sym_difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds a symmetric difference between this geometry and a specified geometry.
        
        :param other: A geometry to compute symmetric difference with.
        :returns: A geometry that represents a symmetric difference of this geometry and an argument. The result geometry contains
        point set that present in one of the geometries but not present in both of them.'''
        raise NotImplementedError()
    
    @property
    def dimension(self) -> aspose.gis.geometries.GeometryDimension:
        '''Gets the topological dimension of this :py:class:`aspose.gis.geometries.Geometry`.
        If the dimension is unknown (e.g. for an empty GEOMETRYCOLLECTION) :py:attr:`aspose.gis.geometries.GeometryDimension.POINT` is returned.'''
        raise NotImplementedError()
    
    null : aspose.gis.geometries.IGeometry
    '''Gets an instance of null geometry.'''
    @property
    def coordinate_dimension(self) -> int:
        '''Gets the number of coordinate dimensions for this :py:class:`aspose.gis.geometries.Geometry`.'''
        raise NotImplementedError()
    
    @property
    def is_empty(self) -> bool:
        '''Gets a value indicating whether this instance is empty.'''
        raise NotImplementedError()
    
    @property
    def is_simple(self) -> bool:
        '''Gets a value indicating whether this instance is simple from SFA point of view.'''
        raise NotImplementedError()
    
    @property
    def is_valid(self) -> bool:
        '''Gets a value indicating whether this instance is valid.'''
        raise NotImplementedError()
    
    @property
    def has_m(self) -> bool:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @has_m.setter
    def has_m(self, value : bool) -> None:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_z(self) -> bool:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @has_z.setter
    def has_z(self, value : bool) -> None:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_curve_geometry(self) -> bool:
        '''Gets a value indicating whether this geometry is or contains curve (not linear) geometry.'''
        raise NotImplementedError()
    
    @property
    def geometry_type(self) -> aspose.gis.geometries.GeometryType:
        '''Gets the type of the geometry.'''
        raise NotImplementedError()
    
    @property
    def spatial_reference_system(self) -> aspose.gis.spatialreferencing.SpatialReferenceSystem:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , is SpatialReferenceSystem is unknown.
        Assigning new SpatialReferenceSystem will not perform any coordinate transformation, only reference will change.'''
        raise NotImplementedError()
    
    @spatial_reference_system.setter
    def spatial_reference_system(self, value : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> None:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , is SpatialReferenceSystem is unknown.
        Assigning new SpatialReferenceSystem will not perform any coordinate transformation, only reference will change.'''
        raise NotImplementedError()
    

class GeometryCollection(Geometry):
    '''A :py:class:`aspose.gis.geometries.GeometryCollection` is a :py:class:`aspose.gis.geometries.Geometry` that is a collection of one or more geometries.'''
    
    @overload
    @staticmethod
    def from_text(wkt : str) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Text representation.
        
        :param wkt: Well-Known Text representation of a geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_text(wkt : str, spatial_reference_system : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Text representation.
        
        :param wkt: Well-Known Text representation of a geometry.
        :param spatial_reference_system: Spatial Reference System to be assigned to the geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_binary(wkb : List[int]) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Binary representation.
        
        :param wkb: Well-Known Binary representation of a geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_binary(wkb : List[int], spatial_reference_system : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Binary representation.
        
        :param wkb: Well-Known Binary representation of a geometry.
        :param spatial_reference_system: Spatial Reference System to be assigned to the geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self) -> aspose.gis.geometries.IGeometryCollection:
        '''Gets approximate or equivalent non-curve version of this geometry using the default ``tolerance``.
        
        :returns: A geometry, that has no curve geometries. This is the equivalent of :py:func:`aspose.gis.geometries.IGeometryCollection.to_linear_geometry` with
        default ``tolerance``. Default ``tolerance``s value is dependent on :py:class:`aspose.gis.spatialreferencing.SpatialReferenceSystem`
        of this geometry:
        
        *
        
        *
        
        *
        
        For more details on what transformations are applied refer to :py:func:`aspose.gis.geometries.IGeometryCollection.to_linear_geometry` specification.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self, tolerance : float) -> aspose.gis.geometries.IGeometryCollection:
        '''Gets approximate or equivalent non-curve version of this geometry using the specified ``tolerance``.
        
        :param tolerance: The ``tolerance`` to use. The result is guaranteed to be less than ``tolerance`` away from the
        curved geometry.
        :returns: A geometry, that has no curve geometries. The following transformations are applied:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        As a result, :py:attr:`aspose.gis.geometries.IGeometry.has_curve_geometry` of output geometry is .'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : aspose.gis.AbstractPath, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : str, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> io.RawIOBase:
        '''Export this geometry to an image representation.
        
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.
        :returns: The image as stream'''
        raise NotImplementedError()
    
    @overload
    def as_text(self) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant, format : aspose.gis.NumericFormat) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :param format: Coordinate format for conversion to string. See the :py:class:`aspose.gis.NumericFormat` to get it.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self, variant : aspose.gis.geometries.WkbVariant) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :param variant: Well-Known Binary variant to use.
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def within(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry is within a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry is within extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def within(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is within a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially within" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry intersects a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry intersects the extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry intersects.
        
        :param other: A geometry.
        :returns: if this geometry "spatially intersects" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def to_editable(self) -> aspose.gis.geometries.GeometryCollection:
        '''Gets an editable copy of this geometry.
        
        :returns: An editable copy of this geometry.'''
        raise NotImplementedError()
    
    def replace_polygons_by_lines(self) -> aspose.gis.geometries.IGeometryCollection:
        '''Gets polygons represented as lines of this geometry.
        
        :returns: A geometry, that has no polygon geometries. The following transformation are applied:
        
        *
        
        *'''
        raise NotImplementedError()
    
    def to_svg(self, extent : aspose.gis.Extent) -> str:
        '''Translates this geometry to Svg representation.
        
        :param extent: Extent for translation this geometry to Svg
        :returns: The Svg representation.'''
        raise NotImplementedError()
    
    def set_empty(self) -> None:
        '''Makes this :py:class:`aspose.gis.geometries.Geometry` empty.'''
        raise NotImplementedError()
    
    def clone(self) -> aspose.gis.geometries.Geometry:
        '''Clones this instance.
        
        :returns: The clone of this instance'''
        raise NotImplementedError()
    
    def round_xy(self, digits : int) -> None:
        '''Rounds X and Y coordinates to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def round_z(self, digits : int) -> None:
        '''Rounds Z coordinate to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def round_m(self, digits : int) -> None:
        '''Rounds M coordinate to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def get_extent(self) -> aspose.gis.Extent:
        '''Computes and returns a bounding extent of this geometry.
        
        :returns: A bounding extent of this geometry.'''
        raise NotImplementedError()
    
    def get_area(self) -> float:
        '''Computes the area of this geometry.
        
        :returns: The area of this geometry.
        Sum of areas of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_length(self) -> float:
        '''Computes the length of this geometry.
        
        :returns: The length of this geometry.
        Perimeter if this is a :py:class:`aspose.gis.geometries.Polygon`.
        Sum of lengths of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_distance_to(self, other : aspose.gis.geometries.IGeometry) -> float:
        '''Computes the minimum distance between this geometry and a specified geometry.
        
        :param other: A geometry to find distance to.
        :returns: If both geometries are not :py:attr:`aspose.gis.geometries.Geometry.is_empty` - a distance between closest points of the geometries.
        If at least one geometry is empty -1 is returned.'''
        raise NotImplementedError()
    
    def get_convex_hull(self) -> aspose.gis.geometries.IGeometry:
        '''Computes the convex hull of this geometry.
        
        :returns: A geometry that represents a convex hull of this geometry.
        If this geometry has no points then the result is :py:attr:`aspose.gis.geometries.Geometry.null`.
        If this geometry has only one point then the result is this point.
        If this geometry has only two points then the result is :py:class:`aspose.gis.geometries.ILineString` with the points.
        If this geometry has three or more points then the result is :py:class:`aspose.gis.geometries.ILinearRing` that represents a convex
        hull around all geometries points.'''
        raise NotImplementedError()
    
    def get_centroid(self) -> aspose.gis.geometries.IPoint:
        '''Computes the centroid of this geometry.
        
        :returns: The centroid of this geometry. If this geometry is empty an empty point returned.
        The centroid is equal to the centroid of the highest dimension geometries in this geometry
        (e.g. if both points and lines are contained in the geometry, only lines contribute to centroid).'''
        raise NotImplementedError()
    
    def get_buffer(self, distance : float, quadrant_segments : int) -> aspose.gis.geometries.IGeometry:
        '''Computes a buffer region around this geometry.
        
        :param distance: The buffer region width.
        :param quadrant_segments: Number of segments used to approximate a 90 degree of curvature.
        The larger this number is the better approximation of curves is produced.
        Default is 30.
        :returns: A geometry that represents all points that are within a specified distance from
        this geometry.
        The type of result is either :py:attr:`aspose.gis.geometries.Geometry.null`, :py:class:`aspose.gis.geometries.IPolygon` or :py:class:`aspose.gis.geometries.IMultiPolygon`.'''
        raise NotImplementedError()
    
    def spatially_equals(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry spatially equal to a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry "spatially equals" to specified geometry.  otherwise.'''
        raise NotImplementedError()
    
    def disjoint(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry is disjoint from a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially disjoint" from another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def touches(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry touch.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially touches" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def crosses(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry cross.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially crosses" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def spatially_contains(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry spatially contains a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially contains" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def overlaps(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry overlap with a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially overlaps" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covers(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry covers a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covers" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covered_by(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is covered by a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covered by" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def relate(self, other : aspose.gis.geometries.IGeometry, intersection_pattern_matrix : str) -> bool:
        '''Determines if DE-9IM intersection matrix of this geometry and a specified geometry matches provided pattern.
        
        :param other: A geometry.
        :param intersection_pattern_matrix: A patter to match with.
        This should be a string with length equal to 9.
        Each character of the string represent expected dimension of an intersection:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        Possible values of each characters are:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        For example, an intersection pattern "F0*******" means, that there should not be intersection between geometries interiors
        and intersection between geometries boundaries must be a point.
        See OpenGIS Simple Features Specification for more details about intersection matrix pattern.
        :returns: if this intersection matrix matches patter;  otherwise.'''
        raise NotImplementedError()
    
    def intersection(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds an intersection between this geometry and a specified geometry.
        
        :param other: A geometry to compute intersection with.
        :returns: A geometry that represents an intersection of this geometry and an argument. The result geometry contain
        point set that present in both this geometry and an argument.'''
        raise NotImplementedError()
    
    def union(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Unites this geometry and a specified geometry.
        
        :param other: A geometry to unite with.
        :returns: A geometry that represents a union of this geometry and an argument. The result geometry contains
        point set that present in this geometry or in an argument.'''
        raise NotImplementedError()
    
    def difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Subtracts a specified geometry from this geometry.
        
        :param other: A geometry to subtract.
        :returns: A geometry that represents a difference of this geometry and an argument. The result geometry contains
        point set that present in this geometry but not present in an argument.'''
        raise NotImplementedError()
    
    def sym_difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds a symmetric difference between this geometry and a specified geometry.
        
        :param other: A geometry to compute symmetric difference with.
        :returns: A geometry that represents a symmetric difference of this geometry and an argument. The result geometry contains
        point set that present in one of the geometries but not present in both of them.'''
        raise NotImplementedError()
    
    def get_point_on_surface(self) -> aspose.gis.geometries.IPoint:
        '''Finds a point that is guaranteed to be on one of the surfaces in this collection.
        
        :returns: A point on one of the surfaces. An empty point if this collection does not contain surfaces or all surfaces are empty.'''
        raise NotImplementedError()
    
    def add(self, geometry : aspose.gis.geometries.IGeometry) -> None:
        '''Adds the specified geometry to the collection.
        
        :param geometry: The geometry to add.'''
        raise NotImplementedError()
    
    def add_range(self, geometries : Iterable[aspose.gis.geometries.IGeometry]) -> None:
        raise NotImplementedError()
    
    def remove_at(self, index : int) -> None:
        '''Removes the specified geometry from the collection.
        
        :param index: Index of the geometry to remove.'''
        raise NotImplementedError()
    
    def equals(self, other : aspose.gis.geometries.IGeometryCollection) -> bool:
        '''Indicates whether the current object is equal to another object of the same type.
        
        :param other: An object to compare with this object.
        :returns: true if the current object is equal to the ``other`` parameter; otherwise, false.'''
        raise NotImplementedError()
    
    @property
    def dimension(self) -> aspose.gis.geometries.GeometryDimension:
        '''Gets the topological dimension of this :py:class:`aspose.gis.geometries.Geometry`.
        If collection is Empty, :py:attr:`aspose.gis.geometries.GeometryDimension.POINT` is returned.'''
        raise NotImplementedError()
    
    null : aspose.gis.geometries.IGeometry
    '''Gets an instance of null geometry.'''
    @property
    def coordinate_dimension(self) -> int:
        '''Gets the number of coordinate dimensions for this :py:class:`aspose.gis.geometries.Geometry`.'''
        raise NotImplementedError()
    
    @property
    def is_empty(self) -> bool:
        '''Gets a value indicating whether this instance is empty.'''
        raise NotImplementedError()
    
    @property
    def is_simple(self) -> bool:
        '''Gets a value indicating whether this instance is simple from SFA point of view.'''
        raise NotImplementedError()
    
    @property
    def is_valid(self) -> bool:
        '''Gets a value indicating whether this instance is valid.'''
        raise NotImplementedError()
    
    @property
    def has_m(self) -> bool:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @has_m.setter
    def has_m(self, value : bool) -> None:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_z(self) -> bool:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @has_z.setter
    def has_z(self, value : bool) -> None:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_curve_geometry(self) -> bool:
        '''Gets a value indicating whether this geometry is or contains curve (not linear) geometry.'''
        raise NotImplementedError()
    
    @property
    def geometry_type(self) -> aspose.gis.geometries.GeometryType:
        '''Gets the type of the geometry.'''
        raise NotImplementedError()
    
    @property
    def spatial_reference_system(self) -> aspose.gis.spatialreferencing.SpatialReferenceSystem:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , is SpatialReferenceSystem is unknown.
        Assigning new SpatialReferenceSystem will not perform any coordinate transformation, only reference will change.'''
        raise NotImplementedError()
    
    @spatial_reference_system.setter
    def spatial_reference_system(self, value : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> None:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , is SpatialReferenceSystem is unknown.
        Assigning new SpatialReferenceSystem will not perform any coordinate transformation, only reference will change.'''
        raise NotImplementedError()
    
    @property
    def count(self) -> int:
        '''Gets the number of geometries in this collection.'''
        raise NotImplementedError()
    
    def __getitem__(self, key : int) -> aspose.gis.geometries.IGeometry:
        '''Gets a :py:class:`aspose.gis.geometries.IGeometry` at the specified index.'''
        raise NotImplementedError()
    

class ICircularString(ICurve):
    '''A multi-vertex curve with circular interpolation between points.'''
    
    @overload
    def to_linear_geometry(self) -> aspose.gis.geometries.ILineString:
        '''Gets approximate or equivalent non-curve version of this geometry using the default ``tolerance``.
        
        :returns: A :py:class:`aspose.gis.geometries.ILineString` that approximates or equivalent to this curve.
        This is the equivalent of :py:func:`aspose.gis.geometries.ICurve.to_linear_geometry` with
        default ``tolerance``. Default ``tolerance``s value is dependent on :py:class:`aspose.gis.spatialreferencing.SpatialReferenceSystem`
        of this geometry:
        
        *
        
        *
        
        *
        
        For more details on what transformations are applied refer to :py:func:`aspose.gis.geometries.ICurve.to_linear_geometry` specification.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self, tolerance : float) -> aspose.gis.geometries.ILineString:
        '''Gets approximate or equivalent non-curve version of this geometry using the specified ``tolerance``.
        
        :param tolerance: The ``tolerance`` to use. The result is guaranteed to be less than ``tolerance`` away from the
        curved geometry, unless the number of points needed to linearize the geometry exceeds the per-quadrant maximum,
        currently equal to 10000 points.
        :returns: A :py:class:`aspose.gis.geometries.ILineString` that approximates or equivalent to this curve:
        
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : aspose.gis.AbstractPath, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : str, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> io.RawIOBase:
        '''Export this geometry to an image representation.
        
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.
        :returns: The image as stream'''
        raise NotImplementedError()
    
    @overload
    def as_text(self) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant, format : aspose.gis.NumericFormat) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :param format: Coordinate format for conversion to string. See the :py:class:`aspose.gis.NumericFormat` to get it.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self, variant : aspose.gis.geometries.WkbVariant) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :param variant: Well-Known Binary variant to use.
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def within(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry is within a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry is within extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def within(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is within a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially within" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry intersects a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry intersects the extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry intersects.
        
        :param other: A geometry.
        :returns: if this geometry "spatially intersects" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def to_editable(self) -> aspose.gis.geometries.CircularString:
        '''Gets an editable copy of this geometry.
        
        :returns: An editable copy of this geometry.'''
        raise NotImplementedError()
    
    def replace_polygons_by_lines(self) -> aspose.gis.geometries.IGeometry:
        '''Gets polygons represented as lines of this geometry.
        
        :returns: A geometry, that has no polygon geometries. The following transformation are applied:
        
        *
        
        *'''
        raise NotImplementedError()
    
    def clone(self) -> aspose.gis.geometries.Geometry:
        '''Clones this instance.
        
        :returns: The clone of this instance'''
        raise NotImplementedError()
    
    def get_extent(self) -> aspose.gis.Extent:
        '''Computes and returns a bounding extent of this geometry.
        
        :returns: A bounding extent of this geometry.'''
        raise NotImplementedError()
    
    def get_area(self) -> float:
        '''Computes the area of this geometry.
        
        :returns: The area of this geometry.
        Sum of areas of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_length(self) -> float:
        '''Computes the length of this geometry.
        
        :returns: The length of this geometry.
        Perimeter if this is a :py:class:`aspose.gis.geometries.Polygon`.
        Sum of lengths of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_distance_to(self, other : aspose.gis.geometries.IGeometry) -> float:
        '''Computes the minimum distance between this geometry and a specified geometry.
        
        :param other: A geometry to find distance to.
        :returns: If both geometries are not :py:attr:`aspose.gis.geometries.IGeometry.is_empty` - a distance between closest points of the geometries.
        If at least one geometry is empty -1 is returned.'''
        raise NotImplementedError()
    
    def get_convex_hull(self) -> aspose.gis.geometries.IGeometry:
        '''Computes the convex hull of this geometry.
        
        :returns: A geometry that represents a convex hull of this geometry.
        If this geometry has no points then the result is :py:attr:`aspose.gis.geometries.Geometry.null`.
        If this geometry has only one point then the result is this point.
        If this geometry has only two points then the result is :py:class:`aspose.gis.geometries.ILineString` with the points.
        If this geometry has three or more points then the result is :py:class:`aspose.gis.geometries.ILinearRing` that represents a convex
        hull around all geometries points.'''
        raise NotImplementedError()
    
    def get_centroid(self) -> aspose.gis.geometries.IPoint:
        '''Computes the centroid of this geometry.
        
        :returns: The centroid of this geometry. If this geometry is empty an empty point returned.
        The centroid is equal to the centroid of the highest dimension geometries in this geometry
        (e.g. if both points and lines are contained in the geometry, only lines contribute to centroid).'''
        raise NotImplementedError()
    
    def get_buffer(self, distance : float, quadrant_segments : int) -> aspose.gis.geometries.IGeometry:
        '''Computes a buffer region around this geometry.
        
        :param distance: The buffer region width (in Spatial Reference units).
        :param quadrant_segments: Number of segments used to approximate a 90 degree of curvature.
        The larger this number is the better approximation of curves is produced.
        Default is 30.
        :returns: A geometry that represents all points that are within a specified distance from
        this geometry.
        The type of result is either :py:attr:`aspose.gis.geometries.Geometry.null`, :py:class:`aspose.gis.geometries.IPolygon` or :py:class:`aspose.gis.geometries.IMultiPolygon`.'''
        raise NotImplementedError()
    
    def spatially_equals(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry spatially equal to a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry "spatially equals" to specified geometry.  otherwise.'''
        raise NotImplementedError()
    
    def disjoint(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry is disjoint from a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially disjoint" from another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def touches(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry touch.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially touches" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def crosses(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry cross.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially crosses" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def spatially_contains(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry spatially contains a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially contains" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def overlaps(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry overlap with a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially overlaps" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covers(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry covers a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covers" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covered_by(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is covered by a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covered by" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def relate(self, other : aspose.gis.geometries.IGeometry, intersection_pattern_matrix : str) -> bool:
        '''Determines if DE-9IM intersection matrix of this geometry and a specified geometry matches provided pattern.
        
        :param other: A geometry.
        :param intersection_pattern_matrix: A patter to match with.
        This should be a string with length equal to 9.
        Each character of the string represent expected dimension of an intersection:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        Possible values of each characters are:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        For example, an intersection pattern "F0*******" means, that there should not be intersection between geometries interiors
        and intersection between geometries boundaries must be a point.
        See OpenGIS Simple Features Specification for more details about intersection matrix pattern.
        :returns: if this intersection matrix matches patter;  otherwise.'''
        raise NotImplementedError()
    
    def intersection(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds an intersection between this geometry and a specified geometry.
        
        :param other: A geometry to compute intersection with.
        :returns: A geometry that represents an intersection of this geometry and an argument. The result geometry contain
        point set that present in both this geometry and an argument.'''
        raise NotImplementedError()
    
    def union(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Unites this geometry and a specified geometry.
        
        :param other: A geometry to unite with.
        :returns: A geometry that represents a union of this geometry and an argument. The result geometry contains
        point set that present in this geometry or in an argument.'''
        raise NotImplementedError()
    
    def difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Subtracts a specified geometry from this geometry.
        
        :param other: A geometry to subtract.
        :returns: A geometry that represents a difference of this geometry and an argument. The result geometry contains
        point set that present in this geometry but not present in an argument.'''
        raise NotImplementedError()
    
    def sym_difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds a symmetric difference between this geometry and a specified geometry.
        
        :param other: A geometry to compute symmetric difference with.
        :returns: A geometry that represents a symmetric difference of this geometry and an argument. The result geometry contains
        point set that present in one of the geometries but not present in both of them.'''
        raise NotImplementedError()
    
    @property
    def start_point(self) -> aspose.gis.geometries.IPoint:
        '''Returns a copy of the starting point of the curve.'''
        raise NotImplementedError()
    
    @property
    def end_point(self) -> aspose.gis.geometries.IPoint:
        '''Returns a copy of the end point of the curve.'''
        raise NotImplementedError()
    
    @property
    def is_closed(self) -> bool:
        '''Gets a values indicating whether a curve is closed.
        A curve is closed if its start point is equal to its end point.'''
        raise NotImplementedError()
    
    @property
    def geometry_type(self) -> aspose.gis.geometries.GeometryType:
        '''Gets the type of the geometry.'''
        raise NotImplementedError()
    
    @property
    def dimension(self) -> aspose.gis.geometries.GeometryDimension:
        '''Gets the topological dimension of this :py:class:`aspose.gis.geometries.IGeometry`.
        If the dimension is unknown (e.g. for an empty GEOMETRYCOLLECTION) :py:attr:`aspose.gis.geometries.GeometryDimension.POINT` is returned.'''
        raise NotImplementedError()
    
    @property
    def is_empty(self) -> bool:
        '''Gets a value indicating whether this instance is empty (represents the empty point set).'''
        raise NotImplementedError()
    
    @property
    def is_simple(self) -> bool:
        '''Gets a value indicating whether this instance is simple from SFA point of view.'''
        raise NotImplementedError()
    
    @property
    def is_valid(self) -> bool:
        '''Gets a value indicating whether this instance is valid.'''
        raise NotImplementedError()
    
    @property
    def has_m(self) -> bool:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_z(self) -> bool:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @property
    def spatial_reference_system(self) -> aspose.gis.spatialreferencing.SpatialReferenceSystem:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , if SpatialReferenceSystem is unknown.'''
        raise NotImplementedError()
    
    @property
    def has_curve_geometry(self) -> bool:
        '''Gets a value indicating whether this geometry is or contains curve (not linear) geometry.'''
        raise NotImplementedError()
    

class ICompoundCurve(ICurve):
    '''A curve that represents a sequence of contiguous curves such that adjacent curves are joined at their end points.'''
    
    @overload
    def to_linear_geometry(self) -> aspose.gis.geometries.ILineString:
        '''Gets approximate or equivalent non-curve version of this geometry using the default ``tolerance``.
        
        :returns: A :py:class:`aspose.gis.geometries.ILineString` that approximates or equivalent to this curve.
        This is the equivalent of :py:func:`aspose.gis.geometries.ICurve.to_linear_geometry` with
        default ``tolerance``. Default ``tolerance``s value is dependent on :py:class:`aspose.gis.spatialreferencing.SpatialReferenceSystem`
        of this geometry:
        
        *
        
        *
        
        *
        
        For more details on what transformations are applied refer to :py:func:`aspose.gis.geometries.ICurve.to_linear_geometry` specification.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self, tolerance : float) -> aspose.gis.geometries.ILineString:
        '''Gets approximate or equivalent non-curve version of this geometry using the specified ``tolerance``.
        
        :param tolerance: The ``tolerance`` to use. The result is guaranteed to be less than ``tolerance`` away from the
        curved geometry, unless the number of points needed to linearize the geometry exceeds the per-quadrant maximum,
        currently equal to 10000 points.
        :returns: A :py:class:`aspose.gis.geometries.ILineString` that approximates or equivalent to this curve:
        
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : aspose.gis.AbstractPath, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : str, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> io.RawIOBase:
        '''Export this geometry to an image representation.
        
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.
        :returns: The image as stream'''
        raise NotImplementedError()
    
    @overload
    def as_text(self) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant, format : aspose.gis.NumericFormat) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :param format: Coordinate format for conversion to string. See the :py:class:`aspose.gis.NumericFormat` to get it.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self, variant : aspose.gis.geometries.WkbVariant) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :param variant: Well-Known Binary variant to use.
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def within(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry is within a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry is within extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def within(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is within a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially within" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry intersects a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry intersects the extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry intersects.
        
        :param other: A geometry.
        :returns: if this geometry "spatially intersects" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def to_editable(self) -> aspose.gis.geometries.CompoundCurve:
        '''Gets an editable copy of this geometry.
        
        :returns: An editable copy of this geometry.'''
        raise NotImplementedError()
    
    def replace_polygons_by_lines(self) -> aspose.gis.geometries.IGeometry:
        '''Gets polygons represented as lines of this geometry.
        
        :returns: A geometry, that has no polygon geometries. The following transformation are applied:
        
        *
        
        *'''
        raise NotImplementedError()
    
    def clone(self) -> aspose.gis.geometries.Geometry:
        '''Clones this instance.
        
        :returns: The clone of this instance'''
        raise NotImplementedError()
    
    def get_extent(self) -> aspose.gis.Extent:
        '''Computes and returns a bounding extent of this geometry.
        
        :returns: A bounding extent of this geometry.'''
        raise NotImplementedError()
    
    def get_area(self) -> float:
        '''Computes the area of this geometry.
        
        :returns: The area of this geometry.
        Sum of areas of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_length(self) -> float:
        '''Computes the length of this geometry.
        
        :returns: The length of this geometry.
        Perimeter if this is a :py:class:`aspose.gis.geometries.Polygon`.
        Sum of lengths of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_distance_to(self, other : aspose.gis.geometries.IGeometry) -> float:
        '''Computes the minimum distance between this geometry and a specified geometry.
        
        :param other: A geometry to find distance to.
        :returns: If both geometries are not :py:attr:`aspose.gis.geometries.IGeometry.is_empty` - a distance between closest points of the geometries.
        If at least one geometry is empty -1 is returned.'''
        raise NotImplementedError()
    
    def get_convex_hull(self) -> aspose.gis.geometries.IGeometry:
        '''Computes the convex hull of this geometry.
        
        :returns: A geometry that represents a convex hull of this geometry.
        If this geometry has no points then the result is :py:attr:`aspose.gis.geometries.Geometry.null`.
        If this geometry has only one point then the result is this point.
        If this geometry has only two points then the result is :py:class:`aspose.gis.geometries.ILineString` with the points.
        If this geometry has three or more points then the result is :py:class:`aspose.gis.geometries.ILinearRing` that represents a convex
        hull around all geometries points.'''
        raise NotImplementedError()
    
    def get_centroid(self) -> aspose.gis.geometries.IPoint:
        '''Computes the centroid of this geometry.
        
        :returns: The centroid of this geometry. If this geometry is empty an empty point returned.
        The centroid is equal to the centroid of the highest dimension geometries in this geometry
        (e.g. if both points and lines are contained in the geometry, only lines contribute to centroid).'''
        raise NotImplementedError()
    
    def get_buffer(self, distance : float, quadrant_segments : int) -> aspose.gis.geometries.IGeometry:
        '''Computes a buffer region around this geometry.
        
        :param distance: The buffer region width (in Spatial Reference units).
        :param quadrant_segments: Number of segments used to approximate a 90 degree of curvature.
        The larger this number is the better approximation of curves is produced.
        Default is 30.
        :returns: A geometry that represents all points that are within a specified distance from
        this geometry.
        The type of result is either :py:attr:`aspose.gis.geometries.Geometry.null`, :py:class:`aspose.gis.geometries.IPolygon` or :py:class:`aspose.gis.geometries.IMultiPolygon`.'''
        raise NotImplementedError()
    
    def spatially_equals(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry spatially equal to a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry "spatially equals" to specified geometry.  otherwise.'''
        raise NotImplementedError()
    
    def disjoint(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry is disjoint from a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially disjoint" from another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def touches(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry touch.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially touches" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def crosses(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry cross.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially crosses" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def spatially_contains(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry spatially contains a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially contains" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def overlaps(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry overlap with a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially overlaps" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covers(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry covers a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covers" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covered_by(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is covered by a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covered by" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def relate(self, other : aspose.gis.geometries.IGeometry, intersection_pattern_matrix : str) -> bool:
        '''Determines if DE-9IM intersection matrix of this geometry and a specified geometry matches provided pattern.
        
        :param other: A geometry.
        :param intersection_pattern_matrix: A patter to match with.
        This should be a string with length equal to 9.
        Each character of the string represent expected dimension of an intersection:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        Possible values of each characters are:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        For example, an intersection pattern "F0*******" means, that there should not be intersection between geometries interiors
        and intersection between geometries boundaries must be a point.
        See OpenGIS Simple Features Specification for more details about intersection matrix pattern.
        :returns: if this intersection matrix matches patter;  otherwise.'''
        raise NotImplementedError()
    
    def intersection(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds an intersection between this geometry and a specified geometry.
        
        :param other: A geometry to compute intersection with.
        :returns: A geometry that represents an intersection of this geometry and an argument. The result geometry contain
        point set that present in both this geometry and an argument.'''
        raise NotImplementedError()
    
    def union(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Unites this geometry and a specified geometry.
        
        :param other: A geometry to unite with.
        :returns: A geometry that represents a union of this geometry and an argument. The result geometry contains
        point set that present in this geometry or in an argument.'''
        raise NotImplementedError()
    
    def difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Subtracts a specified geometry from this geometry.
        
        :param other: A geometry to subtract.
        :returns: A geometry that represents a difference of this geometry and an argument. The result geometry contains
        point set that present in this geometry but not present in an argument.'''
        raise NotImplementedError()
    
    def sym_difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds a symmetric difference between this geometry and a specified geometry.
        
        :param other: A geometry to compute symmetric difference with.
        :returns: A geometry that represents a symmetric difference of this geometry and an argument. The result geometry contains
        point set that present in one of the geometries but not present in both of them.'''
        raise NotImplementedError()
    
    @property
    def count(self) -> int:
        '''Gets the number of curves in the :py:class:`aspose.gis.geometries.ICompoundCurve`.'''
        raise NotImplementedError()
    
    @property
    def start_point(self) -> aspose.gis.geometries.IPoint:
        '''Returns a copy of the starting point of the curve.'''
        raise NotImplementedError()
    
    @property
    def end_point(self) -> aspose.gis.geometries.IPoint:
        '''Returns a copy of the end point of the curve.'''
        raise NotImplementedError()
    
    @property
    def is_closed(self) -> bool:
        '''Gets a values indicating whether a curve is closed.
        A curve is closed if its start point is equal to its end point.'''
        raise NotImplementedError()
    
    @property
    def geometry_type(self) -> aspose.gis.geometries.GeometryType:
        '''Gets the type of the geometry.'''
        raise NotImplementedError()
    
    @property
    def dimension(self) -> aspose.gis.geometries.GeometryDimension:
        '''Gets the topological dimension of this :py:class:`aspose.gis.geometries.IGeometry`.
        If the dimension is unknown (e.g. for an empty GEOMETRYCOLLECTION) :py:attr:`aspose.gis.geometries.GeometryDimension.POINT` is returned.'''
        raise NotImplementedError()
    
    @property
    def is_empty(self) -> bool:
        '''Gets a value indicating whether this instance is empty (represents the empty point set).'''
        raise NotImplementedError()
    
    @property
    def is_simple(self) -> bool:
        '''Gets a value indicating whether this instance is simple from SFA point of view.'''
        raise NotImplementedError()
    
    @property
    def is_valid(self) -> bool:
        '''Gets a value indicating whether this instance is valid.'''
        raise NotImplementedError()
    
    @property
    def has_m(self) -> bool:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_z(self) -> bool:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @property
    def spatial_reference_system(self) -> aspose.gis.spatialreferencing.SpatialReferenceSystem:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , if SpatialReferenceSystem is unknown.'''
        raise NotImplementedError()
    
    @property
    def has_curve_geometry(self) -> bool:
        '''Gets a value indicating whether this geometry is or contains curve (not linear) geometry.'''
        raise NotImplementedError()
    
    def __getitem__(self, key : int) -> aspose.gis.geometries.ICurve:
        '''Gets the :py:class:`aspose.gis.geometries.ICurve` at the specified index.'''
        raise NotImplementedError()
    

class ICurve(IGeometry):
    '''An interface for ICurve type :py:class:`aspose.gis.geometries.ICurve` is a sequence of points.'''
    
    @overload
    def to_linear_geometry(self) -> aspose.gis.geometries.ILineString:
        '''Gets approximate or equivalent non-curve version of this geometry using the default ``tolerance``.
        
        :returns: A :py:class:`aspose.gis.geometries.ILineString` that approximates or equivalent to this curve.
        This is the equivalent of :py:func:`aspose.gis.geometries.ICurve.to_linear_geometry` with
        default ``tolerance``. Default ``tolerance``s value is dependent on :py:class:`aspose.gis.spatialreferencing.SpatialReferenceSystem`
        of this geometry:
        
        *
        
        *
        
        *
        
        For more details on what transformations are applied refer to :py:func:`aspose.gis.geometries.ICurve.to_linear_geometry` specification.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self, tolerance : float) -> aspose.gis.geometries.ILineString:
        '''Gets approximate or equivalent non-curve version of this geometry using the specified ``tolerance``.
        
        :param tolerance: The ``tolerance`` to use. The result is guaranteed to be less than ``tolerance`` away from the
        curved geometry, unless the number of points needed to linearize the geometry exceeds the per-quadrant maximum,
        currently equal to 10000 points.
        :returns: A :py:class:`aspose.gis.geometries.ILineString` that approximates or equivalent to this curve:
        
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : aspose.gis.AbstractPath, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : str, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> io.RawIOBase:
        '''Export this geometry to an image representation.
        
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.
        :returns: The image as stream'''
        raise NotImplementedError()
    
    @overload
    def as_text(self) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant, format : aspose.gis.NumericFormat) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :param format: Coordinate format for conversion to string. See the :py:class:`aspose.gis.NumericFormat` to get it.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self, variant : aspose.gis.geometries.WkbVariant) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :param variant: Well-Known Binary variant to use.
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def within(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry is within a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry is within extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def within(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is within a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially within" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry intersects a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry intersects the extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry intersects.
        
        :param other: A geometry.
        :returns: if this geometry "spatially intersects" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def to_editable(self) -> aspose.gis.geometries.Curve:
        '''Gets an editable copy of this geometry.
        
        :returns: An editable copy of this geometry.'''
        raise NotImplementedError()
    
    def replace_polygons_by_lines(self) -> aspose.gis.geometries.IGeometry:
        '''Gets polygons represented as lines of this geometry.
        
        :returns: A geometry, that has no polygon geometries. The following transformation are applied:
        
        *
        
        *'''
        raise NotImplementedError()
    
    def clone(self) -> aspose.gis.geometries.Geometry:
        '''Clones this instance.
        
        :returns: The clone of this instance'''
        raise NotImplementedError()
    
    def get_extent(self) -> aspose.gis.Extent:
        '''Computes and returns a bounding extent of this geometry.
        
        :returns: A bounding extent of this geometry.'''
        raise NotImplementedError()
    
    def get_area(self) -> float:
        '''Computes the area of this geometry.
        
        :returns: The area of this geometry.
        Sum of areas of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_length(self) -> float:
        '''Computes the length of this geometry.
        
        :returns: The length of this geometry.
        Perimeter if this is a :py:class:`aspose.gis.geometries.Polygon`.
        Sum of lengths of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_distance_to(self, other : aspose.gis.geometries.IGeometry) -> float:
        '''Computes the minimum distance between this geometry and a specified geometry.
        
        :param other: A geometry to find distance to.
        :returns: If both geometries are not :py:attr:`aspose.gis.geometries.IGeometry.is_empty` - a distance between closest points of the geometries.
        If at least one geometry is empty -1 is returned.'''
        raise NotImplementedError()
    
    def get_convex_hull(self) -> aspose.gis.geometries.IGeometry:
        '''Computes the convex hull of this geometry.
        
        :returns: A geometry that represents a convex hull of this geometry.
        If this geometry has no points then the result is :py:attr:`aspose.gis.geometries.Geometry.null`.
        If this geometry has only one point then the result is this point.
        If this geometry has only two points then the result is :py:class:`aspose.gis.geometries.ILineString` with the points.
        If this geometry has three or more points then the result is :py:class:`aspose.gis.geometries.ILinearRing` that represents a convex
        hull around all geometries points.'''
        raise NotImplementedError()
    
    def get_centroid(self) -> aspose.gis.geometries.IPoint:
        '''Computes the centroid of this geometry.
        
        :returns: The centroid of this geometry. If this geometry is empty an empty point returned.
        The centroid is equal to the centroid of the highest dimension geometries in this geometry
        (e.g. if both points and lines are contained in the geometry, only lines contribute to centroid).'''
        raise NotImplementedError()
    
    def get_buffer(self, distance : float, quadrant_segments : int) -> aspose.gis.geometries.IGeometry:
        '''Computes a buffer region around this geometry.
        
        :param distance: The buffer region width (in Spatial Reference units).
        :param quadrant_segments: Number of segments used to approximate a 90 degree of curvature.
        The larger this number is the better approximation of curves is produced.
        Default is 30.
        :returns: A geometry that represents all points that are within a specified distance from
        this geometry.
        The type of result is either :py:attr:`aspose.gis.geometries.Geometry.null`, :py:class:`aspose.gis.geometries.IPolygon` or :py:class:`aspose.gis.geometries.IMultiPolygon`.'''
        raise NotImplementedError()
    
    def spatially_equals(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry spatially equal to a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry "spatially equals" to specified geometry.  otherwise.'''
        raise NotImplementedError()
    
    def disjoint(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry is disjoint from a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially disjoint" from another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def touches(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry touch.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially touches" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def crosses(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry cross.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially crosses" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def spatially_contains(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry spatially contains a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially contains" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def overlaps(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry overlap with a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially overlaps" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covers(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry covers a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covers" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covered_by(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is covered by a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covered by" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def relate(self, other : aspose.gis.geometries.IGeometry, intersection_pattern_matrix : str) -> bool:
        '''Determines if DE-9IM intersection matrix of this geometry and a specified geometry matches provided pattern.
        
        :param other: A geometry.
        :param intersection_pattern_matrix: A patter to match with.
        This should be a string with length equal to 9.
        Each character of the string represent expected dimension of an intersection:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        Possible values of each characters are:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        For example, an intersection pattern "F0*******" means, that there should not be intersection between geometries interiors
        and intersection between geometries boundaries must be a point.
        See OpenGIS Simple Features Specification for more details about intersection matrix pattern.
        :returns: if this intersection matrix matches patter;  otherwise.'''
        raise NotImplementedError()
    
    def intersection(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds an intersection between this geometry and a specified geometry.
        
        :param other: A geometry to compute intersection with.
        :returns: A geometry that represents an intersection of this geometry and an argument. The result geometry contain
        point set that present in both this geometry and an argument.'''
        raise NotImplementedError()
    
    def union(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Unites this geometry and a specified geometry.
        
        :param other: A geometry to unite with.
        :returns: A geometry that represents a union of this geometry and an argument. The result geometry contains
        point set that present in this geometry or in an argument.'''
        raise NotImplementedError()
    
    def difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Subtracts a specified geometry from this geometry.
        
        :param other: A geometry to subtract.
        :returns: A geometry that represents a difference of this geometry and an argument. The result geometry contains
        point set that present in this geometry but not present in an argument.'''
        raise NotImplementedError()
    
    def sym_difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds a symmetric difference between this geometry and a specified geometry.
        
        :param other: A geometry to compute symmetric difference with.
        :returns: A geometry that represents a symmetric difference of this geometry and an argument. The result geometry contains
        point set that present in one of the geometries but not present in both of them.'''
        raise NotImplementedError()
    
    @property
    def start_point(self) -> aspose.gis.geometries.IPoint:
        '''Returns a copy of the starting point of the curve.'''
        raise NotImplementedError()
    
    @property
    def end_point(self) -> aspose.gis.geometries.IPoint:
        '''Returns a copy of the end point of the curve.'''
        raise NotImplementedError()
    
    @property
    def is_closed(self) -> bool:
        '''Gets a values indicating whether a curve is closed.
        A curve is closed if its start point is equal to its end point.'''
        raise NotImplementedError()
    
    @property
    def geometry_type(self) -> aspose.gis.geometries.GeometryType:
        '''Gets the type of the geometry.'''
        raise NotImplementedError()
    
    @property
    def dimension(self) -> aspose.gis.geometries.GeometryDimension:
        '''Gets the topological dimension of this :py:class:`aspose.gis.geometries.IGeometry`.
        If the dimension is unknown (e.g. for an empty GEOMETRYCOLLECTION) :py:attr:`aspose.gis.geometries.GeometryDimension.POINT` is returned.'''
        raise NotImplementedError()
    
    @property
    def is_empty(self) -> bool:
        '''Gets a value indicating whether this instance is empty (represents the empty point set).'''
        raise NotImplementedError()
    
    @property
    def is_simple(self) -> bool:
        '''Gets a value indicating whether this instance is simple from SFA point of view.'''
        raise NotImplementedError()
    
    @property
    def is_valid(self) -> bool:
        '''Gets a value indicating whether this instance is valid.'''
        raise NotImplementedError()
    
    @property
    def has_m(self) -> bool:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_z(self) -> bool:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @property
    def spatial_reference_system(self) -> aspose.gis.spatialreferencing.SpatialReferenceSystem:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , if SpatialReferenceSystem is unknown.'''
        raise NotImplementedError()
    
    @property
    def has_curve_geometry(self) -> bool:
        '''Gets a value indicating whether this geometry is or contains curve (not linear) geometry.'''
        raise NotImplementedError()
    

class ICurvePolygon(ISurface):
    '''A planar surface, defined by 1 exterior boundary and 0 or more interior boundaries.'''
    
    @overload
    def to_linear_geometry(self) -> aspose.gis.geometries.IPolygon:
        '''Gets approximate or equivalent non-curve version of this geometry using the default ``tolerance``.
        
        :returns: A :py:class:`aspose.gis.geometries.IPolygon` that approximates or equivalent to this ``ISurface``.
        This is the equivalent of :py:func:`aspose.gis.geometries.ISurface.to_linear_geometry` with
        default ``tolerance``. Default ``tolerance``s value is dependent on :py:class:`aspose.gis.spatialreferencing.SpatialReferenceSystem`
        of this geometry:
        
        *
        
        *
        
        *
        
        For more details on what transformations are applied refer to :py:func:`aspose.gis.geometries.ISurface.to_linear_geometry` specification.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self, tolerance : float) -> aspose.gis.geometries.IPolygon:
        '''Gets approximate or equivalent non-curve version of this geometry using the specified ``tolerance``.
        
        :param tolerance: The ``tolerance`` to use. The result is guaranteed to be less than ``tolerance`` away from the
        curved geometry, unless the number of points needed to linearize the geometry exceeds the per-quadrant maximum,
        currently equal to 10000 points.
        :returns: A :py:class:`aspose.gis.geometries.IPolygon` that approximates or equivalent to this ``ISurface``:
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : aspose.gis.AbstractPath, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : str, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> io.RawIOBase:
        '''Export this geometry to an image representation.
        
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.
        :returns: The image as stream'''
        raise NotImplementedError()
    
    @overload
    def as_text(self) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant, format : aspose.gis.NumericFormat) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :param format: Coordinate format for conversion to string. See the :py:class:`aspose.gis.NumericFormat` to get it.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self, variant : aspose.gis.geometries.WkbVariant) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :param variant: Well-Known Binary variant to use.
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def within(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry is within a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry is within extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def within(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is within a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially within" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry intersects a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry intersects the extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry intersects.
        
        :param other: A geometry.
        :returns: if this geometry "spatially intersects" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def get_interior_ring(self, index : int) -> aspose.gis.geometries.ICurve:
        '''Gets the interior ring by its index.
        
        :param index: The index.
        :returns: The interior ring value'''
        raise NotImplementedError()
    
    def get_point_on_surface(self) -> aspose.gis.geometries.IPoint:
        '''Finds a point that is guaranteed to be on this surface.
        
        :returns: A point on this surface. An empty point if this surface has no interior.'''
        raise NotImplementedError()
    
    def to_editable(self) -> aspose.gis.geometries.Surface:
        '''Gets an editable copy of this geometry.
        
        :returns: An editable copy of this geometry.'''
        raise NotImplementedError()
    
    def replace_polygons_by_lines(self) -> aspose.gis.geometries.IGeometry:
        '''Gets polygons represented as lines of this geometry.
        
        :returns: A geometry, that has no polygon geometries. The following transformation are applied:
        
        *
        
        *'''
        raise NotImplementedError()
    
    def clone(self) -> aspose.gis.geometries.Geometry:
        '''Clones this instance.
        
        :returns: The clone of this instance'''
        raise NotImplementedError()
    
    def get_extent(self) -> aspose.gis.Extent:
        '''Computes and returns a bounding extent of this geometry.
        
        :returns: A bounding extent of this geometry.'''
        raise NotImplementedError()
    
    def get_area(self) -> float:
        '''Computes the area of this geometry.
        
        :returns: The area of this geometry.
        Sum of areas of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_length(self) -> float:
        '''Computes the length of this geometry.
        
        :returns: The length of this geometry.
        Perimeter if this is a :py:class:`aspose.gis.geometries.Polygon`.
        Sum of lengths of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_distance_to(self, other : aspose.gis.geometries.IGeometry) -> float:
        '''Computes the minimum distance between this geometry and a specified geometry.
        
        :param other: A geometry to find distance to.
        :returns: If both geometries are not :py:attr:`aspose.gis.geometries.IGeometry.is_empty` - a distance between closest points of the geometries.
        If at least one geometry is empty -1 is returned.'''
        raise NotImplementedError()
    
    def get_convex_hull(self) -> aspose.gis.geometries.IGeometry:
        '''Computes the convex hull of this geometry.
        
        :returns: A geometry that represents a convex hull of this geometry.
        If this geometry has no points then the result is :py:attr:`aspose.gis.geometries.Geometry.null`.
        If this geometry has only one point then the result is this point.
        If this geometry has only two points then the result is :py:class:`aspose.gis.geometries.ILineString` with the points.
        If this geometry has three or more points then the result is :py:class:`aspose.gis.geometries.ILinearRing` that represents a convex
        hull around all geometries points.'''
        raise NotImplementedError()
    
    def get_centroid(self) -> aspose.gis.geometries.IPoint:
        '''Computes the centroid of this geometry.
        
        :returns: The centroid of this geometry. If this geometry is empty an empty point returned.
        The centroid is equal to the centroid of the highest dimension geometries in this geometry
        (e.g. if both points and lines are contained in the geometry, only lines contribute to centroid).'''
        raise NotImplementedError()
    
    def get_buffer(self, distance : float, quadrant_segments : int) -> aspose.gis.geometries.IGeometry:
        '''Computes a buffer region around this geometry.
        
        :param distance: The buffer region width (in Spatial Reference units).
        :param quadrant_segments: Number of segments used to approximate a 90 degree of curvature.
        The larger this number is the better approximation of curves is produced.
        Default is 30.
        :returns: A geometry that represents all points that are within a specified distance from
        this geometry.
        The type of result is either :py:attr:`aspose.gis.geometries.Geometry.null`, :py:class:`aspose.gis.geometries.IPolygon` or :py:class:`aspose.gis.geometries.IMultiPolygon`.'''
        raise NotImplementedError()
    
    def spatially_equals(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry spatially equal to a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry "spatially equals" to specified geometry.  otherwise.'''
        raise NotImplementedError()
    
    def disjoint(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry is disjoint from a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially disjoint" from another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def touches(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry touch.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially touches" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def crosses(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry cross.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially crosses" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def spatially_contains(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry spatially contains a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially contains" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def overlaps(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry overlap with a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially overlaps" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covers(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry covers a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covers" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covered_by(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is covered by a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covered by" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def relate(self, other : aspose.gis.geometries.IGeometry, intersection_pattern_matrix : str) -> bool:
        '''Determines if DE-9IM intersection matrix of this geometry and a specified geometry matches provided pattern.
        
        :param other: A geometry.
        :param intersection_pattern_matrix: A patter to match with.
        This should be a string with length equal to 9.
        Each character of the string represent expected dimension of an intersection:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        Possible values of each characters are:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        For example, an intersection pattern "F0*******" means, that there should not be intersection between geometries interiors
        and intersection between geometries boundaries must be a point.
        See OpenGIS Simple Features Specification for more details about intersection matrix pattern.
        :returns: if this intersection matrix matches patter;  otherwise.'''
        raise NotImplementedError()
    
    def intersection(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds an intersection between this geometry and a specified geometry.
        
        :param other: A geometry to compute intersection with.
        :returns: A geometry that represents an intersection of this geometry and an argument. The result geometry contain
        point set that present in both this geometry and an argument.'''
        raise NotImplementedError()
    
    def union(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Unites this geometry and a specified geometry.
        
        :param other: A geometry to unite with.
        :returns: A geometry that represents a union of this geometry and an argument. The result geometry contains
        point set that present in this geometry or in an argument.'''
        raise NotImplementedError()
    
    def difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Subtracts a specified geometry from this geometry.
        
        :param other: A geometry to subtract.
        :returns: A geometry that represents a difference of this geometry and an argument. The result geometry contains
        point set that present in this geometry but not present in an argument.'''
        raise NotImplementedError()
    
    def sym_difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds a symmetric difference between this geometry and a specified geometry.
        
        :param other: A geometry to compute symmetric difference with.
        :returns: A geometry that represents a symmetric difference of this geometry and an argument. The result geometry contains
        point set that present in one of the geometries but not present in both of them.'''
        raise NotImplementedError()
    
    @property
    def exterior_ring(self) -> aspose.gis.geometries.ICurve:
        '''Gets the exterior ring.'''
        raise NotImplementedError()
    
    @property
    def interior_rings_count(self) -> int:
        '''Gets the number of interior rings.'''
        raise NotImplementedError()
    
    @property
    def geometry_type(self) -> aspose.gis.geometries.GeometryType:
        '''Gets the type of the geometry.'''
        raise NotImplementedError()
    
    @property
    def dimension(self) -> aspose.gis.geometries.GeometryDimension:
        '''Gets the topological dimension of this :py:class:`aspose.gis.geometries.IGeometry`.
        If the dimension is unknown (e.g. for an empty GEOMETRYCOLLECTION) :py:attr:`aspose.gis.geometries.GeometryDimension.POINT` is returned.'''
        raise NotImplementedError()
    
    @property
    def is_empty(self) -> bool:
        '''Gets a value indicating whether this instance is empty (represents the empty point set).'''
        raise NotImplementedError()
    
    @property
    def is_simple(self) -> bool:
        '''Gets a value indicating whether this instance is simple from SFA point of view.'''
        raise NotImplementedError()
    
    @property
    def is_valid(self) -> bool:
        '''Gets a value indicating whether this instance is valid.'''
        raise NotImplementedError()
    
    @property
    def has_m(self) -> bool:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_z(self) -> bool:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @property
    def spatial_reference_system(self) -> aspose.gis.spatialreferencing.SpatialReferenceSystem:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , if SpatialReferenceSystem is unknown.'''
        raise NotImplementedError()
    
    @property
    def has_curve_geometry(self) -> bool:
        '''Gets a value indicating whether this geometry is or contains curve (not linear) geometry.'''
        raise NotImplementedError()
    

class IGeometry:
    '''The interface root class of Geometries hierarchy'''
    
    @overload
    def to_linear_geometry(self) -> aspose.gis.geometries.IGeometry:
        '''Gets approximate or equivalent non-curve version of this geometry using the default ``tolerance``.
        
        :returns: A geometry that has no curve geometries. This is the equivalent of :py:func:`aspose.gis.geometries.IGeometry.to_linear_geometry` with
        default ``tolerance``. Default ``tolerance`` is defined by :py:attr:`aspose.gis.geometries.IGeometry.spatial_reference_system`
        of this geometry:
        
        *
        
        *
        
        *
        
        For more details on what transformations are applied refer to :py:func:`aspose.gis.geometries.IGeometry.to_linear_geometry` specification.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self, tolerance : float) -> aspose.gis.geometries.IGeometry:
        '''Gets approximate or equivalent non-curve version of this geometry using the specified ``tolerance``.
        
        :param tolerance: The ``tolerance`` to use. The result is guaranteed to be less than ``tolerance`` away from the
        curved geometry, unless the number of points needed to linearize the geometry exceeds the per-quadrant maximum
        which is currently equal to 10000 points.
        :returns: A geometry, that has no curve geometries. The following transformations are applied:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        As a result, :py:attr:`aspose.gis.geometries.IGeometry.has_curve_geometry` of output geometry is .'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : aspose.gis.AbstractPath, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : str, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> io.RawIOBase:
        '''Export this geometry to an image representation.
        
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.
        :returns: The image as stream'''
        raise NotImplementedError()
    
    @overload
    def as_text(self) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant, format : aspose.gis.NumericFormat) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :param format: Coordinate format for conversion to string. See the :py:class:`aspose.gis.NumericFormat` to get it.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self, variant : aspose.gis.geometries.WkbVariant) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :param variant: Well-Known Binary variant to use.
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def within(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry is within a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry is within extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def within(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is within a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially within" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry intersects a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry intersects the extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry intersects.
        
        :param other: A geometry.
        :returns: if this geometry "spatially intersects" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def replace_polygons_by_lines(self) -> aspose.gis.geometries.IGeometry:
        '''Gets polygons represented as lines of this geometry.
        
        :returns: A geometry, that has no polygon geometries. The following transformation are applied:
        
        *
        
        *'''
        raise NotImplementedError()
    
    def clone(self) -> aspose.gis.geometries.Geometry:
        '''Clones this instance.
        
        :returns: The clone of this instance'''
        raise NotImplementedError()
    
    def get_extent(self) -> aspose.gis.Extent:
        '''Computes and returns a bounding extent of this geometry.
        
        :returns: A bounding extent of this geometry.'''
        raise NotImplementedError()
    
    def get_area(self) -> float:
        '''Computes the area of this geometry.
        
        :returns: The area of this geometry.
        Sum of areas of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_length(self) -> float:
        '''Computes the length of this geometry.
        
        :returns: The length of this geometry.
        Perimeter if this is a :py:class:`aspose.gis.geometries.Polygon`.
        Sum of lengths of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_distance_to(self, other : aspose.gis.geometries.IGeometry) -> float:
        '''Computes the minimum distance between this geometry and a specified geometry.
        
        :param other: A geometry to find distance to.
        :returns: If both geometries are not :py:attr:`aspose.gis.geometries.IGeometry.is_empty` - a distance between closest points of the geometries.
        If at least one geometry is empty -1 is returned.'''
        raise NotImplementedError()
    
    def get_convex_hull(self) -> aspose.gis.geometries.IGeometry:
        '''Computes the convex hull of this geometry.
        
        :returns: A geometry that represents a convex hull of this geometry.
        If this geometry has no points then the result is :py:attr:`aspose.gis.geometries.Geometry.null`.
        If this geometry has only one point then the result is this point.
        If this geometry has only two points then the result is :py:class:`aspose.gis.geometries.ILineString` with the points.
        If this geometry has three or more points then the result is :py:class:`aspose.gis.geometries.ILinearRing` that represents a convex
        hull around all geometries points.'''
        raise NotImplementedError()
    
    def get_centroid(self) -> aspose.gis.geometries.IPoint:
        '''Computes the centroid of this geometry.
        
        :returns: The centroid of this geometry. If this geometry is empty an empty point returned.
        The centroid is equal to the centroid of the highest dimension geometries in this geometry
        (e.g. if both points and lines are contained in the geometry, only lines contribute to centroid).'''
        raise NotImplementedError()
    
    def get_buffer(self, distance : float, quadrant_segments : int) -> aspose.gis.geometries.IGeometry:
        '''Computes a buffer region around this geometry.
        
        :param distance: The buffer region width (in Spatial Reference units).
        :param quadrant_segments: Number of segments used to approximate a 90 degree of curvature.
        The larger this number is the better approximation of curves is produced.
        Default is 30.
        :returns: A geometry that represents all points that are within a specified distance from
        this geometry.
        The type of result is either :py:attr:`aspose.gis.geometries.Geometry.null`, :py:class:`aspose.gis.geometries.IPolygon` or :py:class:`aspose.gis.geometries.IMultiPolygon`.'''
        raise NotImplementedError()
    
    def spatially_equals(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry spatially equal to a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry "spatially equals" to specified geometry.  otherwise.'''
        raise NotImplementedError()
    
    def disjoint(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry is disjoint from a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially disjoint" from another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def touches(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry touch.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially touches" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def crosses(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry cross.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially crosses" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def spatially_contains(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry spatially contains a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially contains" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def overlaps(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry overlap with a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially overlaps" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covers(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry covers a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covers" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covered_by(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is covered by a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covered by" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def relate(self, other : aspose.gis.geometries.IGeometry, intersection_pattern_matrix : str) -> bool:
        '''Determines if DE-9IM intersection matrix of this geometry and a specified geometry matches provided pattern.
        
        :param other: A geometry.
        :param intersection_pattern_matrix: A patter to match with.
        This should be a string with length equal to 9.
        Each character of the string represent expected dimension of an intersection:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        Possible values of each characters are:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        For example, an intersection pattern "F0*******" means, that there should not be intersection between geometries interiors
        and intersection between geometries boundaries must be a point.
        See OpenGIS Simple Features Specification for more details about intersection matrix pattern.
        :returns: if this intersection matrix matches patter;  otherwise.'''
        raise NotImplementedError()
    
    def intersection(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds an intersection between this geometry and a specified geometry.
        
        :param other: A geometry to compute intersection with.
        :returns: A geometry that represents an intersection of this geometry and an argument. The result geometry contain
        point set that present in both this geometry and an argument.'''
        raise NotImplementedError()
    
    def union(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Unites this geometry and a specified geometry.
        
        :param other: A geometry to unite with.
        :returns: A geometry that represents a union of this geometry and an argument. The result geometry contains
        point set that present in this geometry or in an argument.'''
        raise NotImplementedError()
    
    def difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Subtracts a specified geometry from this geometry.
        
        :param other: A geometry to subtract.
        :returns: A geometry that represents a difference of this geometry and an argument. The result geometry contains
        point set that present in this geometry but not present in an argument.'''
        raise NotImplementedError()
    
    def sym_difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds a symmetric difference between this geometry and a specified geometry.
        
        :param other: A geometry to compute symmetric difference with.
        :returns: A geometry that represents a symmetric difference of this geometry and an argument. The result geometry contains
        point set that present in one of the geometries but not present in both of them.'''
        raise NotImplementedError()
    
    @property
    def geometry_type(self) -> aspose.gis.geometries.GeometryType:
        '''Gets the type of the geometry.'''
        raise NotImplementedError()
    
    @property
    def dimension(self) -> aspose.gis.geometries.GeometryDimension:
        '''Gets the topological dimension of this :py:class:`aspose.gis.geometries.IGeometry`.
        If the dimension is unknown (e.g. for an empty GEOMETRYCOLLECTION) :py:attr:`aspose.gis.geometries.GeometryDimension.POINT` is returned.'''
        raise NotImplementedError()
    
    @property
    def is_empty(self) -> bool:
        '''Gets a value indicating whether this instance is empty (represents the empty point set).'''
        raise NotImplementedError()
    
    @property
    def is_simple(self) -> bool:
        '''Gets a value indicating whether this instance is simple from SFA point of view.'''
        raise NotImplementedError()
    
    @property
    def is_valid(self) -> bool:
        '''Gets a value indicating whether this instance is valid.'''
        raise NotImplementedError()
    
    @property
    def has_m(self) -> bool:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_z(self) -> bool:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @property
    def spatial_reference_system(self) -> aspose.gis.spatialreferencing.SpatialReferenceSystem:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , if SpatialReferenceSystem is unknown.'''
        raise NotImplementedError()
    
    @property
    def has_curve_geometry(self) -> bool:
        '''Gets a value indicating whether this geometry is or contains curve (not linear) geometry.'''
        raise NotImplementedError()
    

class IGeometryCollection(IGeometry):
    '''A :py:class:`aspose.gis.geometries.IGeometryCollection` is a :py:class:`aspose.gis.geometries.IGeometry` that is a collection of one or more geometries.'''
    
    @overload
    def to_linear_geometry(self) -> aspose.gis.geometries.IGeometryCollection:
        '''Gets approximate or equivalent non-curve version of this geometry using the default ``tolerance``.
        
        :returns: A geometry, that has no curve geometries. This is the equivalent of :py:func:`aspose.gis.geometries.IGeometryCollection.to_linear_geometry` with
        default ``tolerance``. Default ``tolerance``s value is dependent on :py:class:`aspose.gis.spatialreferencing.SpatialReferenceSystem`
        of this geometry:
        
        *
        
        *
        
        *
        
        For more details on what transformations are applied refer to :py:func:`aspose.gis.geometries.IGeometryCollection.to_linear_geometry` specification.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self, tolerance : float) -> aspose.gis.geometries.IGeometryCollection:
        '''Gets approximate or equivalent non-curve version of this geometry using the specified ``tolerance``.
        
        :param tolerance: The ``tolerance`` to use. The result is guaranteed to be less than ``tolerance`` away from the
        curved geometry, unless the number of points needed to linearize the geometry exceeds the per-quadrant maximum,
        currently equal to 10000 points.
        :returns: A geometry, that has no curve geometries. The following transformations are applied:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        As a result, :py:attr:`aspose.gis.geometries.IGeometry.has_curve_geometry` of output geometry is .'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : aspose.gis.AbstractPath, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : str, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> io.RawIOBase:
        '''Export this geometry to an image representation.
        
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.
        :returns: The image as stream'''
        raise NotImplementedError()
    
    @overload
    def as_text(self) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant, format : aspose.gis.NumericFormat) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :param format: Coordinate format for conversion to string. See the :py:class:`aspose.gis.NumericFormat` to get it.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self, variant : aspose.gis.geometries.WkbVariant) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :param variant: Well-Known Binary variant to use.
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def within(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry is within a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry is within extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def within(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is within a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially within" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry intersects a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry intersects the extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry intersects.
        
        :param other: A geometry.
        :returns: if this geometry "spatially intersects" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def get_point_on_surface(self) -> aspose.gis.geometries.IPoint:
        '''Finds a point that is guaranteed to be on one of the surfaces in this collection.
        
        :returns: A point on one of the surfaces. An empty point if this collection does not contain surfaces or all surfaces are empty.'''
        raise NotImplementedError()
    
    def to_editable(self) -> aspose.gis.geometries.GeometryCollection:
        '''Gets an editable copy of this geometry.
        
        :returns: An editable copy of this geometry.'''
        raise NotImplementedError()
    
    def replace_polygons_by_lines(self) -> aspose.gis.geometries.IGeometryCollection:
        '''Gets polygons represented as lines of this geometry.
        
        :returns: A geometry, that has no polygon geometries. The following transformation are applied:
        
        *
        
        *'''
        raise NotImplementedError()
    
    def clone(self) -> aspose.gis.geometries.Geometry:
        '''Clones this instance.
        
        :returns: The clone of this instance'''
        raise NotImplementedError()
    
    def get_extent(self) -> aspose.gis.Extent:
        '''Computes and returns a bounding extent of this geometry.
        
        :returns: A bounding extent of this geometry.'''
        raise NotImplementedError()
    
    def get_area(self) -> float:
        '''Computes the area of this geometry.
        
        :returns: The area of this geometry.
        Sum of areas of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_length(self) -> float:
        '''Computes the length of this geometry.
        
        :returns: The length of this geometry.
        Perimeter if this is a :py:class:`aspose.gis.geometries.Polygon`.
        Sum of lengths of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_distance_to(self, other : aspose.gis.geometries.IGeometry) -> float:
        '''Computes the minimum distance between this geometry and a specified geometry.
        
        :param other: A geometry to find distance to.
        :returns: If both geometries are not :py:attr:`aspose.gis.geometries.IGeometry.is_empty` - a distance between closest points of the geometries.
        If at least one geometry is empty -1 is returned.'''
        raise NotImplementedError()
    
    def get_convex_hull(self) -> aspose.gis.geometries.IGeometry:
        '''Computes the convex hull of this geometry.
        
        :returns: A geometry that represents a convex hull of this geometry.
        If this geometry has no points then the result is :py:attr:`aspose.gis.geometries.Geometry.null`.
        If this geometry has only one point then the result is this point.
        If this geometry has only two points then the result is :py:class:`aspose.gis.geometries.ILineString` with the points.
        If this geometry has three or more points then the result is :py:class:`aspose.gis.geometries.ILinearRing` that represents a convex
        hull around all geometries points.'''
        raise NotImplementedError()
    
    def get_centroid(self) -> aspose.gis.geometries.IPoint:
        '''Computes the centroid of this geometry.
        
        :returns: The centroid of this geometry. If this geometry is empty an empty point returned.
        The centroid is equal to the centroid of the highest dimension geometries in this geometry
        (e.g. if both points and lines are contained in the geometry, only lines contribute to centroid).'''
        raise NotImplementedError()
    
    def get_buffer(self, distance : float, quadrant_segments : int) -> aspose.gis.geometries.IGeometry:
        '''Computes a buffer region around this geometry.
        
        :param distance: The buffer region width (in Spatial Reference units).
        :param quadrant_segments: Number of segments used to approximate a 90 degree of curvature.
        The larger this number is the better approximation of curves is produced.
        Default is 30.
        :returns: A geometry that represents all points that are within a specified distance from
        this geometry.
        The type of result is either :py:attr:`aspose.gis.geometries.Geometry.null`, :py:class:`aspose.gis.geometries.IPolygon` or :py:class:`aspose.gis.geometries.IMultiPolygon`.'''
        raise NotImplementedError()
    
    def spatially_equals(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry spatially equal to a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry "spatially equals" to specified geometry.  otherwise.'''
        raise NotImplementedError()
    
    def disjoint(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry is disjoint from a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially disjoint" from another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def touches(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry touch.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially touches" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def crosses(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry cross.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially crosses" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def spatially_contains(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry spatially contains a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially contains" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def overlaps(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry overlap with a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially overlaps" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covers(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry covers a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covers" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covered_by(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is covered by a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covered by" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def relate(self, other : aspose.gis.geometries.IGeometry, intersection_pattern_matrix : str) -> bool:
        '''Determines if DE-9IM intersection matrix of this geometry and a specified geometry matches provided pattern.
        
        :param other: A geometry.
        :param intersection_pattern_matrix: A patter to match with.
        This should be a string with length equal to 9.
        Each character of the string represent expected dimension of an intersection:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        Possible values of each characters are:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        For example, an intersection pattern "F0*******" means, that there should not be intersection between geometries interiors
        and intersection between geometries boundaries must be a point.
        See OpenGIS Simple Features Specification for more details about intersection matrix pattern.
        :returns: if this intersection matrix matches patter;  otherwise.'''
        raise NotImplementedError()
    
    def intersection(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds an intersection between this geometry and a specified geometry.
        
        :param other: A geometry to compute intersection with.
        :returns: A geometry that represents an intersection of this geometry and an argument. The result geometry contain
        point set that present in both this geometry and an argument.'''
        raise NotImplementedError()
    
    def union(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Unites this geometry and a specified geometry.
        
        :param other: A geometry to unite with.
        :returns: A geometry that represents a union of this geometry and an argument. The result geometry contains
        point set that present in this geometry or in an argument.'''
        raise NotImplementedError()
    
    def difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Subtracts a specified geometry from this geometry.
        
        :param other: A geometry to subtract.
        :returns: A geometry that represents a difference of this geometry and an argument. The result geometry contains
        point set that present in this geometry but not present in an argument.'''
        raise NotImplementedError()
    
    def sym_difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds a symmetric difference between this geometry and a specified geometry.
        
        :param other: A geometry to compute symmetric difference with.
        :returns: A geometry that represents a symmetric difference of this geometry and an argument. The result geometry contains
        point set that present in one of the geometries but not present in both of them.'''
        raise NotImplementedError()
    
    @property
    def count(self) -> int:
        '''Gets the number of geometries in this collection.'''
        raise NotImplementedError()
    
    @property
    def geometry_type(self) -> aspose.gis.geometries.GeometryType:
        '''Gets the type of the geometry.'''
        raise NotImplementedError()
    
    @property
    def dimension(self) -> aspose.gis.geometries.GeometryDimension:
        '''Gets the topological dimension of this :py:class:`aspose.gis.geometries.IGeometry`.
        If the dimension is unknown (e.g. for an empty GEOMETRYCOLLECTION) :py:attr:`aspose.gis.geometries.GeometryDimension.POINT` is returned.'''
        raise NotImplementedError()
    
    @property
    def is_empty(self) -> bool:
        '''Gets a value indicating whether this instance is empty (represents the empty point set).'''
        raise NotImplementedError()
    
    @property
    def is_simple(self) -> bool:
        '''Gets a value indicating whether this instance is simple from SFA point of view.'''
        raise NotImplementedError()
    
    @property
    def is_valid(self) -> bool:
        '''Gets a value indicating whether this instance is valid.'''
        raise NotImplementedError()
    
    @property
    def has_m(self) -> bool:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_z(self) -> bool:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @property
    def spatial_reference_system(self) -> aspose.gis.spatialreferencing.SpatialReferenceSystem:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , if SpatialReferenceSystem is unknown.'''
        raise NotImplementedError()
    
    @property
    def has_curve_geometry(self) -> bool:
        '''Gets a value indicating whether this geometry is or contains curve (not linear) geometry.'''
        raise NotImplementedError()
    
    def __getitem__(self, key : int) -> aspose.gis.geometries.IGeometry:
        '''Gets a :py:class:`aspose.gis.geometries.IGeometry` at the specified index.'''
        raise NotImplementedError()
    

class ILineString(ICurve):
    '''A multi-vertex curve with linear interpolation between points.'''
    
    @overload
    def to_linear_geometry(self) -> aspose.gis.geometries.ILineString:
        '''Gets approximate or equivalent non-curve version of this geometry using the default ``tolerance``.
        
        :returns: A :py:class:`aspose.gis.geometries.ILineString` that approximates or equivalent to this curve.
        This is the equivalent of :py:func:`aspose.gis.geometries.ICurve.to_linear_geometry` with
        default ``tolerance``. Default ``tolerance``s value is dependent on :py:class:`aspose.gis.spatialreferencing.SpatialReferenceSystem`
        of this geometry:
        
        *
        
        *
        
        *
        
        For more details on what transformations are applied refer to :py:func:`aspose.gis.geometries.ICurve.to_linear_geometry` specification.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self, tolerance : float) -> aspose.gis.geometries.ILineString:
        '''Gets approximate or equivalent non-curve version of this geometry using the specified ``tolerance``.
        
        :param tolerance: The ``tolerance`` to use. The result is guaranteed to be less than ``tolerance`` away from the
        curved geometry, unless the number of points needed to linearize the geometry exceeds the per-quadrant maximum,
        currently equal to 10000 points.
        :returns: A :py:class:`aspose.gis.geometries.ILineString` that approximates or equivalent to this curve:
        
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : aspose.gis.AbstractPath, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : str, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> io.RawIOBase:
        '''Export this geometry to an image representation.
        
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.
        :returns: The image as stream'''
        raise NotImplementedError()
    
    @overload
    def as_text(self) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant, format : aspose.gis.NumericFormat) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :param format: Coordinate format for conversion to string. See the :py:class:`aspose.gis.NumericFormat` to get it.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self, variant : aspose.gis.geometries.WkbVariant) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :param variant: Well-Known Binary variant to use.
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def within(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry is within a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry is within extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def within(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is within a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially within" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry intersects a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry intersects the extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry intersects.
        
        :param other: A geometry.
        :returns: if this geometry "spatially intersects" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def to_editable(self) -> aspose.gis.geometries.LineString:
        '''Gets an editable copy of this geometry.
        
        :returns: An editable copy of this geometry.'''
        raise NotImplementedError()
    
    def replace_polygons_by_lines(self) -> aspose.gis.geometries.IGeometry:
        '''Gets polygons represented as lines of this geometry.
        
        :returns: A geometry, that has no polygon geometries. The following transformation are applied:
        
        *
        
        *'''
        raise NotImplementedError()
    
    def clone(self) -> aspose.gis.geometries.Geometry:
        '''Clones this instance.
        
        :returns: The clone of this instance'''
        raise NotImplementedError()
    
    def get_extent(self) -> aspose.gis.Extent:
        '''Computes and returns a bounding extent of this geometry.
        
        :returns: A bounding extent of this geometry.'''
        raise NotImplementedError()
    
    def get_area(self) -> float:
        '''Computes the area of this geometry.
        
        :returns: The area of this geometry.
        Sum of areas of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_length(self) -> float:
        '''Computes the length of this geometry.
        
        :returns: The length of this geometry.
        Perimeter if this is a :py:class:`aspose.gis.geometries.Polygon`.
        Sum of lengths of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_distance_to(self, other : aspose.gis.geometries.IGeometry) -> float:
        '''Computes the minimum distance between this geometry and a specified geometry.
        
        :param other: A geometry to find distance to.
        :returns: If both geometries are not :py:attr:`aspose.gis.geometries.IGeometry.is_empty` - a distance between closest points of the geometries.
        If at least one geometry is empty -1 is returned.'''
        raise NotImplementedError()
    
    def get_convex_hull(self) -> aspose.gis.geometries.IGeometry:
        '''Computes the convex hull of this geometry.
        
        :returns: A geometry that represents a convex hull of this geometry.
        If this geometry has no points then the result is :py:attr:`aspose.gis.geometries.Geometry.null`.
        If this geometry has only one point then the result is this point.
        If this geometry has only two points then the result is :py:class:`aspose.gis.geometries.ILineString` with the points.
        If this geometry has three or more points then the result is :py:class:`aspose.gis.geometries.ILinearRing` that represents a convex
        hull around all geometries points.'''
        raise NotImplementedError()
    
    def get_centroid(self) -> aspose.gis.geometries.IPoint:
        '''Computes the centroid of this geometry.
        
        :returns: The centroid of this geometry. If this geometry is empty an empty point returned.
        The centroid is equal to the centroid of the highest dimension geometries in this geometry
        (e.g. if both points and lines are contained in the geometry, only lines contribute to centroid).'''
        raise NotImplementedError()
    
    def get_buffer(self, distance : float, quadrant_segments : int) -> aspose.gis.geometries.IGeometry:
        '''Computes a buffer region around this geometry.
        
        :param distance: The buffer region width (in Spatial Reference units).
        :param quadrant_segments: Number of segments used to approximate a 90 degree of curvature.
        The larger this number is the better approximation of curves is produced.
        Default is 30.
        :returns: A geometry that represents all points that are within a specified distance from
        this geometry.
        The type of result is either :py:attr:`aspose.gis.geometries.Geometry.null`, :py:class:`aspose.gis.geometries.IPolygon` or :py:class:`aspose.gis.geometries.IMultiPolygon`.'''
        raise NotImplementedError()
    
    def spatially_equals(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry spatially equal to a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry "spatially equals" to specified geometry.  otherwise.'''
        raise NotImplementedError()
    
    def disjoint(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry is disjoint from a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially disjoint" from another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def touches(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry touch.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially touches" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def crosses(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry cross.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially crosses" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def spatially_contains(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry spatially contains a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially contains" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def overlaps(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry overlap with a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially overlaps" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covers(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry covers a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covers" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covered_by(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is covered by a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covered by" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def relate(self, other : aspose.gis.geometries.IGeometry, intersection_pattern_matrix : str) -> bool:
        '''Determines if DE-9IM intersection matrix of this geometry and a specified geometry matches provided pattern.
        
        :param other: A geometry.
        :param intersection_pattern_matrix: A patter to match with.
        This should be a string with length equal to 9.
        Each character of the string represent expected dimension of an intersection:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        Possible values of each characters are:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        For example, an intersection pattern "F0*******" means, that there should not be intersection between geometries interiors
        and intersection between geometries boundaries must be a point.
        See OpenGIS Simple Features Specification for more details about intersection matrix pattern.
        :returns: if this intersection matrix matches patter;  otherwise.'''
        raise NotImplementedError()
    
    def intersection(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds an intersection between this geometry and a specified geometry.
        
        :param other: A geometry to compute intersection with.
        :returns: A geometry that represents an intersection of this geometry and an argument. The result geometry contain
        point set that present in both this geometry and an argument.'''
        raise NotImplementedError()
    
    def union(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Unites this geometry and a specified geometry.
        
        :param other: A geometry to unite with.
        :returns: A geometry that represents a union of this geometry and an argument. The result geometry contains
        point set that present in this geometry or in an argument.'''
        raise NotImplementedError()
    
    def difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Subtracts a specified geometry from this geometry.
        
        :param other: A geometry to subtract.
        :returns: A geometry that represents a difference of this geometry and an argument. The result geometry contains
        point set that present in this geometry but not present in an argument.'''
        raise NotImplementedError()
    
    def sym_difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds a symmetric difference between this geometry and a specified geometry.
        
        :param other: A geometry to compute symmetric difference with.
        :returns: A geometry that represents a symmetric difference of this geometry and an argument. The result geometry contains
        point set that present in one of the geometries but not present in both of them.'''
        raise NotImplementedError()
    
    @property
    def start_point(self) -> aspose.gis.geometries.IPoint:
        '''Returns a copy of the starting point of the curve.'''
        raise NotImplementedError()
    
    @property
    def end_point(self) -> aspose.gis.geometries.IPoint:
        '''Returns a copy of the end point of the curve.'''
        raise NotImplementedError()
    
    @property
    def is_closed(self) -> bool:
        '''Gets a values indicating whether a curve is closed.
        A curve is closed if its start point is equal to its end point.'''
        raise NotImplementedError()
    
    @property
    def geometry_type(self) -> aspose.gis.geometries.GeometryType:
        '''Gets the type of the geometry.'''
        raise NotImplementedError()
    
    @property
    def dimension(self) -> aspose.gis.geometries.GeometryDimension:
        '''Gets the topological dimension of this :py:class:`aspose.gis.geometries.IGeometry`.
        If the dimension is unknown (e.g. for an empty GEOMETRYCOLLECTION) :py:attr:`aspose.gis.geometries.GeometryDimension.POINT` is returned.'''
        raise NotImplementedError()
    
    @property
    def is_empty(self) -> bool:
        '''Gets a value indicating whether this instance is empty (represents the empty point set).'''
        raise NotImplementedError()
    
    @property
    def is_simple(self) -> bool:
        '''Gets a value indicating whether this instance is simple from SFA point of view.'''
        raise NotImplementedError()
    
    @property
    def is_valid(self) -> bool:
        '''Gets a value indicating whether this instance is valid.'''
        raise NotImplementedError()
    
    @property
    def has_m(self) -> bool:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_z(self) -> bool:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @property
    def spatial_reference_system(self) -> aspose.gis.spatialreferencing.SpatialReferenceSystem:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , if SpatialReferenceSystem is unknown.'''
        raise NotImplementedError()
    
    @property
    def has_curve_geometry(self) -> bool:
        '''Gets a value indicating whether this geometry is or contains curve (not linear) geometry.'''
        raise NotImplementedError()
    

class ILinearRing(ILineString):
    '''A multi-vertex ring.'''
    
    @overload
    def to_linear_geometry(self) -> aspose.gis.geometries.ILineString:
        '''Gets approximate or equivalent non-curve version of this geometry using the default ``tolerance``.
        
        :returns: A :py:class:`aspose.gis.geometries.ILineString` that approximates or equivalent to this curve.
        This is the equivalent of :py:func:`aspose.gis.geometries.ICurve.to_linear_geometry` with
        default ``tolerance``. Default ``tolerance``s value is dependent on :py:class:`aspose.gis.spatialreferencing.SpatialReferenceSystem`
        of this geometry:
        
        *
        
        *
        
        *
        
        For more details on what transformations are applied refer to :py:func:`aspose.gis.geometries.ICurve.to_linear_geometry` specification.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self, tolerance : float) -> aspose.gis.geometries.ILineString:
        '''Gets approximate or equivalent non-curve version of this geometry using the specified ``tolerance``.
        
        :param tolerance: The ``tolerance`` to use. The result is guaranteed to be less than ``tolerance`` away from the
        curved geometry, unless the number of points needed to linearize the geometry exceeds the per-quadrant maximum,
        currently equal to 10000 points.
        :returns: A :py:class:`aspose.gis.geometries.ILineString` that approximates or equivalent to this curve:
        
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : aspose.gis.AbstractPath, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : str, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> io.RawIOBase:
        '''Export this geometry to an image representation.
        
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.
        :returns: The image as stream'''
        raise NotImplementedError()
    
    @overload
    def as_text(self) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant, format : aspose.gis.NumericFormat) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :param format: Coordinate format for conversion to string. See the :py:class:`aspose.gis.NumericFormat` to get it.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self, variant : aspose.gis.geometries.WkbVariant) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :param variant: Well-Known Binary variant to use.
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def within(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry is within a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry is within extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def within(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is within a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially within" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry intersects a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry intersects the extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry intersects.
        
        :param other: A geometry.
        :returns: if this geometry "spatially intersects" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def is_clockwise(self) -> bool:
        '''Determines if the ring has clockwise winding
        
        :returns: if clockwise; otherwise .'''
        raise NotImplementedError()
    
    def to_editable(self) -> aspose.gis.geometries.LinearRing:
        '''Gets an editable copy of this geometry.
        
        :returns: An editable copy of this geometry.'''
        raise NotImplementedError()
    
    def replace_polygons_by_lines(self) -> aspose.gis.geometries.IGeometry:
        '''Gets polygons represented as lines of this geometry.
        
        :returns: A geometry, that has no polygon geometries. The following transformation are applied:
        
        *
        
        *'''
        raise NotImplementedError()
    
    def clone(self) -> aspose.gis.geometries.Geometry:
        '''Clones this instance.
        
        :returns: The clone of this instance'''
        raise NotImplementedError()
    
    def get_extent(self) -> aspose.gis.Extent:
        '''Computes and returns a bounding extent of this geometry.
        
        :returns: A bounding extent of this geometry.'''
        raise NotImplementedError()
    
    def get_area(self) -> float:
        '''Computes the area of this geometry.
        
        :returns: The area of this geometry.
        Sum of areas of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_length(self) -> float:
        '''Computes the length of this geometry.
        
        :returns: The length of this geometry.
        Perimeter if this is a :py:class:`aspose.gis.geometries.Polygon`.
        Sum of lengths of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_distance_to(self, other : aspose.gis.geometries.IGeometry) -> float:
        '''Computes the minimum distance between this geometry and a specified geometry.
        
        :param other: A geometry to find distance to.
        :returns: If both geometries are not :py:attr:`aspose.gis.geometries.IGeometry.is_empty` - a distance between closest points of the geometries.
        If at least one geometry is empty -1 is returned.'''
        raise NotImplementedError()
    
    def get_convex_hull(self) -> aspose.gis.geometries.IGeometry:
        '''Computes the convex hull of this geometry.
        
        :returns: A geometry that represents a convex hull of this geometry.
        If this geometry has no points then the result is :py:attr:`aspose.gis.geometries.Geometry.null`.
        If this geometry has only one point then the result is this point.
        If this geometry has only two points then the result is :py:class:`aspose.gis.geometries.ILineString` with the points.
        If this geometry has three or more points then the result is :py:class:`aspose.gis.geometries.ILinearRing` that represents a convex
        hull around all geometries points.'''
        raise NotImplementedError()
    
    def get_centroid(self) -> aspose.gis.geometries.IPoint:
        '''Computes the centroid of this geometry.
        
        :returns: The centroid of this geometry. If this geometry is empty an empty point returned.
        The centroid is equal to the centroid of the highest dimension geometries in this geometry
        (e.g. if both points and lines are contained in the geometry, only lines contribute to centroid).'''
        raise NotImplementedError()
    
    def get_buffer(self, distance : float, quadrant_segments : int) -> aspose.gis.geometries.IGeometry:
        '''Computes a buffer region around this geometry.
        
        :param distance: The buffer region width (in Spatial Reference units).
        :param quadrant_segments: Number of segments used to approximate a 90 degree of curvature.
        The larger this number is the better approximation of curves is produced.
        Default is 30.
        :returns: A geometry that represents all points that are within a specified distance from
        this geometry.
        The type of result is either :py:attr:`aspose.gis.geometries.Geometry.null`, :py:class:`aspose.gis.geometries.IPolygon` or :py:class:`aspose.gis.geometries.IMultiPolygon`.'''
        raise NotImplementedError()
    
    def spatially_equals(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry spatially equal to a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry "spatially equals" to specified geometry.  otherwise.'''
        raise NotImplementedError()
    
    def disjoint(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry is disjoint from a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially disjoint" from another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def touches(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry touch.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially touches" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def crosses(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry cross.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially crosses" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def spatially_contains(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry spatially contains a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially contains" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def overlaps(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry overlap with a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially overlaps" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covers(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry covers a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covers" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covered_by(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is covered by a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covered by" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def relate(self, other : aspose.gis.geometries.IGeometry, intersection_pattern_matrix : str) -> bool:
        '''Determines if DE-9IM intersection matrix of this geometry and a specified geometry matches provided pattern.
        
        :param other: A geometry.
        :param intersection_pattern_matrix: A patter to match with.
        This should be a string with length equal to 9.
        Each character of the string represent expected dimension of an intersection:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        Possible values of each characters are:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        For example, an intersection pattern "F0*******" means, that there should not be intersection between geometries interiors
        and intersection between geometries boundaries must be a point.
        See OpenGIS Simple Features Specification for more details about intersection matrix pattern.
        :returns: if this intersection matrix matches patter;  otherwise.'''
        raise NotImplementedError()
    
    def intersection(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds an intersection between this geometry and a specified geometry.
        
        :param other: A geometry to compute intersection with.
        :returns: A geometry that represents an intersection of this geometry and an argument. The result geometry contain
        point set that present in both this geometry and an argument.'''
        raise NotImplementedError()
    
    def union(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Unites this geometry and a specified geometry.
        
        :param other: A geometry to unite with.
        :returns: A geometry that represents a union of this geometry and an argument. The result geometry contains
        point set that present in this geometry or in an argument.'''
        raise NotImplementedError()
    
    def difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Subtracts a specified geometry from this geometry.
        
        :param other: A geometry to subtract.
        :returns: A geometry that represents a difference of this geometry and an argument. The result geometry contains
        point set that present in this geometry but not present in an argument.'''
        raise NotImplementedError()
    
    def sym_difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds a symmetric difference between this geometry and a specified geometry.
        
        :param other: A geometry to compute symmetric difference with.
        :returns: A geometry that represents a symmetric difference of this geometry and an argument. The result geometry contains
        point set that present in one of the geometries but not present in both of them.'''
        raise NotImplementedError()
    
    @property
    def start_point(self) -> aspose.gis.geometries.IPoint:
        '''Returns a copy of the starting point of the curve.'''
        raise NotImplementedError()
    
    @property
    def end_point(self) -> aspose.gis.geometries.IPoint:
        '''Returns a copy of the end point of the curve.'''
        raise NotImplementedError()
    
    @property
    def is_closed(self) -> bool:
        '''Gets a values indicating whether a curve is closed.
        A curve is closed if its start point is equal to its end point.'''
        raise NotImplementedError()
    
    @property
    def geometry_type(self) -> aspose.gis.geometries.GeometryType:
        '''Gets the type of the geometry.'''
        raise NotImplementedError()
    
    @property
    def dimension(self) -> aspose.gis.geometries.GeometryDimension:
        '''Gets the topological dimension of this :py:class:`aspose.gis.geometries.IGeometry`.
        If the dimension is unknown (e.g. for an empty GEOMETRYCOLLECTION) :py:attr:`aspose.gis.geometries.GeometryDimension.POINT` is returned.'''
        raise NotImplementedError()
    
    @property
    def is_empty(self) -> bool:
        '''Gets a value indicating whether this instance is empty (represents the empty point set).'''
        raise NotImplementedError()
    
    @property
    def is_simple(self) -> bool:
        '''Gets a value indicating whether this instance is simple from SFA point of view.'''
        raise NotImplementedError()
    
    @property
    def is_valid(self) -> bool:
        '''Gets a value indicating whether this instance is valid.'''
        raise NotImplementedError()
    
    @property
    def has_m(self) -> bool:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_z(self) -> bool:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @property
    def spatial_reference_system(self) -> aspose.gis.spatialreferencing.SpatialReferenceSystem:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , if SpatialReferenceSystem is unknown.'''
        raise NotImplementedError()
    
    @property
    def has_curve_geometry(self) -> bool:
        '''Gets a value indicating whether this geometry is or contains curve (not linear) geometry.'''
        raise NotImplementedError()
    

class IMultiCurve(IGeometryCollection):
    '''A :py:class:`aspose.gis.geometries.MultiCurve` is a one-dimensional :py:class:`aspose.gis.geometries.GeometryCollection`
    whose elements are :py:class:`aspose.gis.geometries.Curve`s.'''
    
    @overload
    def to_linear_geometry(self) -> aspose.gis.geometries.IMultiLineString:
        '''Gets approximate or equivalent non-curve version of this geometry using the default ``tolerance``.
        
        :returns: A :py:class:`aspose.gis.geometries.IMultiLineString` that approximates or equivalent to this :py:class:`aspose.gis.geometries.IMultiCurve`.
        This is the equivalent of :py:func:`aspose.gis.geometries.IMultiCurve.to_linear_geometry` with
        default ``tolerance``. Default ``tolerance``s value is dependent on :py:class:`aspose.gis.spatialreferencing.SpatialReferenceSystem`
        of this geometry:
        
        *
        
        *
        
        *
        
        For more details on what transformations are applied refer to :py:func:`aspose.gis.geometries.IMultiCurve.to_linear_geometry` specification.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self, tolerance : float) -> aspose.gis.geometries.IMultiLineString:
        '''Gets approximate or equivalent non-curve version of this geometry using the specified ``tolerance``.
        
        :param tolerance: The ``tolerance`` to use. The result is guaranteed to be less than ``tolerance`` away from the
        curved geometry, unless the number of points needed to linearize the geometry exceeds the per-quadrant maximum,
        currently equal to 10000 points.
        :returns: A :py:class:`aspose.gis.geometries.IMultiLineString` that approximates or equivalent to this :py:class:`aspose.gis.geometries.IMultiCurve`:
        
        If this object is :py:class:`aspose.gis.geometries.IMultiLineString` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiLineString` - all curves are linearized and new ``IMultiLineString`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiLineString` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiLineString` - all curves are linearized and new ``IMultiLineString`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiLineString` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiLineString` - all curves are linearized and new ``IMultiLineString`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiLineString` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiLineString` - all curves are linearized and new ``IMultiLineString`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiLineString` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiLineString` - all curves are linearized and new ``IMultiLineString`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiLineString` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiLineString` - all curves are linearized and new ``IMultiLineString`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiLineString` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiLineString` - all curves are linearized and new ``IMultiLineString`` is created'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : aspose.gis.AbstractPath, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : str, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> io.RawIOBase:
        '''Export this geometry to an image representation.
        
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.
        :returns: The image as stream'''
        raise NotImplementedError()
    
    @overload
    def as_text(self) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant, format : aspose.gis.NumericFormat) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :param format: Coordinate format for conversion to string. See the :py:class:`aspose.gis.NumericFormat` to get it.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self, variant : aspose.gis.geometries.WkbVariant) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :param variant: Well-Known Binary variant to use.
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def within(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry is within a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry is within extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def within(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is within a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially within" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry intersects a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry intersects the extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry intersects.
        
        :param other: A geometry.
        :returns: if this geometry "spatially intersects" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def to_editable(self) -> aspose.gis.geometries.MultiCurve:
        '''Gets an editable copy of this geometry.
        
        :returns: An editable copy of this geometry.'''
        raise NotImplementedError()
    
    def get_point_on_surface(self) -> aspose.gis.geometries.IPoint:
        '''Finds a point that is guaranteed to be on one of the surfaces in this collection.
        
        :returns: A point on one of the surfaces. An empty point if this collection does not contain surfaces or all surfaces are empty.'''
        raise NotImplementedError()
    
    def replace_polygons_by_lines(self) -> aspose.gis.geometries.IGeometryCollection:
        '''Gets polygons represented as lines of this geometry.
        
        :returns: A geometry, that has no polygon geometries. The following transformation are applied:
        
        *
        
        *'''
        raise NotImplementedError()
    
    def clone(self) -> aspose.gis.geometries.Geometry:
        '''Clones this instance.
        
        :returns: The clone of this instance'''
        raise NotImplementedError()
    
    def get_extent(self) -> aspose.gis.Extent:
        '''Computes and returns a bounding extent of this geometry.
        
        :returns: A bounding extent of this geometry.'''
        raise NotImplementedError()
    
    def get_area(self) -> float:
        '''Computes the area of this geometry.
        
        :returns: The area of this geometry.
        Sum of areas of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_length(self) -> float:
        '''Computes the length of this geometry.
        
        :returns: The length of this geometry.
        Perimeter if this is a :py:class:`aspose.gis.geometries.Polygon`.
        Sum of lengths of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_distance_to(self, other : aspose.gis.geometries.IGeometry) -> float:
        '''Computes the minimum distance between this geometry and a specified geometry.
        
        :param other: A geometry to find distance to.
        :returns: If both geometries are not :py:attr:`aspose.gis.geometries.IGeometry.is_empty` - a distance between closest points of the geometries.
        If at least one geometry is empty -1 is returned.'''
        raise NotImplementedError()
    
    def get_convex_hull(self) -> aspose.gis.geometries.IGeometry:
        '''Computes the convex hull of this geometry.
        
        :returns: A geometry that represents a convex hull of this geometry.
        If this geometry has no points then the result is :py:attr:`aspose.gis.geometries.Geometry.null`.
        If this geometry has only one point then the result is this point.
        If this geometry has only two points then the result is :py:class:`aspose.gis.geometries.ILineString` with the points.
        If this geometry has three or more points then the result is :py:class:`aspose.gis.geometries.ILinearRing` that represents a convex
        hull around all geometries points.'''
        raise NotImplementedError()
    
    def get_centroid(self) -> aspose.gis.geometries.IPoint:
        '''Computes the centroid of this geometry.
        
        :returns: The centroid of this geometry. If this geometry is empty an empty point returned.
        The centroid is equal to the centroid of the highest dimension geometries in this geometry
        (e.g. if both points and lines are contained in the geometry, only lines contribute to centroid).'''
        raise NotImplementedError()
    
    def get_buffer(self, distance : float, quadrant_segments : int) -> aspose.gis.geometries.IGeometry:
        '''Computes a buffer region around this geometry.
        
        :param distance: The buffer region width (in Spatial Reference units).
        :param quadrant_segments: Number of segments used to approximate a 90 degree of curvature.
        The larger this number is the better approximation of curves is produced.
        Default is 30.
        :returns: A geometry that represents all points that are within a specified distance from
        this geometry.
        The type of result is either :py:attr:`aspose.gis.geometries.Geometry.null`, :py:class:`aspose.gis.geometries.IPolygon` or :py:class:`aspose.gis.geometries.IMultiPolygon`.'''
        raise NotImplementedError()
    
    def spatially_equals(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry spatially equal to a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry "spatially equals" to specified geometry.  otherwise.'''
        raise NotImplementedError()
    
    def disjoint(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry is disjoint from a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially disjoint" from another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def touches(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry touch.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially touches" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def crosses(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry cross.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially crosses" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def spatially_contains(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry spatially contains a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially contains" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def overlaps(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry overlap with a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially overlaps" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covers(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry covers a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covers" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covered_by(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is covered by a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covered by" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def relate(self, other : aspose.gis.geometries.IGeometry, intersection_pattern_matrix : str) -> bool:
        '''Determines if DE-9IM intersection matrix of this geometry and a specified geometry matches provided pattern.
        
        :param other: A geometry.
        :param intersection_pattern_matrix: A patter to match with.
        This should be a string with length equal to 9.
        Each character of the string represent expected dimension of an intersection:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        Possible values of each characters are:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        For example, an intersection pattern "F0*******" means, that there should not be intersection between geometries interiors
        and intersection between geometries boundaries must be a point.
        See OpenGIS Simple Features Specification for more details about intersection matrix pattern.
        :returns: if this intersection matrix matches patter;  otherwise.'''
        raise NotImplementedError()
    
    def intersection(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds an intersection between this geometry and a specified geometry.
        
        :param other: A geometry to compute intersection with.
        :returns: A geometry that represents an intersection of this geometry and an argument. The result geometry contain
        point set that present in both this geometry and an argument.'''
        raise NotImplementedError()
    
    def union(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Unites this geometry and a specified geometry.
        
        :param other: A geometry to unite with.
        :returns: A geometry that represents a union of this geometry and an argument. The result geometry contains
        point set that present in this geometry or in an argument.'''
        raise NotImplementedError()
    
    def difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Subtracts a specified geometry from this geometry.
        
        :param other: A geometry to subtract.
        :returns: A geometry that represents a difference of this geometry and an argument. The result geometry contains
        point set that present in this geometry but not present in an argument.'''
        raise NotImplementedError()
    
    def sym_difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds a symmetric difference between this geometry and a specified geometry.
        
        :param other: A geometry to compute symmetric difference with.
        :returns: A geometry that represents a symmetric difference of this geometry and an argument. The result geometry contains
        point set that present in one of the geometries but not present in both of them.'''
        raise NotImplementedError()
    
    @property
    def count(self) -> int:
        '''Gets the number of geometries in this collection.'''
        raise NotImplementedError()
    
    @property
    def geometry_type(self) -> aspose.gis.geometries.GeometryType:
        '''Gets the type of the geometry.'''
        raise NotImplementedError()
    
    @property
    def dimension(self) -> aspose.gis.geometries.GeometryDimension:
        '''Gets the topological dimension of this :py:class:`aspose.gis.geometries.IGeometry`.
        If the dimension is unknown (e.g. for an empty GEOMETRYCOLLECTION) :py:attr:`aspose.gis.geometries.GeometryDimension.POINT` is returned.'''
        raise NotImplementedError()
    
    @property
    def is_empty(self) -> bool:
        '''Gets a value indicating whether this instance is empty (represents the empty point set).'''
        raise NotImplementedError()
    
    @property
    def is_simple(self) -> bool:
        '''Gets a value indicating whether this instance is simple from SFA point of view.'''
        raise NotImplementedError()
    
    @property
    def is_valid(self) -> bool:
        '''Gets a value indicating whether this instance is valid.'''
        raise NotImplementedError()
    
    @property
    def has_m(self) -> bool:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_z(self) -> bool:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @property
    def spatial_reference_system(self) -> aspose.gis.spatialreferencing.SpatialReferenceSystem:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , if SpatialReferenceSystem is unknown.'''
        raise NotImplementedError()
    
    @property
    def has_curve_geometry(self) -> bool:
        '''Gets a value indicating whether this geometry is or contains curve (not linear) geometry.'''
        raise NotImplementedError()
    
    def __getitem__(self, key : int) -> aspose.gis.geometries.IGeometry:
        raise NotImplementedError()
    

class IMultiLineString(IMultiCurve):
    '''A :py:class:`aspose.gis.geometries.MultiLineString` is a one-dimensional :py:class:`aspose.gis.geometries.GeometryCollection`
    whose elements are :py:class:`aspose.gis.geometries.LineString`s.'''
    
    @overload
    def to_linear_geometry(self) -> aspose.gis.geometries.IMultiLineString:
        '''Gets approximate or equivalent non-curve version of this geometry using the default ``tolerance``.
        
        :returns: A :py:class:`aspose.gis.geometries.IMultiLineString` that approximates or equivalent to this :py:class:`aspose.gis.geometries.IMultiCurve`.
        This is the equivalent of :py:func:`aspose.gis.geometries.IMultiCurve.to_linear_geometry` with
        default ``tolerance``. Default ``tolerance``s value is dependent on :py:class:`aspose.gis.spatialreferencing.SpatialReferenceSystem`
        of this geometry:
        
        *
        
        *
        
        *
        
        For more details on what transformations are applied refer to :py:func:`aspose.gis.geometries.IMultiCurve.to_linear_geometry` specification.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self, tolerance : float) -> aspose.gis.geometries.IMultiLineString:
        '''Gets approximate or equivalent non-curve version of this geometry using the specified ``tolerance``.
        
        :param tolerance: The ``tolerance`` to use. The result is guaranteed to be less than ``tolerance`` away from the
        curved geometry, unless the number of points needed to linearize the geometry exceeds the per-quadrant maximum,
        currently equal to 10000 points.
        :returns: A :py:class:`aspose.gis.geometries.IMultiLineString` that approximates or equivalent to this :py:class:`aspose.gis.geometries.IMultiCurve`:
        
        If this object is :py:class:`aspose.gis.geometries.IMultiLineString` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiLineString` - all curves are linearized and new ``IMultiLineString`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiLineString` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiLineString` - all curves are linearized and new ``IMultiLineString`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiLineString` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiLineString` - all curves are linearized and new ``IMultiLineString`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiLineString` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiLineString` - all curves are linearized and new ``IMultiLineString`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiLineString` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiLineString` - all curves are linearized and new ``IMultiLineString`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiLineString` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiLineString` - all curves are linearized and new ``IMultiLineString`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiLineString` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiLineString` - all curves are linearized and new ``IMultiLineString`` is created'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : aspose.gis.AbstractPath, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : str, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> io.RawIOBase:
        '''Export this geometry to an image representation.
        
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.
        :returns: The image as stream'''
        raise NotImplementedError()
    
    @overload
    def as_text(self) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant, format : aspose.gis.NumericFormat) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :param format: Coordinate format for conversion to string. See the :py:class:`aspose.gis.NumericFormat` to get it.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self, variant : aspose.gis.geometries.WkbVariant) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :param variant: Well-Known Binary variant to use.
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def within(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry is within a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry is within extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def within(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is within a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially within" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry intersects a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry intersects the extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry intersects.
        
        :param other: A geometry.
        :returns: if this geometry "spatially intersects" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def to_editable(self) -> aspose.gis.geometries.MultiLineString:
        '''Gets an editable copy of this geometry.
        
        :returns: An editable copy of this geometry.'''
        raise NotImplementedError()
    
    def get_point_on_surface(self) -> aspose.gis.geometries.IPoint:
        '''Finds a point that is guaranteed to be on one of the surfaces in this collection.
        
        :returns: A point on one of the surfaces. An empty point if this collection does not contain surfaces or all surfaces are empty.'''
        raise NotImplementedError()
    
    def replace_polygons_by_lines(self) -> aspose.gis.geometries.IGeometryCollection:
        '''Gets polygons represented as lines of this geometry.
        
        :returns: A geometry, that has no polygon geometries. The following transformation are applied:
        
        *
        
        *'''
        raise NotImplementedError()
    
    def clone(self) -> aspose.gis.geometries.Geometry:
        '''Clones this instance.
        
        :returns: The clone of this instance'''
        raise NotImplementedError()
    
    def get_extent(self) -> aspose.gis.Extent:
        '''Computes and returns a bounding extent of this geometry.
        
        :returns: A bounding extent of this geometry.'''
        raise NotImplementedError()
    
    def get_area(self) -> float:
        '''Computes the area of this geometry.
        
        :returns: The area of this geometry.
        Sum of areas of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_length(self) -> float:
        '''Computes the length of this geometry.
        
        :returns: The length of this geometry.
        Perimeter if this is a :py:class:`aspose.gis.geometries.Polygon`.
        Sum of lengths of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_distance_to(self, other : aspose.gis.geometries.IGeometry) -> float:
        '''Computes the minimum distance between this geometry and a specified geometry.
        
        :param other: A geometry to find distance to.
        :returns: If both geometries are not :py:attr:`aspose.gis.geometries.IGeometry.is_empty` - a distance between closest points of the geometries.
        If at least one geometry is empty -1 is returned.'''
        raise NotImplementedError()
    
    def get_convex_hull(self) -> aspose.gis.geometries.IGeometry:
        '''Computes the convex hull of this geometry.
        
        :returns: A geometry that represents a convex hull of this geometry.
        If this geometry has no points then the result is :py:attr:`aspose.gis.geometries.Geometry.null`.
        If this geometry has only one point then the result is this point.
        If this geometry has only two points then the result is :py:class:`aspose.gis.geometries.ILineString` with the points.
        If this geometry has three or more points then the result is :py:class:`aspose.gis.geometries.ILinearRing` that represents a convex
        hull around all geometries points.'''
        raise NotImplementedError()
    
    def get_centroid(self) -> aspose.gis.geometries.IPoint:
        '''Computes the centroid of this geometry.
        
        :returns: The centroid of this geometry. If this geometry is empty an empty point returned.
        The centroid is equal to the centroid of the highest dimension geometries in this geometry
        (e.g. if both points and lines are contained in the geometry, only lines contribute to centroid).'''
        raise NotImplementedError()
    
    def get_buffer(self, distance : float, quadrant_segments : int) -> aspose.gis.geometries.IGeometry:
        '''Computes a buffer region around this geometry.
        
        :param distance: The buffer region width (in Spatial Reference units).
        :param quadrant_segments: Number of segments used to approximate a 90 degree of curvature.
        The larger this number is the better approximation of curves is produced.
        Default is 30.
        :returns: A geometry that represents all points that are within a specified distance from
        this geometry.
        The type of result is either :py:attr:`aspose.gis.geometries.Geometry.null`, :py:class:`aspose.gis.geometries.IPolygon` or :py:class:`aspose.gis.geometries.IMultiPolygon`.'''
        raise NotImplementedError()
    
    def spatially_equals(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry spatially equal to a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry "spatially equals" to specified geometry.  otherwise.'''
        raise NotImplementedError()
    
    def disjoint(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry is disjoint from a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially disjoint" from another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def touches(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry touch.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially touches" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def crosses(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry cross.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially crosses" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def spatially_contains(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry spatially contains a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially contains" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def overlaps(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry overlap with a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially overlaps" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covers(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry covers a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covers" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covered_by(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is covered by a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covered by" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def relate(self, other : aspose.gis.geometries.IGeometry, intersection_pattern_matrix : str) -> bool:
        '''Determines if DE-9IM intersection matrix of this geometry and a specified geometry matches provided pattern.
        
        :param other: A geometry.
        :param intersection_pattern_matrix: A patter to match with.
        This should be a string with length equal to 9.
        Each character of the string represent expected dimension of an intersection:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        Possible values of each characters are:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        For example, an intersection pattern "F0*******" means, that there should not be intersection between geometries interiors
        and intersection between geometries boundaries must be a point.
        See OpenGIS Simple Features Specification for more details about intersection matrix pattern.
        :returns: if this intersection matrix matches patter;  otherwise.'''
        raise NotImplementedError()
    
    def intersection(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds an intersection between this geometry and a specified geometry.
        
        :param other: A geometry to compute intersection with.
        :returns: A geometry that represents an intersection of this geometry and an argument. The result geometry contain
        point set that present in both this geometry and an argument.'''
        raise NotImplementedError()
    
    def union(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Unites this geometry and a specified geometry.
        
        :param other: A geometry to unite with.
        :returns: A geometry that represents a union of this geometry and an argument. The result geometry contains
        point set that present in this geometry or in an argument.'''
        raise NotImplementedError()
    
    def difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Subtracts a specified geometry from this geometry.
        
        :param other: A geometry to subtract.
        :returns: A geometry that represents a difference of this geometry and an argument. The result geometry contains
        point set that present in this geometry but not present in an argument.'''
        raise NotImplementedError()
    
    def sym_difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds a symmetric difference between this geometry and a specified geometry.
        
        :param other: A geometry to compute symmetric difference with.
        :returns: A geometry that represents a symmetric difference of this geometry and an argument. The result geometry contains
        point set that present in one of the geometries but not present in both of them.'''
        raise NotImplementedError()
    
    @property
    def count(self) -> int:
        '''Gets the number of geometries in this collection.'''
        raise NotImplementedError()
    
    @property
    def geometry_type(self) -> aspose.gis.geometries.GeometryType:
        '''Gets the type of the geometry.'''
        raise NotImplementedError()
    
    @property
    def dimension(self) -> aspose.gis.geometries.GeometryDimension:
        '''Gets the topological dimension of this :py:class:`aspose.gis.geometries.IGeometry`.
        If the dimension is unknown (e.g. for an empty GEOMETRYCOLLECTION) :py:attr:`aspose.gis.geometries.GeometryDimension.POINT` is returned.'''
        raise NotImplementedError()
    
    @property
    def is_empty(self) -> bool:
        '''Gets a value indicating whether this instance is empty (represents the empty point set).'''
        raise NotImplementedError()
    
    @property
    def is_simple(self) -> bool:
        '''Gets a value indicating whether this instance is simple from SFA point of view.'''
        raise NotImplementedError()
    
    @property
    def is_valid(self) -> bool:
        '''Gets a value indicating whether this instance is valid.'''
        raise NotImplementedError()
    
    @property
    def has_m(self) -> bool:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_z(self) -> bool:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @property
    def spatial_reference_system(self) -> aspose.gis.spatialreferencing.SpatialReferenceSystem:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , if SpatialReferenceSystem is unknown.'''
        raise NotImplementedError()
    
    @property
    def has_curve_geometry(self) -> bool:
        '''Gets a value indicating whether this geometry is or contains curve (not linear) geometry.'''
        raise NotImplementedError()
    
    def __getitem__(self, key : int) -> aspose.gis.geometries.IGeometry:
        raise NotImplementedError()
    

class IMultiPoint(IGeometryCollection):
    '''A :py:class:`aspose.gis.geometries.IMultiPoint` is a one-dimensional :py:class:`aspose.gis.geometries.IGeometryCollection`
    whose elements are :py:class:`aspose.gis.geometries.IPoint`s.'''
    
    @overload
    def to_linear_geometry(self) -> aspose.gis.geometries.IGeometryCollection:
        '''Gets approximate or equivalent non-curve version of this geometry using the default ``tolerance``.
        
        :returns: A geometry, that has no curve geometries. This is the equivalent of :py:func:`aspose.gis.geometries.IGeometryCollection.to_linear_geometry` with
        default ``tolerance``. Default ``tolerance``s value is dependent on :py:class:`aspose.gis.spatialreferencing.SpatialReferenceSystem`
        of this geometry:
        
        *
        
        *
        
        *
        
        For more details on what transformations are applied refer to :py:func:`aspose.gis.geometries.IGeometryCollection.to_linear_geometry` specification.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self, tolerance : float) -> aspose.gis.geometries.IGeometryCollection:
        '''Gets approximate or equivalent non-curve version of this geometry using the specified ``tolerance``.
        
        :param tolerance: The ``tolerance`` to use. The result is guaranteed to be less than ``tolerance`` away from the
        curved geometry, unless the number of points needed to linearize the geometry exceeds the per-quadrant maximum,
        currently equal to 10000 points.
        :returns: A geometry, that has no curve geometries. The following transformations are applied:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        As a result, :py:attr:`aspose.gis.geometries.IGeometry.has_curve_geometry` of output geometry is .'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : aspose.gis.AbstractPath, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : str, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> io.RawIOBase:
        '''Export this geometry to an image representation.
        
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.
        :returns: The image as stream'''
        raise NotImplementedError()
    
    @overload
    def as_text(self) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant, format : aspose.gis.NumericFormat) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :param format: Coordinate format for conversion to string. See the :py:class:`aspose.gis.NumericFormat` to get it.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self, variant : aspose.gis.geometries.WkbVariant) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :param variant: Well-Known Binary variant to use.
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def within(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry is within a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry is within extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def within(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is within a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially within" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry intersects a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry intersects the extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry intersects.
        
        :param other: A geometry.
        :returns: if this geometry "spatially intersects" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def to_editable(self) -> aspose.gis.common.formats.mapinfo.graphicalobjects.MultiPoint:
        '''Gets an editable copy of this geometry.
        
        :returns: An editable copy of this geometry.'''
        raise NotImplementedError()
    
    def get_point_on_surface(self) -> aspose.gis.geometries.IPoint:
        '''Finds a point that is guaranteed to be on one of the surfaces in this collection.
        
        :returns: A point on one of the surfaces. An empty point if this collection does not contain surfaces or all surfaces are empty.'''
        raise NotImplementedError()
    
    def replace_polygons_by_lines(self) -> aspose.gis.geometries.IGeometryCollection:
        '''Gets polygons represented as lines of this geometry.
        
        :returns: A geometry, that has no polygon geometries. The following transformation are applied:
        
        *
        
        *'''
        raise NotImplementedError()
    
    def clone(self) -> aspose.gis.geometries.Geometry:
        '''Clones this instance.
        
        :returns: The clone of this instance'''
        raise NotImplementedError()
    
    def get_extent(self) -> aspose.gis.Extent:
        '''Computes and returns a bounding extent of this geometry.
        
        :returns: A bounding extent of this geometry.'''
        raise NotImplementedError()
    
    def get_area(self) -> float:
        '''Computes the area of this geometry.
        
        :returns: The area of this geometry.
        Sum of areas of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_length(self) -> float:
        '''Computes the length of this geometry.
        
        :returns: The length of this geometry.
        Perimeter if this is a :py:class:`aspose.gis.geometries.Polygon`.
        Sum of lengths of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_distance_to(self, other : aspose.gis.geometries.IGeometry) -> float:
        '''Computes the minimum distance between this geometry and a specified geometry.
        
        :param other: A geometry to find distance to.
        :returns: If both geometries are not :py:attr:`aspose.gis.geometries.IGeometry.is_empty` - a distance between closest points of the geometries.
        If at least one geometry is empty -1 is returned.'''
        raise NotImplementedError()
    
    def get_convex_hull(self) -> aspose.gis.geometries.IGeometry:
        '''Computes the convex hull of this geometry.
        
        :returns: A geometry that represents a convex hull of this geometry.
        If this geometry has no points then the result is :py:attr:`aspose.gis.geometries.Geometry.null`.
        If this geometry has only one point then the result is this point.
        If this geometry has only two points then the result is :py:class:`aspose.gis.geometries.ILineString` with the points.
        If this geometry has three or more points then the result is :py:class:`aspose.gis.geometries.ILinearRing` that represents a convex
        hull around all geometries points.'''
        raise NotImplementedError()
    
    def get_centroid(self) -> aspose.gis.geometries.IPoint:
        '''Computes the centroid of this geometry.
        
        :returns: The centroid of this geometry. If this geometry is empty an empty point returned.
        The centroid is equal to the centroid of the highest dimension geometries in this geometry
        (e.g. if both points and lines are contained in the geometry, only lines contribute to centroid).'''
        raise NotImplementedError()
    
    def get_buffer(self, distance : float, quadrant_segments : int) -> aspose.gis.geometries.IGeometry:
        '''Computes a buffer region around this geometry.
        
        :param distance: The buffer region width (in Spatial Reference units).
        :param quadrant_segments: Number of segments used to approximate a 90 degree of curvature.
        The larger this number is the better approximation of curves is produced.
        Default is 30.
        :returns: A geometry that represents all points that are within a specified distance from
        this geometry.
        The type of result is either :py:attr:`aspose.gis.geometries.Geometry.null`, :py:class:`aspose.gis.geometries.IPolygon` or :py:class:`aspose.gis.geometries.IMultiPolygon`.'''
        raise NotImplementedError()
    
    def spatially_equals(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry spatially equal to a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry "spatially equals" to specified geometry.  otherwise.'''
        raise NotImplementedError()
    
    def disjoint(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry is disjoint from a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially disjoint" from another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def touches(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry touch.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially touches" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def crosses(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry cross.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially crosses" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def spatially_contains(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry spatially contains a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially contains" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def overlaps(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry overlap with a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially overlaps" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covers(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry covers a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covers" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covered_by(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is covered by a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covered by" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def relate(self, other : aspose.gis.geometries.IGeometry, intersection_pattern_matrix : str) -> bool:
        '''Determines if DE-9IM intersection matrix of this geometry and a specified geometry matches provided pattern.
        
        :param other: A geometry.
        :param intersection_pattern_matrix: A patter to match with.
        This should be a string with length equal to 9.
        Each character of the string represent expected dimension of an intersection:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        Possible values of each characters are:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        For example, an intersection pattern "F0*******" means, that there should not be intersection between geometries interiors
        and intersection between geometries boundaries must be a point.
        See OpenGIS Simple Features Specification for more details about intersection matrix pattern.
        :returns: if this intersection matrix matches patter;  otherwise.'''
        raise NotImplementedError()
    
    def intersection(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds an intersection between this geometry and a specified geometry.
        
        :param other: A geometry to compute intersection with.
        :returns: A geometry that represents an intersection of this geometry and an argument. The result geometry contain
        point set that present in both this geometry and an argument.'''
        raise NotImplementedError()
    
    def union(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Unites this geometry and a specified geometry.
        
        :param other: A geometry to unite with.
        :returns: A geometry that represents a union of this geometry and an argument. The result geometry contains
        point set that present in this geometry or in an argument.'''
        raise NotImplementedError()
    
    def difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Subtracts a specified geometry from this geometry.
        
        :param other: A geometry to subtract.
        :returns: A geometry that represents a difference of this geometry and an argument. The result geometry contains
        point set that present in this geometry but not present in an argument.'''
        raise NotImplementedError()
    
    def sym_difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds a symmetric difference between this geometry and a specified geometry.
        
        :param other: A geometry to compute symmetric difference with.
        :returns: A geometry that represents a symmetric difference of this geometry and an argument. The result geometry contains
        point set that present in one of the geometries but not present in both of them.'''
        raise NotImplementedError()
    
    @property
    def count(self) -> int:
        '''Gets the number of geometries in this collection.'''
        raise NotImplementedError()
    
    @property
    def geometry_type(self) -> aspose.gis.geometries.GeometryType:
        '''Gets the type of the geometry.'''
        raise NotImplementedError()
    
    @property
    def dimension(self) -> aspose.gis.geometries.GeometryDimension:
        '''Gets the topological dimension of this :py:class:`aspose.gis.geometries.IGeometry`.
        If the dimension is unknown (e.g. for an empty GEOMETRYCOLLECTION) :py:attr:`aspose.gis.geometries.GeometryDimension.POINT` is returned.'''
        raise NotImplementedError()
    
    @property
    def is_empty(self) -> bool:
        '''Gets a value indicating whether this instance is empty (represents the empty point set).'''
        raise NotImplementedError()
    
    @property
    def is_simple(self) -> bool:
        '''Gets a value indicating whether this instance is simple from SFA point of view.'''
        raise NotImplementedError()
    
    @property
    def is_valid(self) -> bool:
        '''Gets a value indicating whether this instance is valid.'''
        raise NotImplementedError()
    
    @property
    def has_m(self) -> bool:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_z(self) -> bool:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @property
    def spatial_reference_system(self) -> aspose.gis.spatialreferencing.SpatialReferenceSystem:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , if SpatialReferenceSystem is unknown.'''
        raise NotImplementedError()
    
    @property
    def has_curve_geometry(self) -> bool:
        '''Gets a value indicating whether this geometry is or contains curve (not linear) geometry.'''
        raise NotImplementedError()
    
    def __getitem__(self, key : int) -> aspose.gis.geometries.IGeometry:
        raise NotImplementedError()
    

class IMultiPolygon(IMultiSurface):
    '''A :py:class:`aspose.gis.geometries.IMultiPolygon` is a one-dimensional
    :py:class:`aspose.gis.geometries.IGeometryCollection` whose elements are :py:class:`aspose.gis.geometries.IPolygon`s.'''
    
    @overload
    def to_linear_geometry(self) -> aspose.gis.geometries.IMultiPolygon:
        '''Gets approximate or equivalent non-curve version of this geometry using the default ``tolerance``.
        
        :returns: A :py:class:`aspose.gis.geometries.IMultiPolygon` that approximates or equivalent to this :py:class:`aspose.gis.geometries.IMultiSurface`.
        This is the equivalent of :py:func:`aspose.gis.geometries.IMultiSurface.to_linear_geometry` with
        default ``tolerance``. Default ``tolerance``s value is dependent on :py:class:`aspose.gis.spatialreferencing.SpatialReferenceSystem`
        of this geometry:
        
        *
        
        *
        
        *
        
        For more details on what transformations are applied refer to :py:func:`aspose.gis.geometries.IMultiSurface.to_linear_geometry` specification.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self, tolerance : float) -> aspose.gis.geometries.IMultiPolygon:
        '''Gets approximate or equivalent non-curve version of this geometry using the specified ``tolerance``.
        
        :param tolerance: The ``tolerance`` to use. The result is guaranteed to be less than ``tolerance`` away from the
        curved geometry, unless the number of points needed to linearize the geometry exceeds the per-quadrant maximum,
        currently equal to 10000 points.
        :returns: A :py:class:`aspose.gis.geometries.IMultiPolygon` that approximates or equivalent to this :py:class:`aspose.gis.geometries.IMultiSurface`:
        
        If this object is :py:class:`aspose.gis.geometries.IMultiPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiPolygon` - all surfaces are linearized and new ``IMultiPolygon`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiPolygon` - all surfaces are linearized and new ``IMultiPolygon`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiPolygon` - all surfaces are linearized and new ``IMultiPolygon`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiPolygon` - all surfaces are linearized and new ``IMultiPolygon`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiPolygon` - all surfaces are linearized and new ``IMultiPolygon`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiPolygon` - all surfaces are linearized and new ``IMultiPolygon`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiPolygon` - all surfaces are linearized and new ``IMultiPolygon`` is created'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : aspose.gis.AbstractPath, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : str, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> io.RawIOBase:
        '''Export this geometry to an image representation.
        
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.
        :returns: The image as stream'''
        raise NotImplementedError()
    
    @overload
    def as_text(self) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant, format : aspose.gis.NumericFormat) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :param format: Coordinate format for conversion to string. See the :py:class:`aspose.gis.NumericFormat` to get it.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self, variant : aspose.gis.geometries.WkbVariant) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :param variant: Well-Known Binary variant to use.
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def within(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry is within a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry is within extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def within(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is within a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially within" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry intersects a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry intersects the extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry intersects.
        
        :param other: A geometry.
        :returns: if this geometry "spatially intersects" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def to_editable(self) -> aspose.gis.geometries.MultiPolygon:
        '''Gets an editable copy of this geometry.
        
        :returns: An editable copy of this geometry.'''
        raise NotImplementedError()
    
    def get_point_on_surface(self) -> aspose.gis.geometries.IPoint:
        '''Finds a point that is guaranteed to be on one of the surfaces in this collection.
        
        :returns: A point on one of the surfaces. An empty point if this collection does not contain surfaces or all surfaces are empty.'''
        raise NotImplementedError()
    
    def replace_polygons_by_lines(self) -> aspose.gis.geometries.IGeometryCollection:
        '''Gets polygons represented as lines of this geometry.
        
        :returns: A geometry, that has no polygon geometries. The following transformation are applied:
        
        *
        
        *'''
        raise NotImplementedError()
    
    def clone(self) -> aspose.gis.geometries.Geometry:
        '''Clones this instance.
        
        :returns: The clone of this instance'''
        raise NotImplementedError()
    
    def get_extent(self) -> aspose.gis.Extent:
        '''Computes and returns a bounding extent of this geometry.
        
        :returns: A bounding extent of this geometry.'''
        raise NotImplementedError()
    
    def get_area(self) -> float:
        '''Computes the area of this geometry.
        
        :returns: The area of this geometry.
        Sum of areas of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_length(self) -> float:
        '''Computes the length of this geometry.
        
        :returns: The length of this geometry.
        Perimeter if this is a :py:class:`aspose.gis.geometries.Polygon`.
        Sum of lengths of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_distance_to(self, other : aspose.gis.geometries.IGeometry) -> float:
        '''Computes the minimum distance between this geometry and a specified geometry.
        
        :param other: A geometry to find distance to.
        :returns: If both geometries are not :py:attr:`aspose.gis.geometries.IGeometry.is_empty` - a distance between closest points of the geometries.
        If at least one geometry is empty -1 is returned.'''
        raise NotImplementedError()
    
    def get_convex_hull(self) -> aspose.gis.geometries.IGeometry:
        '''Computes the convex hull of this geometry.
        
        :returns: A geometry that represents a convex hull of this geometry.
        If this geometry has no points then the result is :py:attr:`aspose.gis.geometries.Geometry.null`.
        If this geometry has only one point then the result is this point.
        If this geometry has only two points then the result is :py:class:`aspose.gis.geometries.ILineString` with the points.
        If this geometry has three or more points then the result is :py:class:`aspose.gis.geometries.ILinearRing` that represents a convex
        hull around all geometries points.'''
        raise NotImplementedError()
    
    def get_centroid(self) -> aspose.gis.geometries.IPoint:
        '''Computes the centroid of this geometry.
        
        :returns: The centroid of this geometry. If this geometry is empty an empty point returned.
        The centroid is equal to the centroid of the highest dimension geometries in this geometry
        (e.g. if both points and lines are contained in the geometry, only lines contribute to centroid).'''
        raise NotImplementedError()
    
    def get_buffer(self, distance : float, quadrant_segments : int) -> aspose.gis.geometries.IGeometry:
        '''Computes a buffer region around this geometry.
        
        :param distance: The buffer region width (in Spatial Reference units).
        :param quadrant_segments: Number of segments used to approximate a 90 degree of curvature.
        The larger this number is the better approximation of curves is produced.
        Default is 30.
        :returns: A geometry that represents all points that are within a specified distance from
        this geometry.
        The type of result is either :py:attr:`aspose.gis.geometries.Geometry.null`, :py:class:`aspose.gis.geometries.IPolygon` or :py:class:`aspose.gis.geometries.IMultiPolygon`.'''
        raise NotImplementedError()
    
    def spatially_equals(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry spatially equal to a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry "spatially equals" to specified geometry.  otherwise.'''
        raise NotImplementedError()
    
    def disjoint(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry is disjoint from a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially disjoint" from another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def touches(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry touch.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially touches" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def crosses(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry cross.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially crosses" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def spatially_contains(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry spatially contains a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially contains" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def overlaps(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry overlap with a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially overlaps" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covers(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry covers a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covers" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covered_by(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is covered by a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covered by" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def relate(self, other : aspose.gis.geometries.IGeometry, intersection_pattern_matrix : str) -> bool:
        '''Determines if DE-9IM intersection matrix of this geometry and a specified geometry matches provided pattern.
        
        :param other: A geometry.
        :param intersection_pattern_matrix: A patter to match with.
        This should be a string with length equal to 9.
        Each character of the string represent expected dimension of an intersection:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        Possible values of each characters are:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        For example, an intersection pattern "F0*******" means, that there should not be intersection between geometries interiors
        and intersection between geometries boundaries must be a point.
        See OpenGIS Simple Features Specification for more details about intersection matrix pattern.
        :returns: if this intersection matrix matches patter;  otherwise.'''
        raise NotImplementedError()
    
    def intersection(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds an intersection between this geometry and a specified geometry.
        
        :param other: A geometry to compute intersection with.
        :returns: A geometry that represents an intersection of this geometry and an argument. The result geometry contain
        point set that present in both this geometry and an argument.'''
        raise NotImplementedError()
    
    def union(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Unites this geometry and a specified geometry.
        
        :param other: A geometry to unite with.
        :returns: A geometry that represents a union of this geometry and an argument. The result geometry contains
        point set that present in this geometry or in an argument.'''
        raise NotImplementedError()
    
    def difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Subtracts a specified geometry from this geometry.
        
        :param other: A geometry to subtract.
        :returns: A geometry that represents a difference of this geometry and an argument. The result geometry contains
        point set that present in this geometry but not present in an argument.'''
        raise NotImplementedError()
    
    def sym_difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds a symmetric difference between this geometry and a specified geometry.
        
        :param other: A geometry to compute symmetric difference with.
        :returns: A geometry that represents a symmetric difference of this geometry and an argument. The result geometry contains
        point set that present in one of the geometries but not present in both of them.'''
        raise NotImplementedError()
    
    @property
    def count(self) -> int:
        '''Gets the number of geometries in this collection.'''
        raise NotImplementedError()
    
    @property
    def geometry_type(self) -> aspose.gis.geometries.GeometryType:
        '''Gets the type of the geometry.'''
        raise NotImplementedError()
    
    @property
    def dimension(self) -> aspose.gis.geometries.GeometryDimension:
        '''Gets the topological dimension of this :py:class:`aspose.gis.geometries.IGeometry`.
        If the dimension is unknown (e.g. for an empty GEOMETRYCOLLECTION) :py:attr:`aspose.gis.geometries.GeometryDimension.POINT` is returned.'''
        raise NotImplementedError()
    
    @property
    def is_empty(self) -> bool:
        '''Gets a value indicating whether this instance is empty (represents the empty point set).'''
        raise NotImplementedError()
    
    @property
    def is_simple(self) -> bool:
        '''Gets a value indicating whether this instance is simple from SFA point of view.'''
        raise NotImplementedError()
    
    @property
    def is_valid(self) -> bool:
        '''Gets a value indicating whether this instance is valid.'''
        raise NotImplementedError()
    
    @property
    def has_m(self) -> bool:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_z(self) -> bool:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @property
    def spatial_reference_system(self) -> aspose.gis.spatialreferencing.SpatialReferenceSystem:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , if SpatialReferenceSystem is unknown.'''
        raise NotImplementedError()
    
    @property
    def has_curve_geometry(self) -> bool:
        '''Gets a value indicating whether this geometry is or contains curve (not linear) geometry.'''
        raise NotImplementedError()
    
    def __getitem__(self, key : int) -> aspose.gis.geometries.IGeometry:
        raise NotImplementedError()
    

class IMultiSurface(IGeometryCollection):
    '''A :py:class:`aspose.gis.geometries.IMultiPolygon` is a one-dimensional :py:class:`aspose.gis.geometries.IGeometryCollection` whose elements are :py:class:`aspose.gis.geometries.ISurface`s.'''
    
    @overload
    def to_linear_geometry(self) -> aspose.gis.geometries.IMultiPolygon:
        '''Gets approximate or equivalent non-curve version of this geometry using the default ``tolerance``.
        
        :returns: A :py:class:`aspose.gis.geometries.IMultiPolygon` that approximates or equivalent to this :py:class:`aspose.gis.geometries.IMultiSurface`.
        This is the equivalent of :py:func:`aspose.gis.geometries.IMultiSurface.to_linear_geometry` with
        default ``tolerance``. Default ``tolerance``s value is dependent on :py:class:`aspose.gis.spatialreferencing.SpatialReferenceSystem`
        of this geometry:
        
        *
        
        *
        
        *
        
        For more details on what transformations are applied refer to :py:func:`aspose.gis.geometries.IMultiSurface.to_linear_geometry` specification.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self, tolerance : float) -> aspose.gis.geometries.IMultiPolygon:
        '''Gets approximate or equivalent non-curve version of this geometry using the specified ``tolerance``.
        
        :param tolerance: The ``tolerance`` to use. The result is guaranteed to be less than ``tolerance`` away from the
        curved geometry, unless the number of points needed to linearize the geometry exceeds the per-quadrant maximum,
        currently equal to 10000 points.
        :returns: A :py:class:`aspose.gis.geometries.IMultiPolygon` that approximates or equivalent to this :py:class:`aspose.gis.geometries.IMultiSurface`:
        
        If this object is :py:class:`aspose.gis.geometries.IMultiPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiPolygon` - all surfaces are linearized and new ``IMultiPolygon`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiPolygon` - all surfaces are linearized and new ``IMultiPolygon`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiPolygon` - all surfaces are linearized and new ``IMultiPolygon`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiPolygon` - all surfaces are linearized and new ``IMultiPolygon`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiPolygon` - all surfaces are linearized and new ``IMultiPolygon`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiPolygon` - all surfaces are linearized and new ``IMultiPolygon`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiPolygon` - all surfaces are linearized and new ``IMultiPolygon`` is created'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : aspose.gis.AbstractPath, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : str, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> io.RawIOBase:
        '''Export this geometry to an image representation.
        
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.
        :returns: The image as stream'''
        raise NotImplementedError()
    
    @overload
    def as_text(self) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant, format : aspose.gis.NumericFormat) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :param format: Coordinate format for conversion to string. See the :py:class:`aspose.gis.NumericFormat` to get it.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self, variant : aspose.gis.geometries.WkbVariant) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :param variant: Well-Known Binary variant to use.
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def within(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry is within a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry is within extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def within(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is within a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially within" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry intersects a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry intersects the extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry intersects.
        
        :param other: A geometry.
        :returns: if this geometry "spatially intersects" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def to_editable(self) -> aspose.gis.geometries.MultiSurface:
        '''Gets an editable copy of this geometry.
        
        :returns: An editable copy of this geometry.'''
        raise NotImplementedError()
    
    def get_point_on_surface(self) -> aspose.gis.geometries.IPoint:
        '''Finds a point that is guaranteed to be on one of the surfaces in this collection.
        
        :returns: A point on one of the surfaces. An empty point if this collection does not contain surfaces or all surfaces are empty.'''
        raise NotImplementedError()
    
    def replace_polygons_by_lines(self) -> aspose.gis.geometries.IGeometryCollection:
        '''Gets polygons represented as lines of this geometry.
        
        :returns: A geometry, that has no polygon geometries. The following transformation are applied:
        
        *
        
        *'''
        raise NotImplementedError()
    
    def clone(self) -> aspose.gis.geometries.Geometry:
        '''Clones this instance.
        
        :returns: The clone of this instance'''
        raise NotImplementedError()
    
    def get_extent(self) -> aspose.gis.Extent:
        '''Computes and returns a bounding extent of this geometry.
        
        :returns: A bounding extent of this geometry.'''
        raise NotImplementedError()
    
    def get_area(self) -> float:
        '''Computes the area of this geometry.
        
        :returns: The area of this geometry.
        Sum of areas of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_length(self) -> float:
        '''Computes the length of this geometry.
        
        :returns: The length of this geometry.
        Perimeter if this is a :py:class:`aspose.gis.geometries.Polygon`.
        Sum of lengths of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_distance_to(self, other : aspose.gis.geometries.IGeometry) -> float:
        '''Computes the minimum distance between this geometry and a specified geometry.
        
        :param other: A geometry to find distance to.
        :returns: If both geometries are not :py:attr:`aspose.gis.geometries.IGeometry.is_empty` - a distance between closest points of the geometries.
        If at least one geometry is empty -1 is returned.'''
        raise NotImplementedError()
    
    def get_convex_hull(self) -> aspose.gis.geometries.IGeometry:
        '''Computes the convex hull of this geometry.
        
        :returns: A geometry that represents a convex hull of this geometry.
        If this geometry has no points then the result is :py:attr:`aspose.gis.geometries.Geometry.null`.
        If this geometry has only one point then the result is this point.
        If this geometry has only two points then the result is :py:class:`aspose.gis.geometries.ILineString` with the points.
        If this geometry has three or more points then the result is :py:class:`aspose.gis.geometries.ILinearRing` that represents a convex
        hull around all geometries points.'''
        raise NotImplementedError()
    
    def get_centroid(self) -> aspose.gis.geometries.IPoint:
        '''Computes the centroid of this geometry.
        
        :returns: The centroid of this geometry. If this geometry is empty an empty point returned.
        The centroid is equal to the centroid of the highest dimension geometries in this geometry
        (e.g. if both points and lines are contained in the geometry, only lines contribute to centroid).'''
        raise NotImplementedError()
    
    def get_buffer(self, distance : float, quadrant_segments : int) -> aspose.gis.geometries.IGeometry:
        '''Computes a buffer region around this geometry.
        
        :param distance: The buffer region width (in Spatial Reference units).
        :param quadrant_segments: Number of segments used to approximate a 90 degree of curvature.
        The larger this number is the better approximation of curves is produced.
        Default is 30.
        :returns: A geometry that represents all points that are within a specified distance from
        this geometry.
        The type of result is either :py:attr:`aspose.gis.geometries.Geometry.null`, :py:class:`aspose.gis.geometries.IPolygon` or :py:class:`aspose.gis.geometries.IMultiPolygon`.'''
        raise NotImplementedError()
    
    def spatially_equals(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry spatially equal to a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry "spatially equals" to specified geometry.  otherwise.'''
        raise NotImplementedError()
    
    def disjoint(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry is disjoint from a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially disjoint" from another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def touches(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry touch.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially touches" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def crosses(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry cross.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially crosses" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def spatially_contains(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry spatially contains a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially contains" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def overlaps(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry overlap with a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially overlaps" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covers(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry covers a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covers" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covered_by(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is covered by a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covered by" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def relate(self, other : aspose.gis.geometries.IGeometry, intersection_pattern_matrix : str) -> bool:
        '''Determines if DE-9IM intersection matrix of this geometry and a specified geometry matches provided pattern.
        
        :param other: A geometry.
        :param intersection_pattern_matrix: A patter to match with.
        This should be a string with length equal to 9.
        Each character of the string represent expected dimension of an intersection:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        Possible values of each characters are:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        For example, an intersection pattern "F0*******" means, that there should not be intersection between geometries interiors
        and intersection between geometries boundaries must be a point.
        See OpenGIS Simple Features Specification for more details about intersection matrix pattern.
        :returns: if this intersection matrix matches patter;  otherwise.'''
        raise NotImplementedError()
    
    def intersection(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds an intersection between this geometry and a specified geometry.
        
        :param other: A geometry to compute intersection with.
        :returns: A geometry that represents an intersection of this geometry and an argument. The result geometry contain
        point set that present in both this geometry and an argument.'''
        raise NotImplementedError()
    
    def union(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Unites this geometry and a specified geometry.
        
        :param other: A geometry to unite with.
        :returns: A geometry that represents a union of this geometry and an argument. The result geometry contains
        point set that present in this geometry or in an argument.'''
        raise NotImplementedError()
    
    def difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Subtracts a specified geometry from this geometry.
        
        :param other: A geometry to subtract.
        :returns: A geometry that represents a difference of this geometry and an argument. The result geometry contains
        point set that present in this geometry but not present in an argument.'''
        raise NotImplementedError()
    
    def sym_difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds a symmetric difference between this geometry and a specified geometry.
        
        :param other: A geometry to compute symmetric difference with.
        :returns: A geometry that represents a symmetric difference of this geometry and an argument. The result geometry contains
        point set that present in one of the geometries but not present in both of them.'''
        raise NotImplementedError()
    
    @property
    def count(self) -> int:
        '''Gets the number of geometries in this collection.'''
        raise NotImplementedError()
    
    @property
    def geometry_type(self) -> aspose.gis.geometries.GeometryType:
        '''Gets the type of the geometry.'''
        raise NotImplementedError()
    
    @property
    def dimension(self) -> aspose.gis.geometries.GeometryDimension:
        '''Gets the topological dimension of this :py:class:`aspose.gis.geometries.IGeometry`.
        If the dimension is unknown (e.g. for an empty GEOMETRYCOLLECTION) :py:attr:`aspose.gis.geometries.GeometryDimension.POINT` is returned.'''
        raise NotImplementedError()
    
    @property
    def is_empty(self) -> bool:
        '''Gets a value indicating whether this instance is empty (represents the empty point set).'''
        raise NotImplementedError()
    
    @property
    def is_simple(self) -> bool:
        '''Gets a value indicating whether this instance is simple from SFA point of view.'''
        raise NotImplementedError()
    
    @property
    def is_valid(self) -> bool:
        '''Gets a value indicating whether this instance is valid.'''
        raise NotImplementedError()
    
    @property
    def has_m(self) -> bool:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_z(self) -> bool:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @property
    def spatial_reference_system(self) -> aspose.gis.spatialreferencing.SpatialReferenceSystem:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , if SpatialReferenceSystem is unknown.'''
        raise NotImplementedError()
    
    @property
    def has_curve_geometry(self) -> bool:
        '''Gets a value indicating whether this geometry is or contains curve (not linear) geometry.'''
        raise NotImplementedError()
    
    def __getitem__(self, key : int) -> aspose.gis.geometries.IGeometry:
        raise NotImplementedError()
    

class IPoint(IGeometry):
    '''A single location in coordinate space.'''
    
    @overload
    def to_linear_geometry(self) -> aspose.gis.geometries.IGeometry:
        '''Gets approximate or equivalent non-curve version of this geometry using the default ``tolerance``.
        
        :returns: A geometry that has no curve geometries. This is the equivalent of :py:func:`aspose.gis.geometries.IGeometry.to_linear_geometry` with
        default ``tolerance``. Default ``tolerance`` is defined by :py:attr:`aspose.gis.geometries.IGeometry.spatial_reference_system`
        of this geometry:
        
        *
        
        *
        
        *
        
        For more details on what transformations are applied refer to :py:func:`aspose.gis.geometries.IGeometry.to_linear_geometry` specification.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self, tolerance : float) -> aspose.gis.geometries.IGeometry:
        '''Gets approximate or equivalent non-curve version of this geometry using the specified ``tolerance``.
        
        :param tolerance: The ``tolerance`` to use. The result is guaranteed to be less than ``tolerance`` away from the
        curved geometry, unless the number of points needed to linearize the geometry exceeds the per-quadrant maximum
        which is currently equal to 10000 points.
        :returns: A geometry, that has no curve geometries. The following transformations are applied:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        As a result, :py:attr:`aspose.gis.geometries.IGeometry.has_curve_geometry` of output geometry is .'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : aspose.gis.AbstractPath, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : str, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> io.RawIOBase:
        '''Export this geometry to an image representation.
        
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.
        :returns: The image as stream'''
        raise NotImplementedError()
    
    @overload
    def as_text(self) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant, format : aspose.gis.NumericFormat) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :param format: Coordinate format for conversion to string. See the :py:class:`aspose.gis.NumericFormat` to get it.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self, variant : aspose.gis.geometries.WkbVariant) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :param variant: Well-Known Binary variant to use.
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def within(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry is within a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry is within extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def within(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is within a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially within" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry intersects a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry intersects the extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry intersects.
        
        :param other: A geometry.
        :returns: if this geometry "spatially intersects" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def to_editable(self) -> aspose.gis.common.formats.mapinfo.graphicalobjects.Point:
        '''Gets an editable copy of this geometry.
        
        :returns: An editable copy of this geometry.'''
        raise NotImplementedError()
    
    def replace_polygons_by_lines(self) -> aspose.gis.geometries.IGeometry:
        '''Gets polygons represented as lines of this geometry.
        
        :returns: A geometry, that has no polygon geometries. The following transformation are applied:
        
        *
        
        *'''
        raise NotImplementedError()
    
    def clone(self) -> aspose.gis.geometries.Geometry:
        '''Clones this instance.
        
        :returns: The clone of this instance'''
        raise NotImplementedError()
    
    def get_extent(self) -> aspose.gis.Extent:
        '''Computes and returns a bounding extent of this geometry.
        
        :returns: A bounding extent of this geometry.'''
        raise NotImplementedError()
    
    def get_area(self) -> float:
        '''Computes the area of this geometry.
        
        :returns: The area of this geometry.
        Sum of areas of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_length(self) -> float:
        '''Computes the length of this geometry.
        
        :returns: The length of this geometry.
        Perimeter if this is a :py:class:`aspose.gis.geometries.Polygon`.
        Sum of lengths of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_distance_to(self, other : aspose.gis.geometries.IGeometry) -> float:
        '''Computes the minimum distance between this geometry and a specified geometry.
        
        :param other: A geometry to find distance to.
        :returns: If both geometries are not :py:attr:`aspose.gis.geometries.IGeometry.is_empty` - a distance between closest points of the geometries.
        If at least one geometry is empty -1 is returned.'''
        raise NotImplementedError()
    
    def get_convex_hull(self) -> aspose.gis.geometries.IGeometry:
        '''Computes the convex hull of this geometry.
        
        :returns: A geometry that represents a convex hull of this geometry.
        If this geometry has no points then the result is :py:attr:`aspose.gis.geometries.Geometry.null`.
        If this geometry has only one point then the result is this point.
        If this geometry has only two points then the result is :py:class:`aspose.gis.geometries.ILineString` with the points.
        If this geometry has three or more points then the result is :py:class:`aspose.gis.geometries.ILinearRing` that represents a convex
        hull around all geometries points.'''
        raise NotImplementedError()
    
    def get_centroid(self) -> aspose.gis.geometries.IPoint:
        '''Computes the centroid of this geometry.
        
        :returns: The centroid of this geometry. If this geometry is empty an empty point returned.
        The centroid is equal to the centroid of the highest dimension geometries in this geometry
        (e.g. if both points and lines are contained in the geometry, only lines contribute to centroid).'''
        raise NotImplementedError()
    
    def get_buffer(self, distance : float, quadrant_segments : int) -> aspose.gis.geometries.IGeometry:
        '''Computes a buffer region around this geometry.
        
        :param distance: The buffer region width (in Spatial Reference units).
        :param quadrant_segments: Number of segments used to approximate a 90 degree of curvature.
        The larger this number is the better approximation of curves is produced.
        Default is 30.
        :returns: A geometry that represents all points that are within a specified distance from
        this geometry.
        The type of result is either :py:attr:`aspose.gis.geometries.Geometry.null`, :py:class:`aspose.gis.geometries.IPolygon` or :py:class:`aspose.gis.geometries.IMultiPolygon`.'''
        raise NotImplementedError()
    
    def spatially_equals(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry spatially equal to a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry "spatially equals" to specified geometry.  otherwise.'''
        raise NotImplementedError()
    
    def disjoint(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry is disjoint from a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially disjoint" from another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def touches(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry touch.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially touches" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def crosses(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry cross.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially crosses" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def spatially_contains(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry spatially contains a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially contains" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def overlaps(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry overlap with a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially overlaps" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covers(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry covers a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covers" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covered_by(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is covered by a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covered by" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def relate(self, other : aspose.gis.geometries.IGeometry, intersection_pattern_matrix : str) -> bool:
        '''Determines if DE-9IM intersection matrix of this geometry and a specified geometry matches provided pattern.
        
        :param other: A geometry.
        :param intersection_pattern_matrix: A patter to match with.
        This should be a string with length equal to 9.
        Each character of the string represent expected dimension of an intersection:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        Possible values of each characters are:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        For example, an intersection pattern "F0*******" means, that there should not be intersection between geometries interiors
        and intersection between geometries boundaries must be a point.
        See OpenGIS Simple Features Specification for more details about intersection matrix pattern.
        :returns: if this intersection matrix matches patter;  otherwise.'''
        raise NotImplementedError()
    
    def intersection(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds an intersection between this geometry and a specified geometry.
        
        :param other: A geometry to compute intersection with.
        :returns: A geometry that represents an intersection of this geometry and an argument. The result geometry contain
        point set that present in both this geometry and an argument.'''
        raise NotImplementedError()
    
    def union(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Unites this geometry and a specified geometry.
        
        :param other: A geometry to unite with.
        :returns: A geometry that represents a union of this geometry and an argument. The result geometry contains
        point set that present in this geometry or in an argument.'''
        raise NotImplementedError()
    
    def difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Subtracts a specified geometry from this geometry.
        
        :param other: A geometry to subtract.
        :returns: A geometry that represents a difference of this geometry and an argument. The result geometry contains
        point set that present in this geometry but not present in an argument.'''
        raise NotImplementedError()
    
    def sym_difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds a symmetric difference between this geometry and a specified geometry.
        
        :param other: A geometry to compute symmetric difference with.
        :returns: A geometry that represents a symmetric difference of this geometry and an argument. The result geometry contains
        point set that present in one of the geometries but not present in both of them.'''
        raise NotImplementedError()
    
    @property
    def x(self) -> float:
        '''Gets the x-coordinate.'''
        raise NotImplementedError()
    
    @property
    def y(self) -> float:
        '''Gets the y-coordinate.'''
        raise NotImplementedError()
    
    @property
    def z(self) -> float:
        '''Gets the z-coordinate.'''
        raise NotImplementedError()
    
    @property
    def m(self) -> float:
        '''Gets the m-coordinate.'''
        raise NotImplementedError()
    
    @property
    def geometry_type(self) -> aspose.gis.geometries.GeometryType:
        '''Gets the type of the geometry.'''
        raise NotImplementedError()
    
    @property
    def dimension(self) -> aspose.gis.geometries.GeometryDimension:
        '''Gets the topological dimension of this :py:class:`aspose.gis.geometries.IGeometry`.
        If the dimension is unknown (e.g. for an empty GEOMETRYCOLLECTION) :py:attr:`aspose.gis.geometries.GeometryDimension.POINT` is returned.'''
        raise NotImplementedError()
    
    @property
    def is_empty(self) -> bool:
        '''Gets a value indicating whether this instance is empty (represents the empty point set).'''
        raise NotImplementedError()
    
    @property
    def is_simple(self) -> bool:
        '''Gets a value indicating whether this instance is simple from SFA point of view.'''
        raise NotImplementedError()
    
    @property
    def is_valid(self) -> bool:
        '''Gets a value indicating whether this instance is valid.'''
        raise NotImplementedError()
    
    @property
    def has_m(self) -> bool:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_z(self) -> bool:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @property
    def spatial_reference_system(self) -> aspose.gis.spatialreferencing.SpatialReferenceSystem:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , if SpatialReferenceSystem is unknown.'''
        raise NotImplementedError()
    
    @property
    def has_curve_geometry(self) -> bool:
        '''Gets a value indicating whether this geometry is or contains curve (not linear) geometry.'''
        raise NotImplementedError()
    

class IPolygon(ICurvePolygon):
    '''A :py:class:`aspose.gis.geometries.IPolygon` whose boundaries are defined by linear rings.'''
    
    @overload
    def to_linear_geometry(self) -> aspose.gis.geometries.IPolygon:
        '''Gets approximate or equivalent non-curve version of this geometry using the default ``tolerance``.
        
        :returns: A :py:class:`aspose.gis.geometries.IPolygon` that approximates or equivalent to this ``ISurface``.
        This is the equivalent of :py:func:`aspose.gis.geometries.ISurface.to_linear_geometry` with
        default ``tolerance``. Default ``tolerance``s value is dependent on :py:class:`aspose.gis.spatialreferencing.SpatialReferenceSystem`
        of this geometry:
        
        *
        
        *
        
        *
        
        For more details on what transformations are applied refer to :py:func:`aspose.gis.geometries.ISurface.to_linear_geometry` specification.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self, tolerance : float) -> aspose.gis.geometries.IPolygon:
        '''Gets approximate or equivalent non-curve version of this geometry using the specified ``tolerance``.
        
        :param tolerance: The ``tolerance`` to use. The result is guaranteed to be less than ``tolerance`` away from the
        curved geometry, unless the number of points needed to linearize the geometry exceeds the per-quadrant maximum,
        currently equal to 10000 points.
        :returns: A :py:class:`aspose.gis.geometries.IPolygon` that approximates or equivalent to this ``ISurface``:
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : aspose.gis.AbstractPath, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : str, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> io.RawIOBase:
        '''Export this geometry to an image representation.
        
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.
        :returns: The image as stream'''
        raise NotImplementedError()
    
    @overload
    def as_text(self) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant, format : aspose.gis.NumericFormat) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :param format: Coordinate format for conversion to string. See the :py:class:`aspose.gis.NumericFormat` to get it.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self, variant : aspose.gis.geometries.WkbVariant) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :param variant: Well-Known Binary variant to use.
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def within(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry is within a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry is within extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def within(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is within a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially within" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry intersects a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry intersects the extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry intersects.
        
        :param other: A geometry.
        :returns: if this geometry "spatially intersects" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def get_interior_ring(self, index : int) -> aspose.gis.geometries.ILinearRing:
        '''Gets the interior ring by its index.
        
        :param index: The index.
        :returns: The interior ring.'''
        raise NotImplementedError()
    
    def to_editable(self) -> aspose.gis.common.formats.mapinfo.graphicalobjects.Polygon:
        '''Gets an editable copy of this geometry.
        
        :returns: An editable copy of this geometry.'''
        raise NotImplementedError()
    
    def get_point_on_surface(self) -> aspose.gis.geometries.IPoint:
        '''Finds a point that is guaranteed to be on this surface.
        
        :returns: A point on this surface. An empty point if this surface has no interior.'''
        raise NotImplementedError()
    
    def replace_polygons_by_lines(self) -> aspose.gis.geometries.IGeometry:
        '''Gets polygons represented as lines of this geometry.
        
        :returns: A geometry, that has no polygon geometries. The following transformation are applied:
        
        *
        
        *'''
        raise NotImplementedError()
    
    def clone(self) -> aspose.gis.geometries.Geometry:
        '''Clones this instance.
        
        :returns: The clone of this instance'''
        raise NotImplementedError()
    
    def get_extent(self) -> aspose.gis.Extent:
        '''Computes and returns a bounding extent of this geometry.
        
        :returns: A bounding extent of this geometry.'''
        raise NotImplementedError()
    
    def get_area(self) -> float:
        '''Computes the area of this geometry.
        
        :returns: The area of this geometry.
        Sum of areas of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_length(self) -> float:
        '''Computes the length of this geometry.
        
        :returns: The length of this geometry.
        Perimeter if this is a :py:class:`aspose.gis.geometries.Polygon`.
        Sum of lengths of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_distance_to(self, other : aspose.gis.geometries.IGeometry) -> float:
        '''Computes the minimum distance between this geometry and a specified geometry.
        
        :param other: A geometry to find distance to.
        :returns: If both geometries are not :py:attr:`aspose.gis.geometries.IGeometry.is_empty` - a distance between closest points of the geometries.
        If at least one geometry is empty -1 is returned.'''
        raise NotImplementedError()
    
    def get_convex_hull(self) -> aspose.gis.geometries.IGeometry:
        '''Computes the convex hull of this geometry.
        
        :returns: A geometry that represents a convex hull of this geometry.
        If this geometry has no points then the result is :py:attr:`aspose.gis.geometries.Geometry.null`.
        If this geometry has only one point then the result is this point.
        If this geometry has only two points then the result is :py:class:`aspose.gis.geometries.ILineString` with the points.
        If this geometry has three or more points then the result is :py:class:`aspose.gis.geometries.ILinearRing` that represents a convex
        hull around all geometries points.'''
        raise NotImplementedError()
    
    def get_centroid(self) -> aspose.gis.geometries.IPoint:
        '''Computes the centroid of this geometry.
        
        :returns: The centroid of this geometry. If this geometry is empty an empty point returned.
        The centroid is equal to the centroid of the highest dimension geometries in this geometry
        (e.g. if both points and lines are contained in the geometry, only lines contribute to centroid).'''
        raise NotImplementedError()
    
    def get_buffer(self, distance : float, quadrant_segments : int) -> aspose.gis.geometries.IGeometry:
        '''Computes a buffer region around this geometry.
        
        :param distance: The buffer region width (in Spatial Reference units).
        :param quadrant_segments: Number of segments used to approximate a 90 degree of curvature.
        The larger this number is the better approximation of curves is produced.
        Default is 30.
        :returns: A geometry that represents all points that are within a specified distance from
        this geometry.
        The type of result is either :py:attr:`aspose.gis.geometries.Geometry.null`, :py:class:`aspose.gis.geometries.IPolygon` or :py:class:`aspose.gis.geometries.IMultiPolygon`.'''
        raise NotImplementedError()
    
    def spatially_equals(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry spatially equal to a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry "spatially equals" to specified geometry.  otherwise.'''
        raise NotImplementedError()
    
    def disjoint(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry is disjoint from a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially disjoint" from another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def touches(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry touch.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially touches" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def crosses(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry cross.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially crosses" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def spatially_contains(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry spatially contains a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially contains" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def overlaps(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry overlap with a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially overlaps" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covers(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry covers a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covers" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covered_by(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is covered by a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covered by" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def relate(self, other : aspose.gis.geometries.IGeometry, intersection_pattern_matrix : str) -> bool:
        '''Determines if DE-9IM intersection matrix of this geometry and a specified geometry matches provided pattern.
        
        :param other: A geometry.
        :param intersection_pattern_matrix: A patter to match with.
        This should be a string with length equal to 9.
        Each character of the string represent expected dimension of an intersection:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        Possible values of each characters are:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        For example, an intersection pattern "F0*******" means, that there should not be intersection between geometries interiors
        and intersection between geometries boundaries must be a point.
        See OpenGIS Simple Features Specification for more details about intersection matrix pattern.
        :returns: if this intersection matrix matches patter;  otherwise.'''
        raise NotImplementedError()
    
    def intersection(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds an intersection between this geometry and a specified geometry.
        
        :param other: A geometry to compute intersection with.
        :returns: A geometry that represents an intersection of this geometry and an argument. The result geometry contain
        point set that present in both this geometry and an argument.'''
        raise NotImplementedError()
    
    def union(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Unites this geometry and a specified geometry.
        
        :param other: A geometry to unite with.
        :returns: A geometry that represents a union of this geometry and an argument. The result geometry contains
        point set that present in this geometry or in an argument.'''
        raise NotImplementedError()
    
    def difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Subtracts a specified geometry from this geometry.
        
        :param other: A geometry to subtract.
        :returns: A geometry that represents a difference of this geometry and an argument. The result geometry contains
        point set that present in this geometry but not present in an argument.'''
        raise NotImplementedError()
    
    def sym_difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds a symmetric difference between this geometry and a specified geometry.
        
        :param other: A geometry to compute symmetric difference with.
        :returns: A geometry that represents a symmetric difference of this geometry and an argument. The result geometry contains
        point set that present in one of the geometries but not present in both of them.'''
        raise NotImplementedError()
    
    @property
    def exterior_ring(self) -> aspose.gis.geometries.ILinearRing:
        '''Gets the exterior ring.'''
        raise NotImplementedError()
    
    @property
    def interior_rings_count(self) -> int:
        '''Gets the number of interior rings.'''
        raise NotImplementedError()
    
    @property
    def geometry_type(self) -> aspose.gis.geometries.GeometryType:
        '''Gets the type of the geometry.'''
        raise NotImplementedError()
    
    @property
    def dimension(self) -> aspose.gis.geometries.GeometryDimension:
        '''Gets the topological dimension of this :py:class:`aspose.gis.geometries.IGeometry`.
        If the dimension is unknown (e.g. for an empty GEOMETRYCOLLECTION) :py:attr:`aspose.gis.geometries.GeometryDimension.POINT` is returned.'''
        raise NotImplementedError()
    
    @property
    def is_empty(self) -> bool:
        '''Gets a value indicating whether this instance is empty (represents the empty point set).'''
        raise NotImplementedError()
    
    @property
    def is_simple(self) -> bool:
        '''Gets a value indicating whether this instance is simple from SFA point of view.'''
        raise NotImplementedError()
    
    @property
    def is_valid(self) -> bool:
        '''Gets a value indicating whether this instance is valid.'''
        raise NotImplementedError()
    
    @property
    def has_m(self) -> bool:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_z(self) -> bool:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @property
    def spatial_reference_system(self) -> aspose.gis.spatialreferencing.SpatialReferenceSystem:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , if SpatialReferenceSystem is unknown.'''
        raise NotImplementedError()
    
    @property
    def has_curve_geometry(self) -> bool:
        '''Gets a value indicating whether this geometry is or contains curve (not linear) geometry.'''
        raise NotImplementedError()
    

class ISurface(IGeometry):
    '''A :py:class:`aspose.gis.geometries.ISurface` is a two-dimensional geometric object.'''
    
    @overload
    def to_linear_geometry(self) -> aspose.gis.geometries.IPolygon:
        '''Gets approximate or equivalent non-curve version of this geometry using the default ``tolerance``.
        
        :returns: A :py:class:`aspose.gis.geometries.IPolygon` that approximates or equivalent to this ``ISurface``.
        This is the equivalent of :py:func:`aspose.gis.geometries.ISurface.to_linear_geometry` with
        default ``tolerance``. Default ``tolerance``s value is dependent on :py:class:`aspose.gis.spatialreferencing.SpatialReferenceSystem`
        of this geometry:
        
        *
        
        *
        
        *
        
        For more details on what transformations are applied refer to :py:func:`aspose.gis.geometries.ISurface.to_linear_geometry` specification.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self, tolerance : float) -> aspose.gis.geometries.IPolygon:
        '''Gets approximate or equivalent non-curve version of this geometry using the specified ``tolerance``.
        
        :param tolerance: The ``tolerance`` to use. The result is guaranteed to be less than ``tolerance`` away from the
        curved geometry, unless the number of points needed to linearize the geometry exceeds the per-quadrant maximum,
        currently equal to 10000 points.
        :returns: A :py:class:`aspose.gis.geometries.IPolygon` that approximates or equivalent to this ``ISurface``:
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : aspose.gis.AbstractPath, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : str, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> io.RawIOBase:
        '''Export this geometry to an image representation.
        
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.
        :returns: The image as stream'''
        raise NotImplementedError()
    
    @overload
    def as_text(self) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant, format : aspose.gis.NumericFormat) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :param format: Coordinate format for conversion to string. See the :py:class:`aspose.gis.NumericFormat` to get it.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self, variant : aspose.gis.geometries.WkbVariant) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :param variant: Well-Known Binary variant to use.
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def within(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry is within a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry is within extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def within(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is within a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially within" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry intersects a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry intersects the extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry intersects.
        
        :param other: A geometry.
        :returns: if this geometry "spatially intersects" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def get_point_on_surface(self) -> aspose.gis.geometries.IPoint:
        '''Finds a point that is guaranteed to be on this surface.
        
        :returns: A point on this surface. An empty point if this surface has no interior.'''
        raise NotImplementedError()
    
    def to_editable(self) -> aspose.gis.geometries.Surface:
        '''Gets an editable copy of this geometry.
        
        :returns: An editable copy of this geometry.'''
        raise NotImplementedError()
    
    def replace_polygons_by_lines(self) -> aspose.gis.geometries.IGeometry:
        '''Gets polygons represented as lines of this geometry.
        
        :returns: A geometry, that has no polygon geometries. The following transformation are applied:
        
        *
        
        *'''
        raise NotImplementedError()
    
    def clone(self) -> aspose.gis.geometries.Geometry:
        '''Clones this instance.
        
        :returns: The clone of this instance'''
        raise NotImplementedError()
    
    def get_extent(self) -> aspose.gis.Extent:
        '''Computes and returns a bounding extent of this geometry.
        
        :returns: A bounding extent of this geometry.'''
        raise NotImplementedError()
    
    def get_area(self) -> float:
        '''Computes the area of this geometry.
        
        :returns: The area of this geometry.
        Sum of areas of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_length(self) -> float:
        '''Computes the length of this geometry.
        
        :returns: The length of this geometry.
        Perimeter if this is a :py:class:`aspose.gis.geometries.Polygon`.
        Sum of lengths of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_distance_to(self, other : aspose.gis.geometries.IGeometry) -> float:
        '''Computes the minimum distance between this geometry and a specified geometry.
        
        :param other: A geometry to find distance to.
        :returns: If both geometries are not :py:attr:`aspose.gis.geometries.IGeometry.is_empty` - a distance between closest points of the geometries.
        If at least one geometry is empty -1 is returned.'''
        raise NotImplementedError()
    
    def get_convex_hull(self) -> aspose.gis.geometries.IGeometry:
        '''Computes the convex hull of this geometry.
        
        :returns: A geometry that represents a convex hull of this geometry.
        If this geometry has no points then the result is :py:attr:`aspose.gis.geometries.Geometry.null`.
        If this geometry has only one point then the result is this point.
        If this geometry has only two points then the result is :py:class:`aspose.gis.geometries.ILineString` with the points.
        If this geometry has three or more points then the result is :py:class:`aspose.gis.geometries.ILinearRing` that represents a convex
        hull around all geometries points.'''
        raise NotImplementedError()
    
    def get_centroid(self) -> aspose.gis.geometries.IPoint:
        '''Computes the centroid of this geometry.
        
        :returns: The centroid of this geometry. If this geometry is empty an empty point returned.
        The centroid is equal to the centroid of the highest dimension geometries in this geometry
        (e.g. if both points and lines are contained in the geometry, only lines contribute to centroid).'''
        raise NotImplementedError()
    
    def get_buffer(self, distance : float, quadrant_segments : int) -> aspose.gis.geometries.IGeometry:
        '''Computes a buffer region around this geometry.
        
        :param distance: The buffer region width (in Spatial Reference units).
        :param quadrant_segments: Number of segments used to approximate a 90 degree of curvature.
        The larger this number is the better approximation of curves is produced.
        Default is 30.
        :returns: A geometry that represents all points that are within a specified distance from
        this geometry.
        The type of result is either :py:attr:`aspose.gis.geometries.Geometry.null`, :py:class:`aspose.gis.geometries.IPolygon` or :py:class:`aspose.gis.geometries.IMultiPolygon`.'''
        raise NotImplementedError()
    
    def spatially_equals(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry spatially equal to a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry "spatially equals" to specified geometry.  otherwise.'''
        raise NotImplementedError()
    
    def disjoint(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry is disjoint from a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially disjoint" from another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def touches(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry touch.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially touches" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def crosses(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry cross.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially crosses" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def spatially_contains(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry spatially contains a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially contains" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def overlaps(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry overlap with a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially overlaps" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covers(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry covers a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covers" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covered_by(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is covered by a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covered by" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def relate(self, other : aspose.gis.geometries.IGeometry, intersection_pattern_matrix : str) -> bool:
        '''Determines if DE-9IM intersection matrix of this geometry and a specified geometry matches provided pattern.
        
        :param other: A geometry.
        :param intersection_pattern_matrix: A patter to match with.
        This should be a string with length equal to 9.
        Each character of the string represent expected dimension of an intersection:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        Possible values of each characters are:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        For example, an intersection pattern "F0*******" means, that there should not be intersection between geometries interiors
        and intersection between geometries boundaries must be a point.
        See OpenGIS Simple Features Specification for more details about intersection matrix pattern.
        :returns: if this intersection matrix matches patter;  otherwise.'''
        raise NotImplementedError()
    
    def intersection(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds an intersection between this geometry and a specified geometry.
        
        :param other: A geometry to compute intersection with.
        :returns: A geometry that represents an intersection of this geometry and an argument. The result geometry contain
        point set that present in both this geometry and an argument.'''
        raise NotImplementedError()
    
    def union(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Unites this geometry and a specified geometry.
        
        :param other: A geometry to unite with.
        :returns: A geometry that represents a union of this geometry and an argument. The result geometry contains
        point set that present in this geometry or in an argument.'''
        raise NotImplementedError()
    
    def difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Subtracts a specified geometry from this geometry.
        
        :param other: A geometry to subtract.
        :returns: A geometry that represents a difference of this geometry and an argument. The result geometry contains
        point set that present in this geometry but not present in an argument.'''
        raise NotImplementedError()
    
    def sym_difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds a symmetric difference between this geometry and a specified geometry.
        
        :param other: A geometry to compute symmetric difference with.
        :returns: A geometry that represents a symmetric difference of this geometry and an argument. The result geometry contains
        point set that present in one of the geometries but not present in both of them.'''
        raise NotImplementedError()
    
    @property
    def geometry_type(self) -> aspose.gis.geometries.GeometryType:
        '''Gets the type of the geometry.'''
        raise NotImplementedError()
    
    @property
    def dimension(self) -> aspose.gis.geometries.GeometryDimension:
        '''Gets the topological dimension of this :py:class:`aspose.gis.geometries.IGeometry`.
        If the dimension is unknown (e.g. for an empty GEOMETRYCOLLECTION) :py:attr:`aspose.gis.geometries.GeometryDimension.POINT` is returned.'''
        raise NotImplementedError()
    
    @property
    def is_empty(self) -> bool:
        '''Gets a value indicating whether this instance is empty (represents the empty point set).'''
        raise NotImplementedError()
    
    @property
    def is_simple(self) -> bool:
        '''Gets a value indicating whether this instance is simple from SFA point of view.'''
        raise NotImplementedError()
    
    @property
    def is_valid(self) -> bool:
        '''Gets a value indicating whether this instance is valid.'''
        raise NotImplementedError()
    
    @property
    def has_m(self) -> bool:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_z(self) -> bool:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @property
    def spatial_reference_system(self) -> aspose.gis.spatialreferencing.SpatialReferenceSystem:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , if SpatialReferenceSystem is unknown.'''
        raise NotImplementedError()
    
    @property
    def has_curve_geometry(self) -> bool:
        '''Gets a value indicating whether this geometry is or contains curve (not linear) geometry.'''
        raise NotImplementedError()
    

class LineString(Curve):
    '''A multi-vertex line.'''
    
    @overload
    @staticmethod
    def from_text(wkt : str) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Text representation.
        
        :param wkt: Well-Known Text representation of a geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_text(wkt : str, spatial_reference_system : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Text representation.
        
        :param wkt: Well-Known Text representation of a geometry.
        :param spatial_reference_system: Spatial Reference System to be assigned to the geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_binary(wkb : List[int]) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Binary representation.
        
        :param wkb: Well-Known Binary representation of a geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_binary(wkb : List[int], spatial_reference_system : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Binary representation.
        
        :param wkb: Well-Known Binary representation of a geometry.
        :param spatial_reference_system: Spatial Reference System to be assigned to the geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self) -> aspose.gis.geometries.ILineString:
        '''Gets approximate or equivalent non-curve version of this geometry using the default ``tolerance``.
        
        :returns: A :py:class:`aspose.gis.geometries.ILineString` that approximates or equivalent to this curve.
        This is the equivalent of :py:func:`aspose.gis.geometries.ICurve.to_linear_geometry` with
        default ``tolerance``. Default ``tolerance``s value is dependent on :py:class:`aspose.gis.spatialreferencing.SpatialReferenceSystem`
        of this geometry:
        
        *
        
        *
        
        *
        
        For more details on what transformations are applied refer to :py:func:`aspose.gis.geometries.ICurve.to_linear_geometry` specification.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self, tolerance : float) -> aspose.gis.geometries.ILineString:
        '''Gets approximate or equivalent non-curve version of this geometry using the specified ``tolerance``.
        
        :param tolerance: The ``tolerance`` to use. The result is guaranteed to be less than ``tolerance`` away from the
        curved geometry, unless the number of points needed to linearize the geometry exceeds the per-quadrant maximum,
        currently equal to 10000 points.
        :returns: A :py:class:`aspose.gis.geometries.ILineString` that approximates or equivalent to this curve:
        
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : aspose.gis.AbstractPath, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : str, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> io.RawIOBase:
        '''Export this geometry to an image representation.
        
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.
        :returns: The image as stream'''
        raise NotImplementedError()
    
    @overload
    def as_text(self) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant, format : aspose.gis.NumericFormat) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :param format: Coordinate format for conversion to string. See the :py:class:`aspose.gis.NumericFormat` to get it.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self, variant : aspose.gis.geometries.WkbVariant) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :param variant: Well-Known Binary variant to use.
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def within(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry is within a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry is within extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def within(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is within a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially within" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry intersects a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry intersects the extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry intersects.
        
        :param other: A geometry.
        :returns: if this geometry "spatially intersects" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def add_point(self, point : aspose.gis.geometries.IPoint) -> None:
        '''Adds a point to the end of the line.
        
        :param point: The point to add.'''
        raise NotImplementedError()
    
    @overload
    def add_point(self, x : float, y : float) -> None:
        '''Adds a point to the end of the line.
        
        :param x: The value for X coordinate.
        :param y: The value for Y coordinate.'''
        raise NotImplementedError()
    
    @overload
    def add_point(self, x : float, y : float, z : float) -> None:
        '''Adds a point to the end of the line.
        
        :param x: The value for X coordinate.
        :param y: The value for Y coordinate.
        :param z: The value for Z coordinate.'''
        raise NotImplementedError()
    
    @overload
    def add_point(self, x : float, y : float, z : float, m : float) -> None:
        '''Adds a point to the end of the line.
        
        :param x: The value for X coordinate.
        :param y: The value for Y coordinate.
        :param z: The value for Z coordinate.
        :param m: The value for M coordinate.'''
        raise NotImplementedError()
    
    def to_editable(self) -> aspose.gis.geometries.LineString:
        '''Gets an editable copy of this geometry.
        
        :returns: An editable copy of this geometry.'''
        raise NotImplementedError()
    
    def replace_polygons_by_lines(self) -> aspose.gis.geometries.IGeometry:
        '''Gets polygons represented as lines of this geometry.
        
        :returns: A geometry, that has no polygon geometries. The following transformation are applied:
        
        *
        
        *'''
        raise NotImplementedError()
    
    def to_svg(self, extent : aspose.gis.Extent) -> str:
        '''Translates this geometry to Svg representation.
        
        :param extent: Extent for translation this geometry to Svg
        :returns: The Svg representation.'''
        raise NotImplementedError()
    
    def set_empty(self) -> None:
        '''Makes this :py:class:`aspose.gis.geometries.Geometry` empty.'''
        raise NotImplementedError()
    
    def clone(self) -> aspose.gis.geometries.Geometry:
        '''Clones this instance.
        
        :returns: The clone of this instance'''
        raise NotImplementedError()
    
    def round_xy(self, digits : int) -> None:
        '''Rounds X and Y coordinates to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def round_z(self, digits : int) -> None:
        '''Rounds Z coordinate to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def round_m(self, digits : int) -> None:
        '''Rounds M coordinate to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def get_extent(self) -> aspose.gis.Extent:
        '''Computes and returns a bounding extent of this geometry.
        
        :returns: A bounding extent of this geometry.'''
        raise NotImplementedError()
    
    def get_area(self) -> float:
        '''Computes the area of this geometry.
        
        :returns: The area of this geometry.
        Sum of areas of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_length(self) -> float:
        '''Computes the length of this geometry.
        
        :returns: The length of this geometry.
        Perimeter if this is a :py:class:`aspose.gis.geometries.Polygon`.
        Sum of lengths of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_distance_to(self, other : aspose.gis.geometries.IGeometry) -> float:
        '''Computes the minimum distance between this geometry and a specified geometry.
        
        :param other: A geometry to find distance to.
        :returns: If both geometries are not :py:attr:`aspose.gis.geometries.Geometry.is_empty` - a distance between closest points of the geometries.
        If at least one geometry is empty -1 is returned.'''
        raise NotImplementedError()
    
    def get_convex_hull(self) -> aspose.gis.geometries.IGeometry:
        '''Computes the convex hull of this geometry.
        
        :returns: A geometry that represents a convex hull of this geometry.
        If this geometry has no points then the result is :py:attr:`aspose.gis.geometries.Geometry.null`.
        If this geometry has only one point then the result is this point.
        If this geometry has only two points then the result is :py:class:`aspose.gis.geometries.ILineString` with the points.
        If this geometry has three or more points then the result is :py:class:`aspose.gis.geometries.ILinearRing` that represents a convex
        hull around all geometries points.'''
        raise NotImplementedError()
    
    def get_centroid(self) -> aspose.gis.geometries.IPoint:
        '''Computes the centroid of this geometry.
        
        :returns: The centroid of this geometry. If this geometry is empty an empty point returned.
        The centroid is equal to the centroid of the highest dimension geometries in this geometry
        (e.g. if both points and lines are contained in the geometry, only lines contribute to centroid).'''
        raise NotImplementedError()
    
    def get_buffer(self, distance : float, quadrant_segments : int) -> aspose.gis.geometries.IGeometry:
        '''Computes a buffer region around this geometry.
        
        :param distance: The buffer region width.
        :param quadrant_segments: Number of segments used to approximate a 90 degree of curvature.
        The larger this number is the better approximation of curves is produced.
        Default is 30.
        :returns: A geometry that represents all points that are within a specified distance from
        this geometry.
        The type of result is either :py:attr:`aspose.gis.geometries.Geometry.null`, :py:class:`aspose.gis.geometries.IPolygon` or :py:class:`aspose.gis.geometries.IMultiPolygon`.'''
        raise NotImplementedError()
    
    def spatially_equals(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry spatially equal to a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry "spatially equals" to specified geometry.  otherwise.'''
        raise NotImplementedError()
    
    def disjoint(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry is disjoint from a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially disjoint" from another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def touches(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry touch.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially touches" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def crosses(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry cross.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially crosses" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def spatially_contains(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry spatially contains a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially contains" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def overlaps(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry overlap with a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially overlaps" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covers(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry covers a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covers" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covered_by(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is covered by a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covered by" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def relate(self, other : aspose.gis.geometries.IGeometry, intersection_pattern_matrix : str) -> bool:
        '''Determines if DE-9IM intersection matrix of this geometry and a specified geometry matches provided pattern.
        
        :param other: A geometry.
        :param intersection_pattern_matrix: A patter to match with.
        This should be a string with length equal to 9.
        Each character of the string represent expected dimension of an intersection:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        Possible values of each characters are:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        For example, an intersection pattern "F0*******" means, that there should not be intersection between geometries interiors
        and intersection between geometries boundaries must be a point.
        See OpenGIS Simple Features Specification for more details about intersection matrix pattern.
        :returns: if this intersection matrix matches patter;  otherwise.'''
        raise NotImplementedError()
    
    def intersection(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds an intersection between this geometry and a specified geometry.
        
        :param other: A geometry to compute intersection with.
        :returns: A geometry that represents an intersection of this geometry and an argument. The result geometry contain
        point set that present in both this geometry and an argument.'''
        raise NotImplementedError()
    
    def union(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Unites this geometry and a specified geometry.
        
        :param other: A geometry to unite with.
        :returns: A geometry that represents a union of this geometry and an argument. The result geometry contains
        point set that present in this geometry or in an argument.'''
        raise NotImplementedError()
    
    def difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Subtracts a specified geometry from this geometry.
        
        :param other: A geometry to subtract.
        :returns: A geometry that represents a difference of this geometry and an argument. The result geometry contains
        point set that present in this geometry but not present in an argument.'''
        raise NotImplementedError()
    
    def sym_difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds a symmetric difference between this geometry and a specified geometry.
        
        :param other: A geometry to compute symmetric difference with.
        :returns: A geometry that represents a symmetric difference of this geometry and an argument. The result geometry contains
        point set that present in one of the geometries but not present in both of them.'''
        raise NotImplementedError()
    
    def reverse(self) -> None:
        '''Reverses order of points in this :py:class:`aspose.gis.geometries.LineString`.'''
        raise NotImplementedError()
    
    def equals(self, other : aspose.gis.geometries.ILineString) -> bool:
        '''Indicates whether the current object is equal to another object of the same type.
        
        :param other: An object to compare with this object.
        :returns: true if the current object is equal to the ``other`` parameter; otherwise, false.'''
        raise NotImplementedError()
    
    @property
    def dimension(self) -> aspose.gis.geometries.GeometryDimension:
        '''Gets the topological dimension of this :py:class:`aspose.gis.geometries.Geometry`.'''
        raise NotImplementedError()
    
    null : aspose.gis.geometries.IGeometry
    '''Gets an instance of null geometry.'''
    @property
    def coordinate_dimension(self) -> int:
        '''Gets the number of coordinate dimensions for this :py:class:`aspose.gis.geometries.Geometry`.'''
        raise NotImplementedError()
    
    @property
    def is_empty(self) -> bool:
        '''Gets a value indicating whether this instance is empty.'''
        raise NotImplementedError()
    
    @property
    def is_simple(self) -> bool:
        '''Gets a value indicating whether this instance is simple from SFA point of view.'''
        raise NotImplementedError()
    
    @property
    def is_valid(self) -> bool:
        '''Gets a value indicating whether this instance is valid.'''
        raise NotImplementedError()
    
    @property
    def has_m(self) -> bool:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @has_m.setter
    def has_m(self, value : bool) -> None:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_z(self) -> bool:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @has_z.setter
    def has_z(self, value : bool) -> None:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_curve_geometry(self) -> bool:
        '''Gets a value indicating whether this geometry is or contains curve (not linear) geometry.'''
        raise NotImplementedError()
    
    @property
    def geometry_type(self) -> aspose.gis.geometries.GeometryType:
        '''Gets the type of the geometry.'''
        raise NotImplementedError()
    
    @property
    def spatial_reference_system(self) -> aspose.gis.spatialreferencing.SpatialReferenceSystem:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , if SpatialReferenceSystem is unset.
        Assigning new SpatialReferenceSystem will not perform any coordinate transformation, only reference will change.'''
        raise NotImplementedError()
    
    @spatial_reference_system.setter
    def spatial_reference_system(self, value : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> None:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , if SpatialReferenceSystem is unset.
        Assigning new SpatialReferenceSystem will not perform any coordinate transformation, only reference will change.'''
        raise NotImplementedError()
    
    @property
    def start_point(self) -> aspose.gis.geometries.IPoint:
        '''Returns a copy of the starting point of the curve.'''
        raise NotImplementedError()
    
    @property
    def end_point(self) -> aspose.gis.geometries.IPoint:
        '''Returns a copy of the end point of the curve.'''
        raise NotImplementedError()
    
    @property
    def is_closed(self) -> bool:
        '''Gets a values indicating whether a curve is closed.
        A curve is closed if its start point is equal to its end point.'''
        raise NotImplementedError()
    
    def __getitem__(self, key : int) -> aspose.gis.geometries.IPoint:
        '''Gets or sets the :py:class:`aspose.gis.geometries.IPoint` at the specified index.'''
        raise NotImplementedError()
    
    def __setitem__(self, key : int, value : aspose.gis.geometries.IPoint):
        raise NotImplementedError()
    

class LinearRing(LineString):
    '''A :py:class:`aspose.gis.geometries.LinearRing` is a :py:class:`aspose.gis.geometries.LineString` that is both closed and simple.'''
    
    @overload
    @staticmethod
    def from_text(wkt : str) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Text representation.
        
        :param wkt: Well-Known Text representation of a geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_text(wkt : str, spatial_reference_system : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Text representation.
        
        :param wkt: Well-Known Text representation of a geometry.
        :param spatial_reference_system: Spatial Reference System to be assigned to the geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_binary(wkb : List[int]) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Binary representation.
        
        :param wkb: Well-Known Binary representation of a geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_binary(wkb : List[int], spatial_reference_system : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Binary representation.
        
        :param wkb: Well-Known Binary representation of a geometry.
        :param spatial_reference_system: Spatial Reference System to be assigned to the geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self) -> aspose.gis.geometries.ILineString:
        '''Gets approximate or equivalent non-curve version of this geometry using the default ``tolerance``.
        
        :returns: A :py:class:`aspose.gis.geometries.ILineString` that approximates or equivalent to this curve.
        This is the equivalent of :py:func:`aspose.gis.geometries.ICurve.to_linear_geometry` with
        default ``tolerance``. Default ``tolerance``s value is dependent on :py:class:`aspose.gis.spatialreferencing.SpatialReferenceSystem`
        of this geometry:
        
        *
        
        *
        
        *
        
        For more details on what transformations are applied refer to :py:func:`aspose.gis.geometries.ICurve.to_linear_geometry` specification.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self, tolerance : float) -> aspose.gis.geometries.ILineString:
        '''Gets approximate or equivalent non-curve version of this geometry using the specified ``tolerance``.
        
        :param tolerance: The ``tolerance`` to use. The result is guaranteed to be less than ``tolerance`` away from the
        curved geometry, unless the number of points needed to linearize the geometry exceeds the per-quadrant maximum,
        currently equal to 10000 points.
        :returns: A :py:class:`aspose.gis.geometries.ILineString` that approximates or equivalent to this curve:
        
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`
        If this object is :py:class:`aspose.gis.geometries.ILineString` itself the result is equivalent to this object
        If this object is :py:class:`aspose.gis.geometries.ICircularString` the result is the circular string linearized with the specified ``tolerance``
        If this object is :py:class:`aspose.gis.geometries.ICompoundCurve` - all curves from it are linearized and then joined into :py:class:`aspose.gis.geometries.ILineString`'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : aspose.gis.AbstractPath, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : str, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> io.RawIOBase:
        '''Export this geometry to an image representation.
        
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.
        :returns: The image as stream'''
        raise NotImplementedError()
    
    @overload
    def as_text(self) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant, format : aspose.gis.NumericFormat) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :param format: Coordinate format for conversion to string. See the :py:class:`aspose.gis.NumericFormat` to get it.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self, variant : aspose.gis.geometries.WkbVariant) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :param variant: Well-Known Binary variant to use.
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def within(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry is within a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry is within extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def within(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is within a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially within" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry intersects a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry intersects the extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry intersects.
        
        :param other: A geometry.
        :returns: if this geometry "spatially intersects" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def add_point(self, point : aspose.gis.geometries.IPoint) -> None:
        '''Adds a point to the end of the line.
        
        :param point: The point to add.'''
        raise NotImplementedError()
    
    @overload
    def add_point(self, x : float, y : float) -> None:
        '''Adds a point to the end of the line.
        
        :param x: The value for X coordinate.
        :param y: The value for Y coordinate.'''
        raise NotImplementedError()
    
    @overload
    def add_point(self, x : float, y : float, z : float) -> None:
        '''Adds a point to the end of the line.
        
        :param x: The value for X coordinate.
        :param y: The value for Y coordinate.
        :param z: The value for Z coordinate.'''
        raise NotImplementedError()
    
    @overload
    def add_point(self, x : float, y : float, z : float, m : float) -> None:
        '''Adds a point to the end of the line.
        
        :param x: The value for X coordinate.
        :param y: The value for Y coordinate.
        :param z: The value for Z coordinate.
        :param m: The value for M coordinate.'''
        raise NotImplementedError()
    
    def to_editable(self) -> aspose.gis.geometries.LinearRing:
        '''Gets an editable copy of this geometry.
        
        :returns: An editable copy of this geometry.'''
        raise NotImplementedError()
    
    def replace_polygons_by_lines(self) -> aspose.gis.geometries.IGeometry:
        '''Gets polygons represented as lines of this geometry.
        
        :returns: A geometry, that has no polygon geometries. The following transformation are applied:
        
        *
        
        *'''
        raise NotImplementedError()
    
    def to_svg(self, extent : aspose.gis.Extent) -> str:
        '''Translates this geometry to Svg representation.
        
        :param extent: Extent for translation this geometry to Svg
        :returns: The Svg representation.'''
        raise NotImplementedError()
    
    def set_empty(self) -> None:
        '''Makes this :py:class:`aspose.gis.geometries.Geometry` empty.'''
        raise NotImplementedError()
    
    def clone(self) -> aspose.gis.geometries.Geometry:
        '''Clones this instance.
        
        :returns: The clone of this instance'''
        raise NotImplementedError()
    
    def round_xy(self, digits : int) -> None:
        '''Rounds X and Y coordinates to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def round_z(self, digits : int) -> None:
        '''Rounds Z coordinate to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def round_m(self, digits : int) -> None:
        '''Rounds M coordinate to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def get_extent(self) -> aspose.gis.Extent:
        '''Computes and returns a bounding extent of this geometry.
        
        :returns: A bounding extent of this geometry.'''
        raise NotImplementedError()
    
    def get_area(self) -> float:
        '''Computes the area of this geometry.
        
        :returns: The area of this geometry.
        Sum of areas of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_length(self) -> float:
        '''Computes the length of this geometry.
        
        :returns: The length of this geometry.
        Perimeter if this is a :py:class:`aspose.gis.geometries.Polygon`.
        Sum of lengths of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_distance_to(self, other : aspose.gis.geometries.IGeometry) -> float:
        '''Computes the minimum distance between this geometry and a specified geometry.
        
        :param other: A geometry to find distance to.
        :returns: If both geometries are not :py:attr:`aspose.gis.geometries.Geometry.is_empty` - a distance between closest points of the geometries.
        If at least one geometry is empty -1 is returned.'''
        raise NotImplementedError()
    
    def get_convex_hull(self) -> aspose.gis.geometries.IGeometry:
        '''Computes the convex hull of this geometry.
        
        :returns: A geometry that represents a convex hull of this geometry.
        If this geometry has no points then the result is :py:attr:`aspose.gis.geometries.Geometry.null`.
        If this geometry has only one point then the result is this point.
        If this geometry has only two points then the result is :py:class:`aspose.gis.geometries.ILineString` with the points.
        If this geometry has three or more points then the result is :py:class:`aspose.gis.geometries.ILinearRing` that represents a convex
        hull around all geometries points.'''
        raise NotImplementedError()
    
    def get_centroid(self) -> aspose.gis.geometries.IPoint:
        '''Computes the centroid of this geometry.
        
        :returns: The centroid of this geometry. If this geometry is empty an empty point returned.
        The centroid is equal to the centroid of the highest dimension geometries in this geometry
        (e.g. if both points and lines are contained in the geometry, only lines contribute to centroid).'''
        raise NotImplementedError()
    
    def get_buffer(self, distance : float, quadrant_segments : int) -> aspose.gis.geometries.IGeometry:
        '''Computes a buffer region around this geometry.
        
        :param distance: The buffer region width.
        :param quadrant_segments: Number of segments used to approximate a 90 degree of curvature.
        The larger this number is the better approximation of curves is produced.
        Default is 30.
        :returns: A geometry that represents all points that are within a specified distance from
        this geometry.
        The type of result is either :py:attr:`aspose.gis.geometries.Geometry.null`, :py:class:`aspose.gis.geometries.IPolygon` or :py:class:`aspose.gis.geometries.IMultiPolygon`.'''
        raise NotImplementedError()
    
    def spatially_equals(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry spatially equal to a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry "spatially equals" to specified geometry.  otherwise.'''
        raise NotImplementedError()
    
    def disjoint(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry is disjoint from a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially disjoint" from another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def touches(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry touch.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially touches" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def crosses(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry cross.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially crosses" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def spatially_contains(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry spatially contains a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially contains" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def overlaps(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry overlap with a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially overlaps" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covers(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry covers a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covers" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covered_by(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is covered by a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covered by" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def relate(self, other : aspose.gis.geometries.IGeometry, intersection_pattern_matrix : str) -> bool:
        '''Determines if DE-9IM intersection matrix of this geometry and a specified geometry matches provided pattern.
        
        :param other: A geometry.
        :param intersection_pattern_matrix: A patter to match with.
        This should be a string with length equal to 9.
        Each character of the string represent expected dimension of an intersection:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        Possible values of each characters are:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        For example, an intersection pattern "F0*******" means, that there should not be intersection between geometries interiors
        and intersection between geometries boundaries must be a point.
        See OpenGIS Simple Features Specification for more details about intersection matrix pattern.
        :returns: if this intersection matrix matches patter;  otherwise.'''
        raise NotImplementedError()
    
    def intersection(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds an intersection between this geometry and a specified geometry.
        
        :param other: A geometry to compute intersection with.
        :returns: A geometry that represents an intersection of this geometry and an argument. The result geometry contain
        point set that present in both this geometry and an argument.'''
        raise NotImplementedError()
    
    def union(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Unites this geometry and a specified geometry.
        
        :param other: A geometry to unite with.
        :returns: A geometry that represents a union of this geometry and an argument. The result geometry contains
        point set that present in this geometry or in an argument.'''
        raise NotImplementedError()
    
    def difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Subtracts a specified geometry from this geometry.
        
        :param other: A geometry to subtract.
        :returns: A geometry that represents a difference of this geometry and an argument. The result geometry contains
        point set that present in this geometry but not present in an argument.'''
        raise NotImplementedError()
    
    def sym_difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds a symmetric difference between this geometry and a specified geometry.
        
        :param other: A geometry to compute symmetric difference with.
        :returns: A geometry that represents a symmetric difference of this geometry and an argument. The result geometry contains
        point set that present in one of the geometries but not present in both of them.'''
        raise NotImplementedError()
    
    def reverse(self) -> None:
        '''Reverses order of points in this :py:class:`aspose.gis.geometries.LineString`.'''
        raise NotImplementedError()
    
    def equals(self, other : aspose.gis.geometries.ILineString) -> bool:
        '''Indicates whether the current object is equal to another object of the same type.
        
        :param other: An object to compare with this object.
        :returns: true if the current object is equal to the ``other`` parameter; otherwise, false.'''
        raise NotImplementedError()
    
    def is_clockwise(self) -> bool:
        '''Determines if the ring has clockwise winding.
        
        :returns: if clockwise; otherwise .'''
        raise NotImplementedError()
    
    @property
    def dimension(self) -> aspose.gis.geometries.GeometryDimension:
        '''Gets the topological dimension of this :py:class:`aspose.gis.geometries.Geometry`.'''
        raise NotImplementedError()
    
    null : aspose.gis.geometries.IGeometry
    '''Gets an instance of null geometry.'''
    @property
    def coordinate_dimension(self) -> int:
        '''Gets the number of coordinate dimensions for this :py:class:`aspose.gis.geometries.Geometry`.'''
        raise NotImplementedError()
    
    @property
    def is_empty(self) -> bool:
        '''Gets a value indicating whether this instance is empty.'''
        raise NotImplementedError()
    
    @property
    def is_simple(self) -> bool:
        '''Gets a value indicating whether this instance is simple from SFA point of view.'''
        raise NotImplementedError()
    
    @property
    def is_valid(self) -> bool:
        '''Gets a value indicating whether this instance is valid.'''
        raise NotImplementedError()
    
    @property
    def has_m(self) -> bool:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @has_m.setter
    def has_m(self, value : bool) -> None:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_z(self) -> bool:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @has_z.setter
    def has_z(self, value : bool) -> None:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_curve_geometry(self) -> bool:
        '''Gets a value indicating whether this geometry is or contains curve (not linear) geometry.'''
        raise NotImplementedError()
    
    @property
    def geometry_type(self) -> aspose.gis.geometries.GeometryType:
        '''Gets the type of the geometry.'''
        raise NotImplementedError()
    
    @property
    def spatial_reference_system(self) -> aspose.gis.spatialreferencing.SpatialReferenceSystem:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , if SpatialReferenceSystem is unset.
        Assigning new SpatialReferenceSystem will not perform any coordinate transformation, only reference will change.'''
        raise NotImplementedError()
    
    @spatial_reference_system.setter
    def spatial_reference_system(self, value : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> None:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , if SpatialReferenceSystem is unset.
        Assigning new SpatialReferenceSystem will not perform any coordinate transformation, only reference will change.'''
        raise NotImplementedError()
    
    @property
    def start_point(self) -> aspose.gis.geometries.IPoint:
        '''Returns a copy of the starting point of the curve.'''
        raise NotImplementedError()
    
    @property
    def end_point(self) -> aspose.gis.geometries.IPoint:
        '''Returns a copy of the end point of the curve.'''
        raise NotImplementedError()
    
    @property
    def is_closed(self) -> bool:
        '''Gets a values indicating whether a curve is closed.
        A curve is closed if its start point is equal to its end point.'''
        raise NotImplementedError()
    
    def __getitem__(self, key : int) -> aspose.gis.geometries.IPoint:
        raise NotImplementedError()
    
    def __setitem__(self, key : int, value : aspose.gis.geometries.IPoint):
        raise NotImplementedError()
    

class MultiCurve(GeometryCollection):
    '''A :py:class:`aspose.gis.geometries.MultiCurve` is a one-dimensional :py:class:`aspose.gis.geometries.GeometryCollection`
    whose elements are :py:class:`aspose.gis.geometries.Curve`s.'''
    
    @overload
    @staticmethod
    def from_text(wkt : str) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Text representation.
        
        :param wkt: Well-Known Text representation of a geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_text(wkt : str, spatial_reference_system : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Text representation.
        
        :param wkt: Well-Known Text representation of a geometry.
        :param spatial_reference_system: Spatial Reference System to be assigned to the geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_binary(wkb : List[int]) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Binary representation.
        
        :param wkb: Well-Known Binary representation of a geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_binary(wkb : List[int], spatial_reference_system : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Binary representation.
        
        :param wkb: Well-Known Binary representation of a geometry.
        :param spatial_reference_system: Spatial Reference System to be assigned to the geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self, tolerance : float) -> aspose.gis.geometries.IMultiLineString:
        '''Gets approximate or equivalent non-curve version of this geometry using the specified ``tolerance``.
        
        :param tolerance: The ``tolerance`` to use. The result is guaranteed to be less than ``tolerance`` away from the
        curved geometry, unless the number of points needed to linearize the geometry exceeds the per-quadrant maximum,
        currently equal to 10000 points.
        :returns: A :py:class:`aspose.gis.geometries.IMultiLineString` that approximates or equivalent to this :py:class:`aspose.gis.geometries.IMultiCurve`:
        
        If this object is :py:class:`aspose.gis.geometries.IMultiLineString` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiLineString` - all curves are linearized and new ``IMultiLineString`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiLineString` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiLineString` - all curves are linearized and new ``IMultiLineString`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiLineString` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiLineString` - all curves are linearized and new ``IMultiLineString`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiLineString` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiLineString` - all curves are linearized and new ``IMultiLineString`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiLineString` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiLineString` - all curves are linearized and new ``IMultiLineString`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiLineString` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiLineString` - all curves are linearized and new ``IMultiLineString`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiLineString` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiLineString` - all curves are linearized and new ``IMultiLineString`` is created'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self) -> aspose.gis.geometries.IMultiLineString:
        '''Gets approximate or equivalent non-curve version of this geometry using the default ``tolerance``.
        
        :returns: A :py:class:`aspose.gis.geometries.IMultiLineString` that approximates or equivalent to this :py:class:`aspose.gis.geometries.IMultiCurve`.
        This is the equivalent of :py:func:`aspose.gis.geometries.IMultiCurve.to_linear_geometry` with
        default ``tolerance``. Default ``tolerance``s value is dependent on :py:class:`aspose.gis.spatialreferencing.SpatialReferenceSystem`
        of this geometry:
        
        *
        
        *
        
        *
        
        For more details on what transformations are applied refer to :py:func:`aspose.gis.geometries.IMultiCurve.to_linear_geometry` specification.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : aspose.gis.AbstractPath, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : str, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> io.RawIOBase:
        '''Export this geometry to an image representation.
        
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.
        :returns: The image as stream'''
        raise NotImplementedError()
    
    @overload
    def as_text(self) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant, format : aspose.gis.NumericFormat) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :param format: Coordinate format for conversion to string. See the :py:class:`aspose.gis.NumericFormat` to get it.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self, variant : aspose.gis.geometries.WkbVariant) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :param variant: Well-Known Binary variant to use.
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def within(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry is within a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry is within extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def within(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is within a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially within" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry intersects a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry intersects the extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry intersects.
        
        :param other: A geometry.
        :returns: if this geometry "spatially intersects" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def to_editable(self) -> aspose.gis.geometries.MultiCurve:
        '''Gets an editable copy of this geometry.
        
        :returns: An editable copy of this geometry.'''
        raise NotImplementedError()
    
    def replace_polygons_by_lines(self) -> aspose.gis.geometries.IGeometryCollection:
        '''Gets polygons represented as lines of this geometry.
        
        :returns: A geometry, that has no polygon geometries. The following transformation are applied:
        
        *
        
        *'''
        raise NotImplementedError()
    
    def to_svg(self, extent : aspose.gis.Extent) -> str:
        '''Translates this geometry to Svg representation.
        
        :param extent: Extent for translation this geometry to Svg
        :returns: The Svg representation.'''
        raise NotImplementedError()
    
    def set_empty(self) -> None:
        '''Makes this :py:class:`aspose.gis.geometries.Geometry` empty.'''
        raise NotImplementedError()
    
    def clone(self) -> aspose.gis.geometries.Geometry:
        '''Clones this instance.
        
        :returns: The clone of this instance'''
        raise NotImplementedError()
    
    def round_xy(self, digits : int) -> None:
        '''Rounds X and Y coordinates to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def round_z(self, digits : int) -> None:
        '''Rounds Z coordinate to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def round_m(self, digits : int) -> None:
        '''Rounds M coordinate to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def get_extent(self) -> aspose.gis.Extent:
        '''Computes and returns a bounding extent of this geometry.
        
        :returns: A bounding extent of this geometry.'''
        raise NotImplementedError()
    
    def get_area(self) -> float:
        '''Computes the area of this geometry.
        
        :returns: The area of this geometry.
        Sum of areas of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_length(self) -> float:
        '''Computes the length of this geometry.
        
        :returns: The length of this geometry.
        Perimeter if this is a :py:class:`aspose.gis.geometries.Polygon`.
        Sum of lengths of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_distance_to(self, other : aspose.gis.geometries.IGeometry) -> float:
        '''Computes the minimum distance between this geometry and a specified geometry.
        
        :param other: A geometry to find distance to.
        :returns: If both geometries are not :py:attr:`aspose.gis.geometries.Geometry.is_empty` - a distance between closest points of the geometries.
        If at least one geometry is empty -1 is returned.'''
        raise NotImplementedError()
    
    def get_convex_hull(self) -> aspose.gis.geometries.IGeometry:
        '''Computes the convex hull of this geometry.
        
        :returns: A geometry that represents a convex hull of this geometry.
        If this geometry has no points then the result is :py:attr:`aspose.gis.geometries.Geometry.null`.
        If this geometry has only one point then the result is this point.
        If this geometry has only two points then the result is :py:class:`aspose.gis.geometries.ILineString` with the points.
        If this geometry has three or more points then the result is :py:class:`aspose.gis.geometries.ILinearRing` that represents a convex
        hull around all geometries points.'''
        raise NotImplementedError()
    
    def get_centroid(self) -> aspose.gis.geometries.IPoint:
        '''Computes the centroid of this geometry.
        
        :returns: The centroid of this geometry. If this geometry is empty an empty point returned.
        The centroid is equal to the centroid of the highest dimension geometries in this geometry
        (e.g. if both points and lines are contained in the geometry, only lines contribute to centroid).'''
        raise NotImplementedError()
    
    def get_buffer(self, distance : float, quadrant_segments : int) -> aspose.gis.geometries.IGeometry:
        '''Computes a buffer region around this geometry.
        
        :param distance: The buffer region width.
        :param quadrant_segments: Number of segments used to approximate a 90 degree of curvature.
        The larger this number is the better approximation of curves is produced.
        Default is 30.
        :returns: A geometry that represents all points that are within a specified distance from
        this geometry.
        The type of result is either :py:attr:`aspose.gis.geometries.Geometry.null`, :py:class:`aspose.gis.geometries.IPolygon` or :py:class:`aspose.gis.geometries.IMultiPolygon`.'''
        raise NotImplementedError()
    
    def spatially_equals(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry spatially equal to a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry "spatially equals" to specified geometry.  otherwise.'''
        raise NotImplementedError()
    
    def disjoint(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry is disjoint from a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially disjoint" from another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def touches(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry touch.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially touches" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def crosses(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry cross.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially crosses" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def spatially_contains(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry spatially contains a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially contains" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def overlaps(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry overlap with a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially overlaps" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covers(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry covers a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covers" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covered_by(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is covered by a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covered by" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def relate(self, other : aspose.gis.geometries.IGeometry, intersection_pattern_matrix : str) -> bool:
        '''Determines if DE-9IM intersection matrix of this geometry and a specified geometry matches provided pattern.
        
        :param other: A geometry.
        :param intersection_pattern_matrix: A patter to match with.
        This should be a string with length equal to 9.
        Each character of the string represent expected dimension of an intersection:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        Possible values of each characters are:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        For example, an intersection pattern "F0*******" means, that there should not be intersection between geometries interiors
        and intersection between geometries boundaries must be a point.
        See OpenGIS Simple Features Specification for more details about intersection matrix pattern.
        :returns: if this intersection matrix matches patter;  otherwise.'''
        raise NotImplementedError()
    
    def intersection(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds an intersection between this geometry and a specified geometry.
        
        :param other: A geometry to compute intersection with.
        :returns: A geometry that represents an intersection of this geometry and an argument. The result geometry contain
        point set that present in both this geometry and an argument.'''
        raise NotImplementedError()
    
    def union(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Unites this geometry and a specified geometry.
        
        :param other: A geometry to unite with.
        :returns: A geometry that represents a union of this geometry and an argument. The result geometry contains
        point set that present in this geometry or in an argument.'''
        raise NotImplementedError()
    
    def difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Subtracts a specified geometry from this geometry.
        
        :param other: A geometry to subtract.
        :returns: A geometry that represents a difference of this geometry and an argument. The result geometry contains
        point set that present in this geometry but not present in an argument.'''
        raise NotImplementedError()
    
    def sym_difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds a symmetric difference between this geometry and a specified geometry.
        
        :param other: A geometry to compute symmetric difference with.
        :returns: A geometry that represents a symmetric difference of this geometry and an argument. The result geometry contains
        point set that present in one of the geometries but not present in both of them.'''
        raise NotImplementedError()
    
    def get_point_on_surface(self) -> aspose.gis.geometries.IPoint:
        '''Finds a point that is guaranteed to be on one of the surfaces in this collection.
        
        :returns: A point on one of the surfaces. An empty point if this collection does not contain surfaces or all surfaces are empty.'''
        raise NotImplementedError()
    
    def add(self, geometry : aspose.gis.geometries.IGeometry) -> None:
        '''Adds the specified geometry to the collection.
        
        :param geometry: The geometry to add.'''
        raise NotImplementedError()
    
    def add_range(self, geometries : Iterable[aspose.gis.geometries.IGeometry]) -> None:
        raise NotImplementedError()
    
    def remove_at(self, index : int) -> None:
        '''Removes the specified geometry from the collection.
        
        :param index: Index of the geometry to remove.'''
        raise NotImplementedError()
    
    def equals(self, other : aspose.gis.geometries.IGeometryCollection) -> bool:
        '''Indicates whether the current object is equal to another object of the same type.
        
        :param other: An object to compare with this object.
        :returns: true if the current object is equal to the ``other`` parameter; otherwise, false.'''
        raise NotImplementedError()
    
    @property
    def dimension(self) -> aspose.gis.geometries.GeometryDimension:
        '''Gets the topological dimension of this :py:class:`aspose.gis.geometries.Geometry`.'''
        raise NotImplementedError()
    
    null : aspose.gis.geometries.IGeometry
    '''Gets an instance of null geometry.'''
    @property
    def coordinate_dimension(self) -> int:
        '''Gets the number of coordinate dimensions for this :py:class:`aspose.gis.geometries.Geometry`.'''
        raise NotImplementedError()
    
    @property
    def is_empty(self) -> bool:
        '''Gets a value indicating whether this instance is empty.'''
        raise NotImplementedError()
    
    @property
    def is_simple(self) -> bool:
        '''Gets a value indicating whether this instance is simple from SFA point of view.'''
        raise NotImplementedError()
    
    @property
    def is_valid(self) -> bool:
        '''Gets a value indicating whether this instance is valid.'''
        raise NotImplementedError()
    
    @property
    def has_m(self) -> bool:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @has_m.setter
    def has_m(self, value : bool) -> None:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_z(self) -> bool:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @has_z.setter
    def has_z(self, value : bool) -> None:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_curve_geometry(self) -> bool:
        '''Gets a value indicating whether this geometry is or contains curve (not linear) geometry.'''
        raise NotImplementedError()
    
    @property
    def geometry_type(self) -> aspose.gis.geometries.GeometryType:
        '''Gets the type of the geometry.'''
        raise NotImplementedError()
    
    @property
    def spatial_reference_system(self) -> aspose.gis.spatialreferencing.SpatialReferenceSystem:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , is SpatialReferenceSystem is unknown.
        Assigning new SpatialReferenceSystem will not perform any coordinate transformation, only reference will change.'''
        raise NotImplementedError()
    
    @spatial_reference_system.setter
    def spatial_reference_system(self, value : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> None:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , is SpatialReferenceSystem is unknown.
        Assigning new SpatialReferenceSystem will not perform any coordinate transformation, only reference will change.'''
        raise NotImplementedError()
    
    @property
    def count(self) -> int:
        '''Gets the number of geometries in this collection.'''
        raise NotImplementedError()
    
    @property
    def is_closed(self) -> bool:
        '''Determines whether this curve is closed.'''
        raise NotImplementedError()
    
    def __getitem__(self, key : int) -> aspose.gis.geometries.IGeometry:
        raise NotImplementedError()
    

class MultiLineString(MultiCurve):
    '''A :py:class:`aspose.gis.geometries.MultiLineString` is a one-dimensional :py:class:`aspose.gis.geometries.GeometryCollection`
    whose elements are :py:class:`aspose.gis.geometries.LineString`s.'''
    
    @overload
    @staticmethod
    def from_text(wkt : str) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Text representation.
        
        :param wkt: Well-Known Text representation of a geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_text(wkt : str, spatial_reference_system : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Text representation.
        
        :param wkt: Well-Known Text representation of a geometry.
        :param spatial_reference_system: Spatial Reference System to be assigned to the geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_binary(wkb : List[int]) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Binary representation.
        
        :param wkb: Well-Known Binary representation of a geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_binary(wkb : List[int], spatial_reference_system : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Binary representation.
        
        :param wkb: Well-Known Binary representation of a geometry.
        :param spatial_reference_system: Spatial Reference System to be assigned to the geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self, tolerance : float) -> aspose.gis.geometries.IMultiLineString:
        '''Gets approximate or equivalent non-curve version of this geometry using the specified ``tolerance``.
        
        :param tolerance: The ``tolerance`` to use. The result is guaranteed to be less than ``tolerance`` away from the
        curved geometry, unless the number of points needed to linearize the geometry exceeds the per-quadrant maximum,
        currently equal to 10000 points.
        :returns: A :py:class:`aspose.gis.geometries.IMultiLineString` that approximates or equivalent to this :py:class:`aspose.gis.geometries.IMultiCurve`:
        
        If this object is :py:class:`aspose.gis.geometries.IMultiLineString` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiLineString` - all curves are linearized and new ``IMultiLineString`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiLineString` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiLineString` - all curves are linearized and new ``IMultiLineString`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiLineString` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiLineString` - all curves are linearized and new ``IMultiLineString`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiLineString` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiLineString` - all curves are linearized and new ``IMultiLineString`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiLineString` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiLineString` - all curves are linearized and new ``IMultiLineString`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiLineString` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiLineString` - all curves are linearized and new ``IMultiLineString`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiLineString` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiLineString` - all curves are linearized and new ``IMultiLineString`` is created'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self) -> aspose.gis.geometries.IMultiLineString:
        '''Gets approximate or equivalent non-curve version of this geometry using the default ``tolerance``.
        
        :returns: A :py:class:`aspose.gis.geometries.IMultiLineString` that approximates or equivalent to this :py:class:`aspose.gis.geometries.IMultiCurve`.
        This is the equivalent of :py:func:`aspose.gis.geometries.IMultiCurve.to_linear_geometry` with
        default ``tolerance``. Default ``tolerance``s value is dependent on :py:class:`aspose.gis.spatialreferencing.SpatialReferenceSystem`
        of this geometry:
        
        *
        
        *
        
        *
        
        For more details on what transformations are applied refer to :py:func:`aspose.gis.geometries.IMultiCurve.to_linear_geometry` specification.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : aspose.gis.AbstractPath, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : str, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> io.RawIOBase:
        '''Export this geometry to an image representation.
        
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.
        :returns: The image as stream'''
        raise NotImplementedError()
    
    @overload
    def as_text(self) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant, format : aspose.gis.NumericFormat) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :param format: Coordinate format for conversion to string. See the :py:class:`aspose.gis.NumericFormat` to get it.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self, variant : aspose.gis.geometries.WkbVariant) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :param variant: Well-Known Binary variant to use.
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def within(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry is within a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry is within extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def within(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is within a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially within" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry intersects a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry intersects the extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry intersects.
        
        :param other: A geometry.
        :returns: if this geometry "spatially intersects" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def to_editable(self) -> aspose.gis.geometries.MultiLineString:
        '''Gets an editable copy of this geometry.
        
        :returns: An editable copy of this geometry.'''
        raise NotImplementedError()
    
    def replace_polygons_by_lines(self) -> aspose.gis.geometries.IGeometryCollection:
        '''Gets polygons represented as lines of this geometry.
        
        :returns: A geometry, that has no polygon geometries. The following transformation are applied:
        
        *
        
        *'''
        raise NotImplementedError()
    
    def to_svg(self, extent : aspose.gis.Extent) -> str:
        '''Translates this geometry to Svg representation.
        
        :param extent: Extent for translation this geometry to Svg
        :returns: The Svg representation.'''
        raise NotImplementedError()
    
    def set_empty(self) -> None:
        '''Makes this :py:class:`aspose.gis.geometries.Geometry` empty.'''
        raise NotImplementedError()
    
    def clone(self) -> aspose.gis.geometries.Geometry:
        '''Clones this instance.
        
        :returns: The clone of this instance'''
        raise NotImplementedError()
    
    def round_xy(self, digits : int) -> None:
        '''Rounds X and Y coordinates to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def round_z(self, digits : int) -> None:
        '''Rounds Z coordinate to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def round_m(self, digits : int) -> None:
        '''Rounds M coordinate to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def get_extent(self) -> aspose.gis.Extent:
        '''Computes and returns a bounding extent of this geometry.
        
        :returns: A bounding extent of this geometry.'''
        raise NotImplementedError()
    
    def get_area(self) -> float:
        '''Computes the area of this geometry.
        
        :returns: The area of this geometry.
        Sum of areas of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_length(self) -> float:
        '''Computes the length of this geometry.
        
        :returns: The length of this geometry.
        Perimeter if this is a :py:class:`aspose.gis.geometries.Polygon`.
        Sum of lengths of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_distance_to(self, other : aspose.gis.geometries.IGeometry) -> float:
        '''Computes the minimum distance between this geometry and a specified geometry.
        
        :param other: A geometry to find distance to.
        :returns: If both geometries are not :py:attr:`aspose.gis.geometries.Geometry.is_empty` - a distance between closest points of the geometries.
        If at least one geometry is empty -1 is returned.'''
        raise NotImplementedError()
    
    def get_convex_hull(self) -> aspose.gis.geometries.IGeometry:
        '''Computes the convex hull of this geometry.
        
        :returns: A geometry that represents a convex hull of this geometry.
        If this geometry has no points then the result is :py:attr:`aspose.gis.geometries.Geometry.null`.
        If this geometry has only one point then the result is this point.
        If this geometry has only two points then the result is :py:class:`aspose.gis.geometries.ILineString` with the points.
        If this geometry has three or more points then the result is :py:class:`aspose.gis.geometries.ILinearRing` that represents a convex
        hull around all geometries points.'''
        raise NotImplementedError()
    
    def get_centroid(self) -> aspose.gis.geometries.IPoint:
        '''Computes the centroid of this geometry.
        
        :returns: The centroid of this geometry. If this geometry is empty an empty point returned.
        The centroid is equal to the centroid of the highest dimension geometries in this geometry
        (e.g. if both points and lines are contained in the geometry, only lines contribute to centroid).'''
        raise NotImplementedError()
    
    def get_buffer(self, distance : float, quadrant_segments : int) -> aspose.gis.geometries.IGeometry:
        '''Computes a buffer region around this geometry.
        
        :param distance: The buffer region width.
        :param quadrant_segments: Number of segments used to approximate a 90 degree of curvature.
        The larger this number is the better approximation of curves is produced.
        Default is 30.
        :returns: A geometry that represents all points that are within a specified distance from
        this geometry.
        The type of result is either :py:attr:`aspose.gis.geometries.Geometry.null`, :py:class:`aspose.gis.geometries.IPolygon` or :py:class:`aspose.gis.geometries.IMultiPolygon`.'''
        raise NotImplementedError()
    
    def spatially_equals(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry spatially equal to a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry "spatially equals" to specified geometry.  otherwise.'''
        raise NotImplementedError()
    
    def disjoint(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry is disjoint from a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially disjoint" from another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def touches(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry touch.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially touches" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def crosses(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry cross.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially crosses" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def spatially_contains(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry spatially contains a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially contains" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def overlaps(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry overlap with a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially overlaps" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covers(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry covers a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covers" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covered_by(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is covered by a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covered by" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def relate(self, other : aspose.gis.geometries.IGeometry, intersection_pattern_matrix : str) -> bool:
        '''Determines if DE-9IM intersection matrix of this geometry and a specified geometry matches provided pattern.
        
        :param other: A geometry.
        :param intersection_pattern_matrix: A patter to match with.
        This should be a string with length equal to 9.
        Each character of the string represent expected dimension of an intersection:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        Possible values of each characters are:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        For example, an intersection pattern "F0*******" means, that there should not be intersection between geometries interiors
        and intersection between geometries boundaries must be a point.
        See OpenGIS Simple Features Specification for more details about intersection matrix pattern.
        :returns: if this intersection matrix matches patter;  otherwise.'''
        raise NotImplementedError()
    
    def intersection(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds an intersection between this geometry and a specified geometry.
        
        :param other: A geometry to compute intersection with.
        :returns: A geometry that represents an intersection of this geometry and an argument. The result geometry contain
        point set that present in both this geometry and an argument.'''
        raise NotImplementedError()
    
    def union(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Unites this geometry and a specified geometry.
        
        :param other: A geometry to unite with.
        :returns: A geometry that represents a union of this geometry and an argument. The result geometry contains
        point set that present in this geometry or in an argument.'''
        raise NotImplementedError()
    
    def difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Subtracts a specified geometry from this geometry.
        
        :param other: A geometry to subtract.
        :returns: A geometry that represents a difference of this geometry and an argument. The result geometry contains
        point set that present in this geometry but not present in an argument.'''
        raise NotImplementedError()
    
    def sym_difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds a symmetric difference between this geometry and a specified geometry.
        
        :param other: A geometry to compute symmetric difference with.
        :returns: A geometry that represents a symmetric difference of this geometry and an argument. The result geometry contains
        point set that present in one of the geometries but not present in both of them.'''
        raise NotImplementedError()
    
    def get_point_on_surface(self) -> aspose.gis.geometries.IPoint:
        '''Finds a point that is guaranteed to be on one of the surfaces in this collection.
        
        :returns: A point on one of the surfaces. An empty point if this collection does not contain surfaces or all surfaces are empty.'''
        raise NotImplementedError()
    
    def add(self, geometry : aspose.gis.geometries.IGeometry) -> None:
        '''Adds the specified geometry to the collection.
        
        :param geometry: The geometry to add.'''
        raise NotImplementedError()
    
    def add_range(self, geometries : Iterable[aspose.gis.geometries.IGeometry]) -> None:
        raise NotImplementedError()
    
    def remove_at(self, index : int) -> None:
        '''Removes the specified geometry from the collection.
        
        :param index: Index of the geometry to remove.'''
        raise NotImplementedError()
    
    def equals(self, other : aspose.gis.geometries.IGeometryCollection) -> bool:
        '''Indicates whether the current object is equal to another object of the same type.
        
        :param other: An object to compare with this object.
        :returns: true if the current object is equal to the ``other`` parameter; otherwise, false.'''
        raise NotImplementedError()
    
    @property
    def dimension(self) -> aspose.gis.geometries.GeometryDimension:
        '''Gets the topological dimension of this :py:class:`aspose.gis.geometries.Geometry`.'''
        raise NotImplementedError()
    
    null : aspose.gis.geometries.IGeometry
    '''Gets an instance of null geometry.'''
    @property
    def coordinate_dimension(self) -> int:
        '''Gets the number of coordinate dimensions for this :py:class:`aspose.gis.geometries.Geometry`.'''
        raise NotImplementedError()
    
    @property
    def is_empty(self) -> bool:
        '''Gets a value indicating whether this instance is empty.'''
        raise NotImplementedError()
    
    @property
    def is_simple(self) -> bool:
        '''Gets a value indicating whether this instance is simple from SFA point of view.'''
        raise NotImplementedError()
    
    @property
    def is_valid(self) -> bool:
        '''Gets a value indicating whether this instance is valid.'''
        raise NotImplementedError()
    
    @property
    def has_m(self) -> bool:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @has_m.setter
    def has_m(self, value : bool) -> None:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_z(self) -> bool:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @has_z.setter
    def has_z(self, value : bool) -> None:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_curve_geometry(self) -> bool:
        '''Gets a value indicating whether this geometry is or contains curve (not linear) geometry.'''
        raise NotImplementedError()
    
    @property
    def geometry_type(self) -> aspose.gis.geometries.GeometryType:
        '''Gets the type of the geometry.'''
        raise NotImplementedError()
    
    @property
    def spatial_reference_system(self) -> aspose.gis.spatialreferencing.SpatialReferenceSystem:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , is SpatialReferenceSystem is unknown.
        Assigning new SpatialReferenceSystem will not perform any coordinate transformation, only reference will change.'''
        raise NotImplementedError()
    
    @spatial_reference_system.setter
    def spatial_reference_system(self, value : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> None:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , is SpatialReferenceSystem is unknown.
        Assigning new SpatialReferenceSystem will not perform any coordinate transformation, only reference will change.'''
        raise NotImplementedError()
    
    @property
    def count(self) -> int:
        '''Gets the number of geometries in this collection.'''
        raise NotImplementedError()
    
    @property
    def is_closed(self) -> bool:
        '''Determines whether this curve is closed.'''
        raise NotImplementedError()
    
    def __getitem__(self, key : int) -> aspose.gis.geometries.IGeometry:
        raise NotImplementedError()
    

class MultiPoint(GeometryCollection):
    '''A :py:class:`aspose.gis.geometries.MultiPoint` is a one-dimensional :py:class:`aspose.gis.geometries.GeometryCollection`
    whose elements are :py:class:`aspose.gis.geometries.Point`s.'''
    
    @overload
    @staticmethod
    def from_text(wkt : str) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Text representation.
        
        :param wkt: Well-Known Text representation of a geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_text(wkt : str, spatial_reference_system : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Text representation.
        
        :param wkt: Well-Known Text representation of a geometry.
        :param spatial_reference_system: Spatial Reference System to be assigned to the geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_binary(wkb : List[int]) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Binary representation.
        
        :param wkb: Well-Known Binary representation of a geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_binary(wkb : List[int], spatial_reference_system : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Binary representation.
        
        :param wkb: Well-Known Binary representation of a geometry.
        :param spatial_reference_system: Spatial Reference System to be assigned to the geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self) -> aspose.gis.geometries.IGeometryCollection:
        '''Gets approximate or equivalent non-curve version of this geometry using the default ``tolerance``.
        
        :returns: A geometry, that has no curve geometries. This is the equivalent of :py:func:`aspose.gis.geometries.IGeometryCollection.to_linear_geometry` with
        default ``tolerance``. Default ``tolerance``s value is dependent on :py:class:`aspose.gis.spatialreferencing.SpatialReferenceSystem`
        of this geometry:
        
        *
        
        *
        
        *
        
        For more details on what transformations are applied refer to :py:func:`aspose.gis.geometries.IGeometryCollection.to_linear_geometry` specification.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self, tolerance : float) -> aspose.gis.geometries.IGeometryCollection:
        '''Gets approximate or equivalent non-curve version of this geometry using the specified ``tolerance``.
        
        :param tolerance: The ``tolerance`` to use. The result is guaranteed to be less than ``tolerance`` away from the
        curved geometry.
        :returns: A geometry, that has no curve geometries. The following transformations are applied:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        As a result, :py:attr:`aspose.gis.geometries.IGeometry.has_curve_geometry` of output geometry is .'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : aspose.gis.AbstractPath, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : str, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> io.RawIOBase:
        '''Export this geometry to an image representation.
        
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.
        :returns: The image as stream'''
        raise NotImplementedError()
    
    @overload
    def as_text(self) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant, format : aspose.gis.NumericFormat) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :param format: Coordinate format for conversion to string. See the :py:class:`aspose.gis.NumericFormat` to get it.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self, variant : aspose.gis.geometries.WkbVariant) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :param variant: Well-Known Binary variant to use.
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def within(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry is within a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry is within extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def within(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is within a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially within" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry intersects a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry intersects the extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry intersects.
        
        :param other: A geometry.
        :returns: if this geometry "spatially intersects" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def to_editable(self) -> aspose.gis.common.formats.mapinfo.graphicalobjects.MultiPoint:
        '''Gets an editable copy of this geometry.
        
        :returns: An editable copy of this geometry.'''
        raise NotImplementedError()
    
    def replace_polygons_by_lines(self) -> aspose.gis.geometries.IGeometryCollection:
        '''Gets polygons represented as lines of this geometry.
        
        :returns: A geometry, that has no polygon geometries. The following transformation are applied:
        
        *
        
        *'''
        raise NotImplementedError()
    
    def to_svg(self, extent : aspose.gis.Extent) -> str:
        '''Translates this geometry to Svg representation.
        
        :param extent: Extent for translation this geometry to Svg
        :returns: The Svg representation.'''
        raise NotImplementedError()
    
    def set_empty(self) -> None:
        '''Makes this :py:class:`aspose.gis.geometries.Geometry` empty.'''
        raise NotImplementedError()
    
    def clone(self) -> aspose.gis.geometries.Geometry:
        '''Clones this instance.
        
        :returns: The clone of this instance'''
        raise NotImplementedError()
    
    def round_xy(self, digits : int) -> None:
        '''Rounds X and Y coordinates to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def round_z(self, digits : int) -> None:
        '''Rounds Z coordinate to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def round_m(self, digits : int) -> None:
        '''Rounds M coordinate to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def get_extent(self) -> aspose.gis.Extent:
        '''Computes and returns a bounding extent of this geometry.
        
        :returns: A bounding extent of this geometry.'''
        raise NotImplementedError()
    
    def get_area(self) -> float:
        '''Computes the area of this geometry.
        
        :returns: The area of this geometry.
        Sum of areas of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_length(self) -> float:
        '''Computes the length of this geometry.
        
        :returns: The length of this geometry.
        Perimeter if this is a :py:class:`aspose.gis.geometries.Polygon`.
        Sum of lengths of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_distance_to(self, other : aspose.gis.geometries.IGeometry) -> float:
        '''Computes the minimum distance between this geometry and a specified geometry.
        
        :param other: A geometry to find distance to.
        :returns: If both geometries are not :py:attr:`aspose.gis.geometries.Geometry.is_empty` - a distance between closest points of the geometries.
        If at least one geometry is empty -1 is returned.'''
        raise NotImplementedError()
    
    def get_convex_hull(self) -> aspose.gis.geometries.IGeometry:
        '''Computes the convex hull of this geometry.
        
        :returns: A geometry that represents a convex hull of this geometry.
        If this geometry has no points then the result is :py:attr:`aspose.gis.geometries.Geometry.null`.
        If this geometry has only one point then the result is this point.
        If this geometry has only two points then the result is :py:class:`aspose.gis.geometries.ILineString` with the points.
        If this geometry has three or more points then the result is :py:class:`aspose.gis.geometries.ILinearRing` that represents a convex
        hull around all geometries points.'''
        raise NotImplementedError()
    
    def get_centroid(self) -> aspose.gis.geometries.IPoint:
        '''Computes the centroid of this geometry.
        
        :returns: The centroid of this geometry. If this geometry is empty an empty point returned.
        The centroid is equal to the centroid of the highest dimension geometries in this geometry
        (e.g. if both points and lines are contained in the geometry, only lines contribute to centroid).'''
        raise NotImplementedError()
    
    def get_buffer(self, distance : float, quadrant_segments : int) -> aspose.gis.geometries.IGeometry:
        '''Computes a buffer region around this geometry.
        
        :param distance: The buffer region width.
        :param quadrant_segments: Number of segments used to approximate a 90 degree of curvature.
        The larger this number is the better approximation of curves is produced.
        Default is 30.
        :returns: A geometry that represents all points that are within a specified distance from
        this geometry.
        The type of result is either :py:attr:`aspose.gis.geometries.Geometry.null`, :py:class:`aspose.gis.geometries.IPolygon` or :py:class:`aspose.gis.geometries.IMultiPolygon`.'''
        raise NotImplementedError()
    
    def spatially_equals(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry spatially equal to a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry "spatially equals" to specified geometry.  otherwise.'''
        raise NotImplementedError()
    
    def disjoint(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry is disjoint from a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially disjoint" from another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def touches(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry touch.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially touches" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def crosses(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry cross.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially crosses" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def spatially_contains(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry spatially contains a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially contains" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def overlaps(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry overlap with a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially overlaps" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covers(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry covers a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covers" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covered_by(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is covered by a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covered by" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def relate(self, other : aspose.gis.geometries.IGeometry, intersection_pattern_matrix : str) -> bool:
        '''Determines if DE-9IM intersection matrix of this geometry and a specified geometry matches provided pattern.
        
        :param other: A geometry.
        :param intersection_pattern_matrix: A patter to match with.
        This should be a string with length equal to 9.
        Each character of the string represent expected dimension of an intersection:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        Possible values of each characters are:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        For example, an intersection pattern "F0*******" means, that there should not be intersection between geometries interiors
        and intersection between geometries boundaries must be a point.
        See OpenGIS Simple Features Specification for more details about intersection matrix pattern.
        :returns: if this intersection matrix matches patter;  otherwise.'''
        raise NotImplementedError()
    
    def intersection(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds an intersection between this geometry and a specified geometry.
        
        :param other: A geometry to compute intersection with.
        :returns: A geometry that represents an intersection of this geometry and an argument. The result geometry contain
        point set that present in both this geometry and an argument.'''
        raise NotImplementedError()
    
    def union(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Unites this geometry and a specified geometry.
        
        :param other: A geometry to unite with.
        :returns: A geometry that represents a union of this geometry and an argument. The result geometry contains
        point set that present in this geometry or in an argument.'''
        raise NotImplementedError()
    
    def difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Subtracts a specified geometry from this geometry.
        
        :param other: A geometry to subtract.
        :returns: A geometry that represents a difference of this geometry and an argument. The result geometry contains
        point set that present in this geometry but not present in an argument.'''
        raise NotImplementedError()
    
    def sym_difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds a symmetric difference between this geometry and a specified geometry.
        
        :param other: A geometry to compute symmetric difference with.
        :returns: A geometry that represents a symmetric difference of this geometry and an argument. The result geometry contains
        point set that present in one of the geometries but not present in both of them.'''
        raise NotImplementedError()
    
    def get_point_on_surface(self) -> aspose.gis.geometries.IPoint:
        '''Finds a point that is guaranteed to be on one of the surfaces in this collection.
        
        :returns: A point on one of the surfaces. An empty point if this collection does not contain surfaces or all surfaces are empty.'''
        raise NotImplementedError()
    
    def add(self, geometry : aspose.gis.geometries.IGeometry) -> None:
        '''Adds the specified geometry to the collection.
        
        :param geometry: The geometry to add.'''
        raise NotImplementedError()
    
    def add_range(self, geometries : Iterable[aspose.gis.geometries.IGeometry]) -> None:
        raise NotImplementedError()
    
    def remove_at(self, index : int) -> None:
        '''Removes the specified geometry from the collection.
        
        :param index: Index of the geometry to remove.'''
        raise NotImplementedError()
    
    def equals(self, other : aspose.gis.geometries.IGeometryCollection) -> bool:
        '''Indicates whether the current object is equal to another object of the same type.
        
        :param other: An object to compare with this object.
        :returns: true if the current object is equal to the ``other`` parameter; otherwise, false.'''
        raise NotImplementedError()
    
    @property
    def dimension(self) -> aspose.gis.geometries.GeometryDimension:
        '''Gets the topological dimension of this :py:class:`aspose.gis.geometries.Geometry`.'''
        raise NotImplementedError()
    
    null : aspose.gis.geometries.IGeometry
    '''Gets an instance of null geometry.'''
    @property
    def coordinate_dimension(self) -> int:
        '''Gets the number of coordinate dimensions for this :py:class:`aspose.gis.geometries.Geometry`.'''
        raise NotImplementedError()
    
    @property
    def is_empty(self) -> bool:
        '''Gets a value indicating whether this instance is empty.'''
        raise NotImplementedError()
    
    @property
    def is_simple(self) -> bool:
        '''Gets a value indicating whether this instance is simple from SFA point of view.'''
        raise NotImplementedError()
    
    @property
    def is_valid(self) -> bool:
        '''Gets a value indicating whether this instance is valid.'''
        raise NotImplementedError()
    
    @property
    def has_m(self) -> bool:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @has_m.setter
    def has_m(self, value : bool) -> None:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_z(self) -> bool:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @has_z.setter
    def has_z(self, value : bool) -> None:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_curve_geometry(self) -> bool:
        '''Gets a value indicating whether this geometry is or contains curve (not linear) geometry.'''
        raise NotImplementedError()
    
    @property
    def geometry_type(self) -> aspose.gis.geometries.GeometryType:
        '''Gets the type of the geometry.'''
        raise NotImplementedError()
    
    @property
    def spatial_reference_system(self) -> aspose.gis.spatialreferencing.SpatialReferenceSystem:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , is SpatialReferenceSystem is unknown.
        Assigning new SpatialReferenceSystem will not perform any coordinate transformation, only reference will change.'''
        raise NotImplementedError()
    
    @spatial_reference_system.setter
    def spatial_reference_system(self, value : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> None:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , is SpatialReferenceSystem is unknown.
        Assigning new SpatialReferenceSystem will not perform any coordinate transformation, only reference will change.'''
        raise NotImplementedError()
    
    @property
    def count(self) -> int:
        '''Gets the number of geometries in this collection.'''
        raise NotImplementedError()
    
    def __getitem__(self, key : int) -> aspose.gis.geometries.IGeometry:
        raise NotImplementedError()
    

class MultiPolygon(MultiSurface):
    '''A :py:class:`aspose.gis.geometries.MultiPolygon` is a one-dimensional
    :py:class:`aspose.gis.geometries.GeometryCollection` whose elements are :py:class:`aspose.gis.geometries.Polygon`s.'''
    
    @overload
    @staticmethod
    def from_text(wkt : str) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Text representation.
        
        :param wkt: Well-Known Text representation of a geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_text(wkt : str, spatial_reference_system : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Text representation.
        
        :param wkt: Well-Known Text representation of a geometry.
        :param spatial_reference_system: Spatial Reference System to be assigned to the geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_binary(wkb : List[int]) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Binary representation.
        
        :param wkb: Well-Known Binary representation of a geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_binary(wkb : List[int], spatial_reference_system : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Binary representation.
        
        :param wkb: Well-Known Binary representation of a geometry.
        :param spatial_reference_system: Spatial Reference System to be assigned to the geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self) -> aspose.gis.geometries.IMultiPolygon:
        '''Gets approximate or equivalent non-curve version of this geometry using the default ``tolerance``.
        
        :returns: A :py:class:`aspose.gis.geometries.IMultiPolygon` that approximates or equivalent to this :py:class:`aspose.gis.geometries.IMultiSurface`.
        This is the equivalent of :py:func:`aspose.gis.geometries.IMultiSurface.to_linear_geometry` with
        default ``tolerance``. Default ``tolerance``s value is dependent on :py:class:`aspose.gis.spatialreferencing.SpatialReferenceSystem`
        of this geometry:
        
        *
        
        *
        
        *
        
        For more details on what transformations are applied refer to :py:func:`aspose.gis.geometries.IMultiSurface.to_linear_geometry` specification.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self, tolerance : float) -> aspose.gis.geometries.IMultiPolygon:
        '''Gets approximate or equivalent non-curve version of this geometry using the specified ``tolerance``.
        
        :param tolerance: The ``tolerance`` to use. The result is guaranteed to be less than ``tolerance`` away from the
        curved geometry, unless the number of points needed to linearize the geometry exceeds the per-quadrant maximum,
        currently equal to 10000 points.
        :returns: A :py:class:`aspose.gis.geometries.IMultiPolygon` that approximates or equivalent to this :py:class:`aspose.gis.geometries.IMultiSurface`:
        
        If this object is :py:class:`aspose.gis.geometries.IMultiPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiPolygon` - all surfaces are linearized and new ``IMultiPolygon`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiPolygon` - all surfaces are linearized and new ``IMultiPolygon`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiPolygon` - all surfaces are linearized and new ``IMultiPolygon`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiPolygon` - all surfaces are linearized and new ``IMultiPolygon`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiPolygon` - all surfaces are linearized and new ``IMultiPolygon`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiPolygon` - all surfaces are linearized and new ``IMultiPolygon`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiPolygon` - all surfaces are linearized and new ``IMultiPolygon`` is created'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : aspose.gis.AbstractPath, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : str, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> io.RawIOBase:
        '''Export this geometry to an image representation.
        
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.
        :returns: The image as stream'''
        raise NotImplementedError()
    
    @overload
    def as_text(self) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant, format : aspose.gis.NumericFormat) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :param format: Coordinate format for conversion to string. See the :py:class:`aspose.gis.NumericFormat` to get it.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self, variant : aspose.gis.geometries.WkbVariant) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :param variant: Well-Known Binary variant to use.
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def within(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry is within a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry is within extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def within(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is within a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially within" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry intersects a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry intersects the extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry intersects.
        
        :param other: A geometry.
        :returns: if this geometry "spatially intersects" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def to_editable(self) -> aspose.gis.geometries.MultiPolygon:
        '''Gets an editable copy of this geometry.
        
        :returns: An editable copy of this geometry.'''
        raise NotImplementedError()
    
    def replace_polygons_by_lines(self) -> aspose.gis.geometries.IGeometryCollection:
        '''Gets polygons represented as lines of this geometry.
        
        :returns: A geometry, that has no polygon geometries. The following transformation are applied:
        
        *
        
        *'''
        raise NotImplementedError()
    
    def to_svg(self, extent : aspose.gis.Extent) -> str:
        '''Translates this geometry to Svg representation.
        
        :param extent: Extent for translation this geometry to Svg
        :returns: The Svg representation.'''
        raise NotImplementedError()
    
    def set_empty(self) -> None:
        '''Makes this :py:class:`aspose.gis.geometries.Geometry` empty.'''
        raise NotImplementedError()
    
    def clone(self) -> aspose.gis.geometries.Geometry:
        '''Clones this instance.
        
        :returns: The clone of this instance'''
        raise NotImplementedError()
    
    def round_xy(self, digits : int) -> None:
        '''Rounds X and Y coordinates to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def round_z(self, digits : int) -> None:
        '''Rounds Z coordinate to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def round_m(self, digits : int) -> None:
        '''Rounds M coordinate to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def get_extent(self) -> aspose.gis.Extent:
        '''Computes and returns a bounding extent of this geometry.
        
        :returns: A bounding extent of this geometry.'''
        raise NotImplementedError()
    
    def get_area(self) -> float:
        '''Computes the area of this geometry.
        
        :returns: The area of this geometry.
        Sum of areas of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_length(self) -> float:
        '''Computes the length of this geometry.
        
        :returns: The length of this geometry.
        Perimeter if this is a :py:class:`aspose.gis.geometries.Polygon`.
        Sum of lengths of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_distance_to(self, other : aspose.gis.geometries.IGeometry) -> float:
        '''Computes the minimum distance between this geometry and a specified geometry.
        
        :param other: A geometry to find distance to.
        :returns: If both geometries are not :py:attr:`aspose.gis.geometries.Geometry.is_empty` - a distance between closest points of the geometries.
        If at least one geometry is empty -1 is returned.'''
        raise NotImplementedError()
    
    def get_convex_hull(self) -> aspose.gis.geometries.IGeometry:
        '''Computes the convex hull of this geometry.
        
        :returns: A geometry that represents a convex hull of this geometry.
        If this geometry has no points then the result is :py:attr:`aspose.gis.geometries.Geometry.null`.
        If this geometry has only one point then the result is this point.
        If this geometry has only two points then the result is :py:class:`aspose.gis.geometries.ILineString` with the points.
        If this geometry has three or more points then the result is :py:class:`aspose.gis.geometries.ILinearRing` that represents a convex
        hull around all geometries points.'''
        raise NotImplementedError()
    
    def get_centroid(self) -> aspose.gis.geometries.IPoint:
        '''Computes the centroid of this geometry.
        
        :returns: The centroid of this geometry. If this geometry is empty an empty point returned.
        The centroid is equal to the centroid of the highest dimension geometries in this geometry
        (e.g. if both points and lines are contained in the geometry, only lines contribute to centroid).'''
        raise NotImplementedError()
    
    def get_buffer(self, distance : float, quadrant_segments : int) -> aspose.gis.geometries.IGeometry:
        '''Computes a buffer region around this geometry.
        
        :param distance: The buffer region width.
        :param quadrant_segments: Number of segments used to approximate a 90 degree of curvature.
        The larger this number is the better approximation of curves is produced.
        Default is 30.
        :returns: A geometry that represents all points that are within a specified distance from
        this geometry.
        The type of result is either :py:attr:`aspose.gis.geometries.Geometry.null`, :py:class:`aspose.gis.geometries.IPolygon` or :py:class:`aspose.gis.geometries.IMultiPolygon`.'''
        raise NotImplementedError()
    
    def spatially_equals(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry spatially equal to a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry "spatially equals" to specified geometry.  otherwise.'''
        raise NotImplementedError()
    
    def disjoint(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry is disjoint from a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially disjoint" from another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def touches(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry touch.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially touches" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def crosses(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry cross.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially crosses" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def spatially_contains(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry spatially contains a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially contains" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def overlaps(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry overlap with a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially overlaps" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covers(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry covers a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covers" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covered_by(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is covered by a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covered by" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def relate(self, other : aspose.gis.geometries.IGeometry, intersection_pattern_matrix : str) -> bool:
        '''Determines if DE-9IM intersection matrix of this geometry and a specified geometry matches provided pattern.
        
        :param other: A geometry.
        :param intersection_pattern_matrix: A patter to match with.
        This should be a string with length equal to 9.
        Each character of the string represent expected dimension of an intersection:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        Possible values of each characters are:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        For example, an intersection pattern "F0*******" means, that there should not be intersection between geometries interiors
        and intersection between geometries boundaries must be a point.
        See OpenGIS Simple Features Specification for more details about intersection matrix pattern.
        :returns: if this intersection matrix matches patter;  otherwise.'''
        raise NotImplementedError()
    
    def intersection(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds an intersection between this geometry and a specified geometry.
        
        :param other: A geometry to compute intersection with.
        :returns: A geometry that represents an intersection of this geometry and an argument. The result geometry contain
        point set that present in both this geometry and an argument.'''
        raise NotImplementedError()
    
    def union(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Unites this geometry and a specified geometry.
        
        :param other: A geometry to unite with.
        :returns: A geometry that represents a union of this geometry and an argument. The result geometry contains
        point set that present in this geometry or in an argument.'''
        raise NotImplementedError()
    
    def difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Subtracts a specified geometry from this geometry.
        
        :param other: A geometry to subtract.
        :returns: A geometry that represents a difference of this geometry and an argument. The result geometry contains
        point set that present in this geometry but not present in an argument.'''
        raise NotImplementedError()
    
    def sym_difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds a symmetric difference between this geometry and a specified geometry.
        
        :param other: A geometry to compute symmetric difference with.
        :returns: A geometry that represents a symmetric difference of this geometry and an argument. The result geometry contains
        point set that present in one of the geometries but not present in both of them.'''
        raise NotImplementedError()
    
    def get_point_on_surface(self) -> aspose.gis.geometries.IPoint:
        '''Finds a point that is guaranteed to be on one of the surfaces in this collection.
        
        :returns: A point on one of the surfaces. An empty point if this collection does not contain surfaces or all surfaces are empty.'''
        raise NotImplementedError()
    
    def add(self, geometry : aspose.gis.geometries.IGeometry) -> None:
        '''Adds the specified geometry to the collection.
        
        :param geometry: The geometry to add.'''
        raise NotImplementedError()
    
    def add_range(self, geometries : Iterable[aspose.gis.geometries.IGeometry]) -> None:
        raise NotImplementedError()
    
    def remove_at(self, index : int) -> None:
        '''Removes the specified geometry from the collection.
        
        :param index: Index of the geometry to remove.'''
        raise NotImplementedError()
    
    def equals(self, other : aspose.gis.geometries.IGeometryCollection) -> bool:
        '''Indicates whether the current object is equal to another object of the same type.
        
        :param other: An object to compare with this object.
        :returns: true if the current object is equal to the ``other`` parameter; otherwise, false.'''
        raise NotImplementedError()
    
    @property
    def dimension(self) -> aspose.gis.geometries.GeometryDimension:
        '''Gets the topological dimension of this :py:class:`aspose.gis.geometries.Geometry`.'''
        raise NotImplementedError()
    
    null : aspose.gis.geometries.IGeometry
    '''Gets an instance of null geometry.'''
    @property
    def coordinate_dimension(self) -> int:
        '''Gets the number of coordinate dimensions for this :py:class:`aspose.gis.geometries.Geometry`.'''
        raise NotImplementedError()
    
    @property
    def is_empty(self) -> bool:
        '''Gets a value indicating whether this instance is empty.'''
        raise NotImplementedError()
    
    @property
    def is_simple(self) -> bool:
        '''Gets a value indicating whether this instance is simple from SFA point of view.'''
        raise NotImplementedError()
    
    @property
    def is_valid(self) -> bool:
        '''Gets a value indicating whether this instance is valid.'''
        raise NotImplementedError()
    
    @property
    def has_m(self) -> bool:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @has_m.setter
    def has_m(self, value : bool) -> None:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_z(self) -> bool:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @has_z.setter
    def has_z(self, value : bool) -> None:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_curve_geometry(self) -> bool:
        '''Gets a value indicating whether this geometry is or contains curve (not linear) geometry.'''
        raise NotImplementedError()
    
    @property
    def geometry_type(self) -> aspose.gis.geometries.GeometryType:
        '''Gets the type of the geometry.'''
        raise NotImplementedError()
    
    @property
    def spatial_reference_system(self) -> aspose.gis.spatialreferencing.SpatialReferenceSystem:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , is SpatialReferenceSystem is unknown.
        Assigning new SpatialReferenceSystem will not perform any coordinate transformation, only reference will change.'''
        raise NotImplementedError()
    
    @spatial_reference_system.setter
    def spatial_reference_system(self, value : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> None:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , is SpatialReferenceSystem is unknown.
        Assigning new SpatialReferenceSystem will not perform any coordinate transformation, only reference will change.'''
        raise NotImplementedError()
    
    @property
    def count(self) -> int:
        '''Gets the number of geometries in this collection.'''
        raise NotImplementedError()
    
    def __getitem__(self, key : int) -> aspose.gis.geometries.IGeometry:
        raise NotImplementedError()
    

class MultiSurface(GeometryCollection):
    '''A :py:class:`aspose.gis.geometries.MultiSurface` is a one-dimensional :py:class:`aspose.gis.geometries.GeometryCollection` whose elements are :py:class:`aspose.gis.geometries.ISurface`s.'''
    
    @overload
    @staticmethod
    def from_text(wkt : str) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Text representation.
        
        :param wkt: Well-Known Text representation of a geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_text(wkt : str, spatial_reference_system : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Text representation.
        
        :param wkt: Well-Known Text representation of a geometry.
        :param spatial_reference_system: Spatial Reference System to be assigned to the geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_binary(wkb : List[int]) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Binary representation.
        
        :param wkb: Well-Known Binary representation of a geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_binary(wkb : List[int], spatial_reference_system : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Binary representation.
        
        :param wkb: Well-Known Binary representation of a geometry.
        :param spatial_reference_system: Spatial Reference System to be assigned to the geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self) -> aspose.gis.geometries.IMultiPolygon:
        '''Gets approximate or equivalent non-curve version of this geometry using the default ``tolerance``.
        
        :returns: A :py:class:`aspose.gis.geometries.IMultiPolygon` that approximates or equivalent to this :py:class:`aspose.gis.geometries.IMultiSurface`.
        This is the equivalent of :py:func:`aspose.gis.geometries.IMultiSurface.to_linear_geometry` with
        default ``tolerance``. Default ``tolerance``s value is dependent on :py:class:`aspose.gis.spatialreferencing.SpatialReferenceSystem`
        of this geometry:
        
        *
        
        *
        
        *
        
        For more details on what transformations are applied refer to :py:func:`aspose.gis.geometries.IMultiSurface.to_linear_geometry` specification.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self, tolerance : float) -> aspose.gis.geometries.IMultiPolygon:
        '''Gets approximate or equivalent non-curve version of this geometry using the specified ``tolerance``.
        
        :param tolerance: The ``tolerance`` to use. The result is guaranteed to be less than ``tolerance`` away from the
        curved geometry, unless the number of points needed to linearize the geometry exceeds the per-quadrant maximum,
        currently equal to 10000 points.
        :returns: A :py:class:`aspose.gis.geometries.IMultiPolygon` that approximates or equivalent to this :py:class:`aspose.gis.geometries.IMultiSurface`:
        
        If this object is :py:class:`aspose.gis.geometries.IMultiPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiPolygon` - all surfaces are linearized and new ``IMultiPolygon`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiPolygon` - all surfaces are linearized and new ``IMultiPolygon`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiPolygon` - all surfaces are linearized and new ``IMultiPolygon`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiPolygon` - all surfaces are linearized and new ``IMultiPolygon`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiPolygon` - all surfaces are linearized and new ``IMultiPolygon`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiPolygon` - all surfaces are linearized and new ``IMultiPolygon`` is created
        
        If this object is :py:class:`aspose.gis.geometries.IMultiPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IMultiPolygon` - all surfaces are linearized and new ``IMultiPolygon`` is created'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : aspose.gis.AbstractPath, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : str, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> io.RawIOBase:
        '''Export this geometry to an image representation.
        
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.
        :returns: The image as stream'''
        raise NotImplementedError()
    
    @overload
    def as_text(self) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant, format : aspose.gis.NumericFormat) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :param format: Coordinate format for conversion to string. See the :py:class:`aspose.gis.NumericFormat` to get it.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self, variant : aspose.gis.geometries.WkbVariant) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :param variant: Well-Known Binary variant to use.
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def within(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry is within a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry is within extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def within(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is within a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially within" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry intersects a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry intersects the extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry intersects.
        
        :param other: A geometry.
        :returns: if this geometry "spatially intersects" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def to_editable(self) -> aspose.gis.geometries.MultiSurface:
        '''Gets an editable copy of this geometry.
        
        :returns: An editable copy of this geometry.'''
        raise NotImplementedError()
    
    def replace_polygons_by_lines(self) -> aspose.gis.geometries.IGeometryCollection:
        '''Gets polygons represented as lines of this geometry.
        
        :returns: A geometry, that has no polygon geometries. The following transformation are applied:
        
        *
        
        *'''
        raise NotImplementedError()
    
    def to_svg(self, extent : aspose.gis.Extent) -> str:
        '''Translates this geometry to Svg representation.
        
        :param extent: Extent for translation this geometry to Svg
        :returns: The Svg representation.'''
        raise NotImplementedError()
    
    def set_empty(self) -> None:
        '''Makes this :py:class:`aspose.gis.geometries.Geometry` empty.'''
        raise NotImplementedError()
    
    def clone(self) -> aspose.gis.geometries.Geometry:
        '''Clones this instance.
        
        :returns: The clone of this instance'''
        raise NotImplementedError()
    
    def round_xy(self, digits : int) -> None:
        '''Rounds X and Y coordinates to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def round_z(self, digits : int) -> None:
        '''Rounds Z coordinate to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def round_m(self, digits : int) -> None:
        '''Rounds M coordinate to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def get_extent(self) -> aspose.gis.Extent:
        '''Computes and returns a bounding extent of this geometry.
        
        :returns: A bounding extent of this geometry.'''
        raise NotImplementedError()
    
    def get_area(self) -> float:
        '''Computes the area of this geometry.
        
        :returns: The area of this geometry.
        Sum of areas of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_length(self) -> float:
        '''Computes the length of this geometry.
        
        :returns: The length of this geometry.
        Perimeter if this is a :py:class:`aspose.gis.geometries.Polygon`.
        Sum of lengths of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_distance_to(self, other : aspose.gis.geometries.IGeometry) -> float:
        '''Computes the minimum distance between this geometry and a specified geometry.
        
        :param other: A geometry to find distance to.
        :returns: If both geometries are not :py:attr:`aspose.gis.geometries.Geometry.is_empty` - a distance between closest points of the geometries.
        If at least one geometry is empty -1 is returned.'''
        raise NotImplementedError()
    
    def get_convex_hull(self) -> aspose.gis.geometries.IGeometry:
        '''Computes the convex hull of this geometry.
        
        :returns: A geometry that represents a convex hull of this geometry.
        If this geometry has no points then the result is :py:attr:`aspose.gis.geometries.Geometry.null`.
        If this geometry has only one point then the result is this point.
        If this geometry has only two points then the result is :py:class:`aspose.gis.geometries.ILineString` with the points.
        If this geometry has three or more points then the result is :py:class:`aspose.gis.geometries.ILinearRing` that represents a convex
        hull around all geometries points.'''
        raise NotImplementedError()
    
    def get_centroid(self) -> aspose.gis.geometries.IPoint:
        '''Computes the centroid of this geometry.
        
        :returns: The centroid of this geometry. If this geometry is empty an empty point returned.
        The centroid is equal to the centroid of the highest dimension geometries in this geometry
        (e.g. if both points and lines are contained in the geometry, only lines contribute to centroid).'''
        raise NotImplementedError()
    
    def get_buffer(self, distance : float, quadrant_segments : int) -> aspose.gis.geometries.IGeometry:
        '''Computes a buffer region around this geometry.
        
        :param distance: The buffer region width.
        :param quadrant_segments: Number of segments used to approximate a 90 degree of curvature.
        The larger this number is the better approximation of curves is produced.
        Default is 30.
        :returns: A geometry that represents all points that are within a specified distance from
        this geometry.
        The type of result is either :py:attr:`aspose.gis.geometries.Geometry.null`, :py:class:`aspose.gis.geometries.IPolygon` or :py:class:`aspose.gis.geometries.IMultiPolygon`.'''
        raise NotImplementedError()
    
    def spatially_equals(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry spatially equal to a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry "spatially equals" to specified geometry.  otherwise.'''
        raise NotImplementedError()
    
    def disjoint(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry is disjoint from a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially disjoint" from another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def touches(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry touch.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially touches" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def crosses(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry cross.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially crosses" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def spatially_contains(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry spatially contains a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially contains" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def overlaps(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry overlap with a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially overlaps" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covers(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry covers a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covers" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covered_by(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is covered by a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covered by" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def relate(self, other : aspose.gis.geometries.IGeometry, intersection_pattern_matrix : str) -> bool:
        '''Determines if DE-9IM intersection matrix of this geometry and a specified geometry matches provided pattern.
        
        :param other: A geometry.
        :param intersection_pattern_matrix: A patter to match with.
        This should be a string with length equal to 9.
        Each character of the string represent expected dimension of an intersection:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        Possible values of each characters are:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        For example, an intersection pattern "F0*******" means, that there should not be intersection between geometries interiors
        and intersection between geometries boundaries must be a point.
        See OpenGIS Simple Features Specification for more details about intersection matrix pattern.
        :returns: if this intersection matrix matches patter;  otherwise.'''
        raise NotImplementedError()
    
    def intersection(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds an intersection between this geometry and a specified geometry.
        
        :param other: A geometry to compute intersection with.
        :returns: A geometry that represents an intersection of this geometry and an argument. The result geometry contain
        point set that present in both this geometry and an argument.'''
        raise NotImplementedError()
    
    def union(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Unites this geometry and a specified geometry.
        
        :param other: A geometry to unite with.
        :returns: A geometry that represents a union of this geometry and an argument. The result geometry contains
        point set that present in this geometry or in an argument.'''
        raise NotImplementedError()
    
    def difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Subtracts a specified geometry from this geometry.
        
        :param other: A geometry to subtract.
        :returns: A geometry that represents a difference of this geometry and an argument. The result geometry contains
        point set that present in this geometry but not present in an argument.'''
        raise NotImplementedError()
    
    def sym_difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds a symmetric difference between this geometry and a specified geometry.
        
        :param other: A geometry to compute symmetric difference with.
        :returns: A geometry that represents a symmetric difference of this geometry and an argument. The result geometry contains
        point set that present in one of the geometries but not present in both of them.'''
        raise NotImplementedError()
    
    def get_point_on_surface(self) -> aspose.gis.geometries.IPoint:
        '''Finds a point that is guaranteed to be on one of the surfaces in this collection.
        
        :returns: A point on one of the surfaces. An empty point if this collection does not contain surfaces or all surfaces are empty.'''
        raise NotImplementedError()
    
    def add(self, geometry : aspose.gis.geometries.IGeometry) -> None:
        '''Adds the specified geometry to the collection.
        
        :param geometry: The geometry to add.'''
        raise NotImplementedError()
    
    def add_range(self, geometries : Iterable[aspose.gis.geometries.IGeometry]) -> None:
        raise NotImplementedError()
    
    def remove_at(self, index : int) -> None:
        '''Removes the specified geometry from the collection.
        
        :param index: Index of the geometry to remove.'''
        raise NotImplementedError()
    
    def equals(self, other : aspose.gis.geometries.IGeometryCollection) -> bool:
        '''Indicates whether the current object is equal to another object of the same type.
        
        :param other: An object to compare with this object.
        :returns: true if the current object is equal to the ``other`` parameter; otherwise, false.'''
        raise NotImplementedError()
    
    @property
    def dimension(self) -> aspose.gis.geometries.GeometryDimension:
        '''Gets the topological dimension of this :py:class:`aspose.gis.geometries.Geometry`.'''
        raise NotImplementedError()
    
    null : aspose.gis.geometries.IGeometry
    '''Gets an instance of null geometry.'''
    @property
    def coordinate_dimension(self) -> int:
        '''Gets the number of coordinate dimensions for this :py:class:`aspose.gis.geometries.Geometry`.'''
        raise NotImplementedError()
    
    @property
    def is_empty(self) -> bool:
        '''Gets a value indicating whether this instance is empty.'''
        raise NotImplementedError()
    
    @property
    def is_simple(self) -> bool:
        '''Gets a value indicating whether this instance is simple from SFA point of view.'''
        raise NotImplementedError()
    
    @property
    def is_valid(self) -> bool:
        '''Gets a value indicating whether this instance is valid.'''
        raise NotImplementedError()
    
    @property
    def has_m(self) -> bool:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @has_m.setter
    def has_m(self, value : bool) -> None:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_z(self) -> bool:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @has_z.setter
    def has_z(self, value : bool) -> None:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_curve_geometry(self) -> bool:
        '''Gets a value indicating whether this geometry is or contains curve (not linear) geometry.'''
        raise NotImplementedError()
    
    @property
    def geometry_type(self) -> aspose.gis.geometries.GeometryType:
        '''Gets the type of the geometry.'''
        raise NotImplementedError()
    
    @property
    def spatial_reference_system(self) -> aspose.gis.spatialreferencing.SpatialReferenceSystem:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , is SpatialReferenceSystem is unknown.
        Assigning new SpatialReferenceSystem will not perform any coordinate transformation, only reference will change.'''
        raise NotImplementedError()
    
    @spatial_reference_system.setter
    def spatial_reference_system(self, value : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> None:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , is SpatialReferenceSystem is unknown.
        Assigning new SpatialReferenceSystem will not perform any coordinate transformation, only reference will change.'''
        raise NotImplementedError()
    
    @property
    def count(self) -> int:
        '''Gets the number of geometries in this collection.'''
        raise NotImplementedError()
    
    def __getitem__(self, key : int) -> aspose.gis.geometries.IGeometry:
        raise NotImplementedError()
    

class Point(Geometry):
    '''A :py:class:`aspose.gis.geometries.Point` represents a single location in coordinate space.'''
    
    @overload
    @staticmethod
    def from_text(wkt : str) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Text representation.
        
        :param wkt: Well-Known Text representation of a geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_text(wkt : str, spatial_reference_system : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Text representation.
        
        :param wkt: Well-Known Text representation of a geometry.
        :param spatial_reference_system: Spatial Reference System to be assigned to the geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_binary(wkb : List[int]) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Binary representation.
        
        :param wkb: Well-Known Binary representation of a geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_binary(wkb : List[int], spatial_reference_system : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Binary representation.
        
        :param wkb: Well-Known Binary representation of a geometry.
        :param spatial_reference_system: Spatial Reference System to be assigned to the geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self) -> aspose.gis.geometries.IGeometry:
        '''Gets approximate or equivalent non-curve version of this geometry using the default ``tolerance``.
        
        :returns: A geometry that has no curve geometries. This is the equivalent of :py:func:`aspose.gis.geometries.IGeometry.to_linear_geometry` with
        default ``tolerance``. Default ``tolerance`` is defined by :py:attr:`aspose.gis.geometries.IGeometry.spatial_reference_system`
        of this geometry:
        
        *
        
        *
        
        *
        
        For more details on what transformations are applied refer to :py:func:`aspose.gis.geometries.IGeometry.to_linear_geometry` specification.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self, tolerance : float) -> aspose.gis.geometries.IGeometry:
        '''Gets approximate or equivalent non-curve version of this geometry using the specified ``tolerance``.
        
        :param tolerance: The ``tolerance`` to use. The result is guaranteed to be less than ``tolerance`` away from the
        curved geometry, unless the number of points needed to linearize the geometry exceeds the per-quadrant maximum
        which is currently equal to 10000 points.
        :returns: A geometry, that has no curve geometries. The following transformations are applied:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        As a result, :py:attr:`aspose.gis.geometries.IGeometry.has_curve_geometry` of output geometry is .'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : aspose.gis.AbstractPath, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : str, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> io.RawIOBase:
        '''Export this geometry to an image representation.
        
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.
        :returns: The image as stream'''
        raise NotImplementedError()
    
    @overload
    def as_text(self) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant, format : aspose.gis.NumericFormat) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :param format: Coordinate format for conversion to string. See the :py:class:`aspose.gis.NumericFormat` to get it.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self, variant : aspose.gis.geometries.WkbVariant) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :param variant: Well-Known Binary variant to use.
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def within(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry is within a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry is within extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def within(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is within a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially within" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry intersects a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry intersects the extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry intersects.
        
        :param other: A geometry.
        :returns: if this geometry "spatially intersects" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def to_editable(self) -> aspose.gis.common.formats.mapinfo.graphicalobjects.Point:
        '''Gets an editable copy of this geometry.
        
        :returns: An editable copy of this geometry.'''
        raise NotImplementedError()
    
    def replace_polygons_by_lines(self) -> aspose.gis.geometries.IGeometry:
        '''Gets polygons represented as lines of this geometry.
        
        :returns: A geometry, that has no polygon geometries. The following transformation are applied:
        
        *
        
        *'''
        raise NotImplementedError()
    
    def to_svg(self, extent : aspose.gis.Extent) -> str:
        '''Translates this geometry to Svg representation.
        
        :param extent: Extent for translation this geometry to Svg
        :returns: The Svg representation.'''
        raise NotImplementedError()
    
    def set_empty(self) -> None:
        '''Makes this :py:class:`aspose.gis.geometries.Geometry` empty.'''
        raise NotImplementedError()
    
    def clone(self) -> aspose.gis.geometries.Geometry:
        '''Clones this instance.
        
        :returns: The clone of this instance'''
        raise NotImplementedError()
    
    def round_xy(self, digits : int) -> None:
        '''Rounds X and Y coordinates to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def round_z(self, digits : int) -> None:
        '''Rounds Z coordinate to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def round_m(self, digits : int) -> None:
        '''Rounds M coordinate to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def get_extent(self) -> aspose.gis.Extent:
        '''Computes and returns a bounding extent of this geometry.
        
        :returns: A bounding extent of this geometry.'''
        raise NotImplementedError()
    
    def get_area(self) -> float:
        '''Computes the area of this geometry.
        
        :returns: The area of this geometry.
        Sum of areas of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_length(self) -> float:
        '''Computes the length of this geometry.
        
        :returns: The length of this geometry.
        Perimeter if this is a :py:class:`aspose.gis.geometries.Polygon`.
        Sum of lengths of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_distance_to(self, other : aspose.gis.geometries.IGeometry) -> float:
        '''Computes the minimum distance between this geometry and a specified geometry.
        
        :param other: A geometry to find distance to.
        :returns: If both geometries are not :py:attr:`aspose.gis.geometries.Geometry.is_empty` - a distance between closest points of the geometries.
        If at least one geometry is empty -1 is returned.'''
        raise NotImplementedError()
    
    def get_convex_hull(self) -> aspose.gis.geometries.IGeometry:
        '''Computes the convex hull of this geometry.
        
        :returns: A geometry that represents a convex hull of this geometry.
        If this geometry has no points then the result is :py:attr:`aspose.gis.geometries.Geometry.null`.
        If this geometry has only one point then the result is this point.
        If this geometry has only two points then the result is :py:class:`aspose.gis.geometries.ILineString` with the points.
        If this geometry has three or more points then the result is :py:class:`aspose.gis.geometries.ILinearRing` that represents a convex
        hull around all geometries points.'''
        raise NotImplementedError()
    
    def get_centroid(self) -> aspose.gis.geometries.IPoint:
        '''Computes the centroid of this geometry.
        
        :returns: The centroid of this geometry. If this geometry is empty an empty point returned.
        The centroid is equal to the centroid of the highest dimension geometries in this geometry
        (e.g. if both points and lines are contained in the geometry, only lines contribute to centroid).'''
        raise NotImplementedError()
    
    def get_buffer(self, distance : float, quadrant_segments : int) -> aspose.gis.geometries.IGeometry:
        '''Computes a buffer region around this geometry.
        
        :param distance: The buffer region width.
        :param quadrant_segments: Number of segments used to approximate a 90 degree of curvature.
        The larger this number is the better approximation of curves is produced.
        Default is 30.
        :returns: A geometry that represents all points that are within a specified distance from
        this geometry.
        The type of result is either :py:attr:`aspose.gis.geometries.Geometry.null`, :py:class:`aspose.gis.geometries.IPolygon` or :py:class:`aspose.gis.geometries.IMultiPolygon`.'''
        raise NotImplementedError()
    
    def spatially_equals(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry spatially equal to a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry "spatially equals" to specified geometry.  otherwise.'''
        raise NotImplementedError()
    
    def disjoint(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry is disjoint from a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially disjoint" from another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def touches(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry touch.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially touches" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def crosses(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry cross.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially crosses" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def spatially_contains(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry spatially contains a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially contains" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def overlaps(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry overlap with a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially overlaps" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covers(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry covers a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covers" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covered_by(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is covered by a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covered by" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def relate(self, other : aspose.gis.geometries.IGeometry, intersection_pattern_matrix : str) -> bool:
        '''Determines if DE-9IM intersection matrix of this geometry and a specified geometry matches provided pattern.
        
        :param other: A geometry.
        :param intersection_pattern_matrix: A patter to match with.
        This should be a string with length equal to 9.
        Each character of the string represent expected dimension of an intersection:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        Possible values of each characters are:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        For example, an intersection pattern "F0*******" means, that there should not be intersection between geometries interiors
        and intersection between geometries boundaries must be a point.
        See OpenGIS Simple Features Specification for more details about intersection matrix pattern.
        :returns: if this intersection matrix matches patter;  otherwise.'''
        raise NotImplementedError()
    
    def intersection(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds an intersection between this geometry and a specified geometry.
        
        :param other: A geometry to compute intersection with.
        :returns: A geometry that represents an intersection of this geometry and an argument. The result geometry contain
        point set that present in both this geometry and an argument.'''
        raise NotImplementedError()
    
    def union(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Unites this geometry and a specified geometry.
        
        :param other: A geometry to unite with.
        :returns: A geometry that represents a union of this geometry and an argument. The result geometry contains
        point set that present in this geometry or in an argument.'''
        raise NotImplementedError()
    
    def difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Subtracts a specified geometry from this geometry.
        
        :param other: A geometry to subtract.
        :returns: A geometry that represents a difference of this geometry and an argument. The result geometry contains
        point set that present in this geometry but not present in an argument.'''
        raise NotImplementedError()
    
    def sym_difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds a symmetric difference between this geometry and a specified geometry.
        
        :param other: A geometry to compute symmetric difference with.
        :returns: A geometry that represents a symmetric difference of this geometry and an argument. The result geometry contains
        point set that present in one of the geometries but not present in both of them.'''
        raise NotImplementedError()
    
    def equals(self, other : aspose.gis.geometries.IPoint) -> bool:
        '''Indicates whether the current object is equal to another object of the same type.
        
        :param other: An object to compare with this object.
        :returns: true if the current object is equal to the ``other`` parameter; otherwise, false.'''
        raise NotImplementedError()
    
    @property
    def dimension(self) -> aspose.gis.geometries.GeometryDimension:
        '''Gets the topological dimension of this :py:class:`aspose.gis.geometries.Geometry`.'''
        raise NotImplementedError()
    
    null : aspose.gis.geometries.IGeometry
    '''Gets an instance of null geometry.'''
    @property
    def coordinate_dimension(self) -> int:
        '''Gets the number of coordinate dimensions for this :py:class:`aspose.gis.geometries.Geometry`.'''
        raise NotImplementedError()
    
    @property
    def is_empty(self) -> bool:
        '''Gets a value indicating whether this instance is empty.'''
        raise NotImplementedError()
    
    @property
    def is_simple(self) -> bool:
        '''Gets a value indicating whether this instance is simple from SFA point of view.'''
        raise NotImplementedError()
    
    @property
    def is_valid(self) -> bool:
        '''Gets a value indicating whether this instance is valid.'''
        raise NotImplementedError()
    
    @property
    def has_m(self) -> bool:
        '''Gets a value indicating whether this instance has an M coordinate.'''
        raise NotImplementedError()
    
    @has_m.setter
    def has_m(self, value : bool) -> None:
        '''Gets a value indicating whether this instance has an M coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_z(self) -> bool:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @has_z.setter
    def has_z(self, value : bool) -> None:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_curve_geometry(self) -> bool:
        '''Gets a value indicating whether this geometry is or contains curve (not linear) geometry.'''
        raise NotImplementedError()
    
    @property
    def geometry_type(self) -> aspose.gis.geometries.GeometryType:
        '''Gets the type of the geometry.'''
        raise NotImplementedError()
    
    @property
    def spatial_reference_system(self) -> aspose.gis.spatialreferencing.SpatialReferenceSystem:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , is SpatialReferenceSystem is unknown.
        Assigning new SpatialReferenceSystem will not perform any coordinate transformation, only reference will change.'''
        raise NotImplementedError()
    
    @spatial_reference_system.setter
    def spatial_reference_system(self, value : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> None:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , is SpatialReferenceSystem is unknown.
        Assigning new SpatialReferenceSystem will not perform any coordinate transformation, only reference will change.'''
        raise NotImplementedError()
    
    @property
    def x(self) -> float:
        '''Gets a value for the x-coordinate.'''
        raise NotImplementedError()
    
    @x.setter
    def x(self, value : float) -> None:
        '''Sets a value for the x-coordinate.'''
        raise NotImplementedError()
    
    @property
    def y(self) -> float:
        '''Gets a value for the y-coordinate.'''
        raise NotImplementedError()
    
    @y.setter
    def y(self, value : float) -> None:
        '''Sets a value for the y-coordinate.'''
        raise NotImplementedError()
    
    @property
    def z(self) -> float:
        '''Gets a value for the z-coordinate.'''
        raise NotImplementedError()
    
    @z.setter
    def z(self, value : float) -> None:
        '''Sets a value for the z-coordinate.'''
        raise NotImplementedError()
    
    @property
    def m(self) -> float:
        '''Gets a value for the m-coordinate.'''
        raise NotImplementedError()
    
    @m.setter
    def m(self, value : float) -> None:
        '''Sets a value for the m-coordinate.'''
        raise NotImplementedError()
    

class Polygon(Surface):
    '''A :py:class:`aspose.gis.geometries.Polygon` is a planar surface,
    defined by 1 exterior boundary and 0 or more interior boundaries.'''
    
    @overload
    @staticmethod
    def from_text(wkt : str) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Text representation.
        
        :param wkt: Well-Known Text representation of a geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_text(wkt : str, spatial_reference_system : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Text representation.
        
        :param wkt: Well-Known Text representation of a geometry.
        :param spatial_reference_system: Spatial Reference System to be assigned to the geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_binary(wkb : List[int]) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Binary representation.
        
        :param wkb: Well-Known Binary representation of a geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_binary(wkb : List[int], spatial_reference_system : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Binary representation.
        
        :param wkb: Well-Known Binary representation of a geometry.
        :param spatial_reference_system: Spatial Reference System to be assigned to the geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self) -> aspose.gis.geometries.IPolygon:
        '''Gets approximate or equivalent non-curve version of this geometry using the default ``tolerance``.
        
        :returns: A :py:class:`aspose.gis.geometries.IPolygon` that approximates or equivalent to this ``ISurface``.
        This is the equivalent of :py:func:`aspose.gis.geometries.ISurface.to_linear_geometry` with
        default ``tolerance``. Default ``tolerance``s value is dependent on :py:class:`aspose.gis.spatialreferencing.SpatialReferenceSystem`
        of this geometry:
        
        *
        
        *
        
        *
        
        For more details on what transformations are applied refer to :py:func:`aspose.gis.geometries.ISurface.to_linear_geometry` specification.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self, tolerance : float) -> aspose.gis.geometries.IPolygon:
        '''Gets approximate or equivalent non-curve version of this geometry using the specified ``tolerance``.
        
        :param tolerance: The ``tolerance`` to use. The result is guaranteed to be less than ``tolerance`` away from the
        curved geometry, unless the number of points needed to linearize the geometry exceeds the per-quadrant maximum,
        currently equal to 10000 points.
        :returns: A :py:class:`aspose.gis.geometries.IPolygon` that approximates or equivalent to this ``ISurface``:
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : aspose.gis.AbstractPath, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : str, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> io.RawIOBase:
        '''Export this geometry to an image representation.
        
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.
        :returns: The image as stream'''
        raise NotImplementedError()
    
    @overload
    def as_text(self) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant, format : aspose.gis.NumericFormat) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :param format: Coordinate format for conversion to string. See the :py:class:`aspose.gis.NumericFormat` to get it.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self, variant : aspose.gis.geometries.WkbVariant) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :param variant: Well-Known Binary variant to use.
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def within(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry is within a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry is within extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def within(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is within a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially within" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry intersects a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry intersects the extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry intersects.
        
        :param other: A geometry.
        :returns: if this geometry "spatially intersects" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def equals(self, other : aspose.gis.geometries.ICurvePolygon) -> bool:
        '''Determines whether the specified object is equal to the current object.
        
        :param other: The object to compare with the current object.
        :returns: true if the specified object  is equal to the current object; otherwise, false.'''
        raise NotImplementedError()
    
    @overload
    def equals(self, other : aspose.gis.geometries.IPolygon) -> bool:
        '''Determines whether the specified object is equal to the current object.
        
        :param other: The object to compare with the current object.
        :returns: true if the specified object  is equal to the current object; otherwise, false.'''
        raise NotImplementedError()
    
    def to_editable(self) -> aspose.gis.common.formats.mapinfo.graphicalobjects.Polygon:
        '''Gets an editable copy of this geometry.
        
        :returns: An editable copy of this geometry.'''
        raise NotImplementedError()
    
    def replace_polygons_by_lines(self) -> aspose.gis.geometries.IGeometry:
        '''Gets polygons represented as lines of this geometry.
        
        :returns: A geometry, that has no polygon geometries. The following transformation are applied:
        
        *
        
        *'''
        raise NotImplementedError()
    
    def to_svg(self, extent : aspose.gis.Extent) -> str:
        '''Translates this geometry to Svg representation.
        
        :param extent: Extent for translation this geometry to Svg
        :returns: The Svg representation.'''
        raise NotImplementedError()
    
    def set_empty(self) -> None:
        '''Makes this :py:class:`aspose.gis.geometries.Geometry` empty.'''
        raise NotImplementedError()
    
    def clone(self) -> aspose.gis.geometries.Geometry:
        '''Clones this instance.
        
        :returns: The clone of this instance'''
        raise NotImplementedError()
    
    def round_xy(self, digits : int) -> None:
        '''Rounds X and Y coordinates to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def round_z(self, digits : int) -> None:
        '''Rounds Z coordinate to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def round_m(self, digits : int) -> None:
        '''Rounds M coordinate to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def get_extent(self) -> aspose.gis.Extent:
        '''Computes and returns a bounding extent of this geometry.
        
        :returns: A bounding extent of this geometry.'''
        raise NotImplementedError()
    
    def get_area(self) -> float:
        '''Computes the area of this geometry.
        
        :returns: The area of this geometry.
        Sum of areas of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_length(self) -> float:
        '''Computes the length of this geometry.
        
        :returns: The length of this geometry.
        Perimeter if this is a :py:class:`aspose.gis.geometries.Polygon`.
        Sum of lengths of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_distance_to(self, other : aspose.gis.geometries.IGeometry) -> float:
        '''Computes the minimum distance between this geometry and a specified geometry.
        
        :param other: A geometry to find distance to.
        :returns: If both geometries are not :py:attr:`aspose.gis.geometries.Geometry.is_empty` - a distance between closest points of the geometries.
        If at least one geometry is empty -1 is returned.'''
        raise NotImplementedError()
    
    def get_convex_hull(self) -> aspose.gis.geometries.IGeometry:
        '''Computes the convex hull of this geometry.
        
        :returns: A geometry that represents a convex hull of this geometry.
        If this geometry has no points then the result is :py:attr:`aspose.gis.geometries.Geometry.null`.
        If this geometry has only one point then the result is this point.
        If this geometry has only two points then the result is :py:class:`aspose.gis.geometries.ILineString` with the points.
        If this geometry has three or more points then the result is :py:class:`aspose.gis.geometries.ILinearRing` that represents a convex
        hull around all geometries points.'''
        raise NotImplementedError()
    
    def get_centroid(self) -> aspose.gis.geometries.IPoint:
        '''Computes the centroid of this geometry.
        
        :returns: The centroid of this geometry. If this geometry is empty an empty point returned.
        The centroid is equal to the centroid of the highest dimension geometries in this geometry
        (e.g. if both points and lines are contained in the geometry, only lines contribute to centroid).'''
        raise NotImplementedError()
    
    def get_buffer(self, distance : float, quadrant_segments : int) -> aspose.gis.geometries.IGeometry:
        '''Computes a buffer region around this geometry.
        
        :param distance: The buffer region width.
        :param quadrant_segments: Number of segments used to approximate a 90 degree of curvature.
        The larger this number is the better approximation of curves is produced.
        Default is 30.
        :returns: A geometry that represents all points that are within a specified distance from
        this geometry.
        The type of result is either :py:attr:`aspose.gis.geometries.Geometry.null`, :py:class:`aspose.gis.geometries.IPolygon` or :py:class:`aspose.gis.geometries.IMultiPolygon`.'''
        raise NotImplementedError()
    
    def spatially_equals(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry spatially equal to a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry "spatially equals" to specified geometry.  otherwise.'''
        raise NotImplementedError()
    
    def disjoint(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry is disjoint from a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially disjoint" from another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def touches(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry touch.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially touches" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def crosses(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry cross.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially crosses" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def spatially_contains(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry spatially contains a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially contains" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def overlaps(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry overlap with a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially overlaps" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covers(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry covers a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covers" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covered_by(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is covered by a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covered by" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def relate(self, other : aspose.gis.geometries.IGeometry, intersection_pattern_matrix : str) -> bool:
        '''Determines if DE-9IM intersection matrix of this geometry and a specified geometry matches provided pattern.
        
        :param other: A geometry.
        :param intersection_pattern_matrix: A patter to match with.
        This should be a string with length equal to 9.
        Each character of the string represent expected dimension of an intersection:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        Possible values of each characters are:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        For example, an intersection pattern "F0*******" means, that there should not be intersection between geometries interiors
        and intersection between geometries boundaries must be a point.
        See OpenGIS Simple Features Specification for more details about intersection matrix pattern.
        :returns: if this intersection matrix matches patter;  otherwise.'''
        raise NotImplementedError()
    
    def intersection(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds an intersection between this geometry and a specified geometry.
        
        :param other: A geometry to compute intersection with.
        :returns: A geometry that represents an intersection of this geometry and an argument. The result geometry contain
        point set that present in both this geometry and an argument.'''
        raise NotImplementedError()
    
    def union(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Unites this geometry and a specified geometry.
        
        :param other: A geometry to unite with.
        :returns: A geometry that represents a union of this geometry and an argument. The result geometry contains
        point set that present in this geometry or in an argument.'''
        raise NotImplementedError()
    
    def difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Subtracts a specified geometry from this geometry.
        
        :param other: A geometry to subtract.
        :returns: A geometry that represents a difference of this geometry and an argument. The result geometry contains
        point set that present in this geometry but not present in an argument.'''
        raise NotImplementedError()
    
    def sym_difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds a symmetric difference between this geometry and a specified geometry.
        
        :param other: A geometry to compute symmetric difference with.
        :returns: A geometry that represents a symmetric difference of this geometry and an argument. The result geometry contains
        point set that present in one of the geometries but not present in both of them.'''
        raise NotImplementedError()
    
    def get_point_on_surface(self) -> aspose.gis.geometries.IPoint:
        '''Finds a point that is guaranteed to be on this polygon.
        
        :returns: A point on this polygon. An empty point if this polygon has no interior.'''
        raise NotImplementedError()
    
    def get_interior_ring(self, index : int) -> aspose.gis.geometries.ILinearRing:
        '''Gets the interior ring by its index.
        
        :param index: The index.
        :returns: The interior ring.'''
        raise NotImplementedError()
    
    def add_interior_ring(self, ring : aspose.gis.geometries.ILinearRing) -> None:
        '''Adds an interior ring.
        
        :param ring: The ring to add.'''
        raise NotImplementedError()
    
    @property
    def dimension(self) -> aspose.gis.geometries.GeometryDimension:
        '''Gets the topological dimension of this :py:class:`aspose.gis.geometries.Geometry`.'''
        raise NotImplementedError()
    
    null : aspose.gis.geometries.IGeometry
    '''Gets an instance of null geometry.'''
    @property
    def coordinate_dimension(self) -> int:
        '''Gets the number of coordinate dimensions for this :py:class:`aspose.gis.geometries.Geometry`.'''
        raise NotImplementedError()
    
    @property
    def is_empty(self) -> bool:
        '''Gets a value indicating whether this instance is empty.'''
        raise NotImplementedError()
    
    @property
    def is_simple(self) -> bool:
        '''Gets a value indicating whether this instance is simple from SFA point of view.'''
        raise NotImplementedError()
    
    @property
    def is_valid(self) -> bool:
        '''Gets a value indicating whether this instance is valid.'''
        raise NotImplementedError()
    
    @property
    def has_m(self) -> bool:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @has_m.setter
    def has_m(self, value : bool) -> None:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_z(self) -> bool:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @has_z.setter
    def has_z(self, value : bool) -> None:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_curve_geometry(self) -> bool:
        '''Gets a value indicating whether this geometry is or contains curve (not linear) geometry.'''
        raise NotImplementedError()
    
    @property
    def geometry_type(self) -> aspose.gis.geometries.GeometryType:
        '''Gets the type of the geometry.'''
        raise NotImplementedError()
    
    @property
    def spatial_reference_system(self) -> aspose.gis.spatialreferencing.SpatialReferenceSystem:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , is SpatialReferenceSystem is unknown.
        Assigning new SpatialReferenceSystem will not perform any coordinate transformation, only reference will change.'''
        raise NotImplementedError()
    
    @spatial_reference_system.setter
    def spatial_reference_system(self, value : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> None:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , is SpatialReferenceSystem is unknown.
        Assigning new SpatialReferenceSystem will not perform any coordinate transformation, only reference will change.'''
        raise NotImplementedError()
    
    @property
    def exterior_ring(self) -> aspose.gis.geometries.ILinearRing:
        '''Gets the exterior ring.'''
        raise NotImplementedError()
    
    @exterior_ring.setter
    def exterior_ring(self, value : aspose.gis.geometries.ILinearRing) -> None:
        '''Gets the exterior ring.'''
        raise NotImplementedError()
    
    @property
    def interior_rings_count(self) -> int:
        '''Gets the number of interior rings.'''
        raise NotImplementedError()
    

class Surface(Geometry):
    '''A :py:class:`aspose.gis.geometries.Surface` is a two-dimensional geometric object.'''
    
    @overload
    @staticmethod
    def from_text(wkt : str) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Text representation.
        
        :param wkt: Well-Known Text representation of a geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_text(wkt : str, spatial_reference_system : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Text representation.
        
        :param wkt: Well-Known Text representation of a geometry.
        :param spatial_reference_system: Spatial Reference System to be assigned to the geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_binary(wkb : List[int]) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Binary representation.
        
        :param wkb: Well-Known Binary representation of a geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    @staticmethod
    def from_binary(wkb : List[int], spatial_reference_system : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> aspose.gis.geometries.IGeometry:
        '''Creates a geometry from its Well-Known Binary representation.
        
        :param wkb: Well-Known Binary representation of a geometry.
        :param spatial_reference_system: Spatial Reference System to be assigned to the geometry.
        :returns: A geometry represented by the argument.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self) -> aspose.gis.geometries.IPolygon:
        '''Gets approximate or equivalent non-curve version of this geometry using the default ``tolerance``.
        
        :returns: A :py:class:`aspose.gis.geometries.IPolygon` that approximates or equivalent to this ``ISurface``.
        This is the equivalent of :py:func:`aspose.gis.geometries.ISurface.to_linear_geometry` with
        default ``tolerance``. Default ``tolerance``s value is dependent on :py:class:`aspose.gis.spatialreferencing.SpatialReferenceSystem`
        of this geometry:
        
        *
        
        *
        
        *
        
        For more details on what transformations are applied refer to :py:func:`aspose.gis.geometries.ISurface.to_linear_geometry` specification.'''
        raise NotImplementedError()
    
    @overload
    def to_linear_geometry(self, tolerance : float) -> aspose.gis.geometries.IPolygon:
        '''Gets approximate or equivalent non-curve version of this geometry using the specified ``tolerance``.
        
        :param tolerance: The ``tolerance`` to use. The result is guaranteed to be less than ``tolerance`` away from the
        curved geometry, unless the number of points needed to linearize the geometry exceeds the per-quadrant maximum,
        currently equal to 10000 points.
        :returns: A :py:class:`aspose.gis.geometries.IPolygon` that approximates or equivalent to this ``ISurface``:
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created
        
        If this object is :py:class:`aspose.gis.geometries.IPolygon` itself the result is equivalent to this object
        If this object is not :py:class:`aspose.gis.geometries.IPolygon` it is linearized and :py:class:`aspose.gis.geometries.IPolygon` is created'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : aspose.gis.AbstractPath, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, output_path : str, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> None:
        '''Export this geometry to an image representation.
        
        :param output_path: Path to the output image.
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.'''
        raise NotImplementedError()
    
    @overload
    def as_image(self, width : aspose.gis.rendering.Measurement, height : aspose.gis.rendering.Measurement, renderer : aspose.gis.rendering.Renderer, symbolizer : aspose.gis.rendering.symbolizers.VectorSymbolizer) -> io.RawIOBase:
        '''Export this geometry to an image representation.
        
        :param width: Width of the map.
        :param height: Height of the map.
        :param renderer: Renderer to use.
        :param symbolizer: A symbolizer to use for rendering. If , default symbolizer is used.
        :returns: The image as stream'''
        raise NotImplementedError()
    
    @overload
    def as_text(self) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_text(self, variant : aspose.gis.geometries.WktVariant, format : aspose.gis.NumericFormat) -> str:
        '''Translates this geometry to its Well-Known Text representation.
        
        :param variant: Well-Known Text variant to use.
        :param format: Coordinate format for conversion to string. See the :py:class:`aspose.gis.NumericFormat` to get it.
        :returns: Well-Known Text representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def as_binary(self, variant : aspose.gis.geometries.WkbVariant) -> List[int]:
        '''Translates this geometry to its Well-Known Binary representation.
        
        :param variant: Well-Known Binary variant to use.
        :returns: Well-Known Binary representation of this geometry.'''
        raise NotImplementedError()
    
    @overload
    def within(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry is within a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry is within extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def within(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is within a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially within" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, extent : aspose.gis.Extent) -> bool:
        '''Determines whether this geometry intersects a specified extent.
        
        :param extent: The extent.
        :returns: if this geometry intersects the extent;  otherwise.'''
        raise NotImplementedError()
    
    @overload
    def intersects(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry intersects.
        
        :param other: A geometry.
        :returns: if this geometry "spatially intersects" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def to_editable(self) -> aspose.gis.geometries.Surface:
        '''Gets an editable copy of this geometry.
        
        :returns: An editable copy of this geometry.'''
        raise NotImplementedError()
    
    def replace_polygons_by_lines(self) -> aspose.gis.geometries.IGeometry:
        '''Gets polygons represented as lines of this geometry.
        
        :returns: A geometry, that has no polygon geometries. The following transformation are applied:
        
        *
        
        *'''
        raise NotImplementedError()
    
    def to_svg(self, extent : aspose.gis.Extent) -> str:
        '''Translates this geometry to Svg representation.
        
        :param extent: Extent for translation this geometry to Svg
        :returns: The Svg representation.'''
        raise NotImplementedError()
    
    def set_empty(self) -> None:
        '''Makes this :py:class:`aspose.gis.geometries.Geometry` empty.'''
        raise NotImplementedError()
    
    def clone(self) -> aspose.gis.geometries.Geometry:
        '''Clones this instance.
        
        :returns: The clone of this instance'''
        raise NotImplementedError()
    
    def round_xy(self, digits : int) -> None:
        '''Rounds X and Y coordinates to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def round_z(self, digits : int) -> None:
        '''Rounds Z coordinate to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def round_m(self, digits : int) -> None:
        '''Rounds M coordinate to a specified number of fractional digits.
        
        :param digits: Number of fractional digits.'''
        raise NotImplementedError()
    
    def get_extent(self) -> aspose.gis.Extent:
        '''Computes and returns a bounding extent of this geometry.
        
        :returns: A bounding extent of this geometry.'''
        raise NotImplementedError()
    
    def get_area(self) -> float:
        '''Computes the area of this geometry.
        
        :returns: The area of this geometry.
        Sum of areas of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_length(self) -> float:
        '''Computes the length of this geometry.
        
        :returns: The length of this geometry.
        Perimeter if this is a :py:class:`aspose.gis.geometries.Polygon`.
        Sum of lengths of elements of this geometry if this geometry is a :py:class:`aspose.gis.geometries.GeometryCollection`.'''
        raise NotImplementedError()
    
    def get_distance_to(self, other : aspose.gis.geometries.IGeometry) -> float:
        '''Computes the minimum distance between this geometry and a specified geometry.
        
        :param other: A geometry to find distance to.
        :returns: If both geometries are not :py:attr:`aspose.gis.geometries.Geometry.is_empty` - a distance between closest points of the geometries.
        If at least one geometry is empty -1 is returned.'''
        raise NotImplementedError()
    
    def get_convex_hull(self) -> aspose.gis.geometries.IGeometry:
        '''Computes the convex hull of this geometry.
        
        :returns: A geometry that represents a convex hull of this geometry.
        If this geometry has no points then the result is :py:attr:`aspose.gis.geometries.Geometry.null`.
        If this geometry has only one point then the result is this point.
        If this geometry has only two points then the result is :py:class:`aspose.gis.geometries.ILineString` with the points.
        If this geometry has three or more points then the result is :py:class:`aspose.gis.geometries.ILinearRing` that represents a convex
        hull around all geometries points.'''
        raise NotImplementedError()
    
    def get_centroid(self) -> aspose.gis.geometries.IPoint:
        '''Computes the centroid of this geometry.
        
        :returns: The centroid of this geometry. If this geometry is empty an empty point returned.
        The centroid is equal to the centroid of the highest dimension geometries in this geometry
        (e.g. if both points and lines are contained in the geometry, only lines contribute to centroid).'''
        raise NotImplementedError()
    
    def get_buffer(self, distance : float, quadrant_segments : int) -> aspose.gis.geometries.IGeometry:
        '''Computes a buffer region around this geometry.
        
        :param distance: The buffer region width.
        :param quadrant_segments: Number of segments used to approximate a 90 degree of curvature.
        The larger this number is the better approximation of curves is produced.
        Default is 30.
        :returns: A geometry that represents all points that are within a specified distance from
        this geometry.
        The type of result is either :py:attr:`aspose.gis.geometries.Geometry.null`, :py:class:`aspose.gis.geometries.IPolygon` or :py:class:`aspose.gis.geometries.IMultiPolygon`.'''
        raise NotImplementedError()
    
    def spatially_equals(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry spatially equal to a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry "spatially equals" to specified geometry.  otherwise.'''
        raise NotImplementedError()
    
    def disjoint(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry is disjoint from a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially disjoint" from another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def touches(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry touch.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially touches" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def crosses(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines if this geometry and a specified geometry cross.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially crosses" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def spatially_contains(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry spatially contains a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially contains" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def overlaps(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry overlap with a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially overlaps" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covers(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry covers a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covers" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def covered_by(self, other : aspose.gis.geometries.IGeometry) -> bool:
        '''Determines whether this geometry is covered by a specified geometry.
        
        :param other: A geometry.
        :returns: if this geometry is "spatially covered by" another geometry.  otherwise.'''
        raise NotImplementedError()
    
    def relate(self, other : aspose.gis.geometries.IGeometry, intersection_pattern_matrix : str) -> bool:
        '''Determines if DE-9IM intersection matrix of this geometry and a specified geometry matches provided pattern.
        
        :param other: A geometry.
        :param intersection_pattern_matrix: A patter to match with.
        This should be a string with length equal to 9.
        Each character of the string represent expected dimension of an intersection:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        Possible values of each characters are:
        
        *
        
        *
        
        *
        
        *
        
        *
        
        *
        
        For example, an intersection pattern "F0*******" means, that there should not be intersection between geometries interiors
        and intersection between geometries boundaries must be a point.
        See OpenGIS Simple Features Specification for more details about intersection matrix pattern.
        :returns: if this intersection matrix matches patter;  otherwise.'''
        raise NotImplementedError()
    
    def intersection(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds an intersection between this geometry and a specified geometry.
        
        :param other: A geometry to compute intersection with.
        :returns: A geometry that represents an intersection of this geometry and an argument. The result geometry contain
        point set that present in both this geometry and an argument.'''
        raise NotImplementedError()
    
    def union(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Unites this geometry and a specified geometry.
        
        :param other: A geometry to unite with.
        :returns: A geometry that represents a union of this geometry and an argument. The result geometry contains
        point set that present in this geometry or in an argument.'''
        raise NotImplementedError()
    
    def difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Subtracts a specified geometry from this geometry.
        
        :param other: A geometry to subtract.
        :returns: A geometry that represents a difference of this geometry and an argument. The result geometry contains
        point set that present in this geometry but not present in an argument.'''
        raise NotImplementedError()
    
    def sym_difference(self, other : aspose.gis.geometries.IGeometry) -> aspose.gis.geometries.IGeometry:
        '''Builds a symmetric difference between this geometry and a specified geometry.
        
        :param other: A geometry to compute symmetric difference with.
        :returns: A geometry that represents a symmetric difference of this geometry and an argument. The result geometry contains
        point set that present in one of the geometries but not present in both of them.'''
        raise NotImplementedError()
    
    def get_point_on_surface(self) -> aspose.gis.geometries.IPoint:
        '''Finds a point that is guaranteed to be on this surface.
        
        :returns: A point on this surface. An empty point if this surface has no interior.'''
        raise NotImplementedError()
    
    @property
    def dimension(self) -> aspose.gis.geometries.GeometryDimension:
        '''Gets the topological dimension of this :py:class:`aspose.gis.geometries.Geometry`.'''
        raise NotImplementedError()
    
    null : aspose.gis.geometries.IGeometry
    '''Gets an instance of null geometry.'''
    @property
    def coordinate_dimension(self) -> int:
        '''Gets the number of coordinate dimensions for this :py:class:`aspose.gis.geometries.Geometry`.'''
        raise NotImplementedError()
    
    @property
    def is_empty(self) -> bool:
        '''Gets a value indicating whether this instance is empty.'''
        raise NotImplementedError()
    
    @property
    def is_simple(self) -> bool:
        '''Gets a value indicating whether this instance is simple from SFA point of view.'''
        raise NotImplementedError()
    
    @property
    def is_valid(self) -> bool:
        '''Gets a value indicating whether this instance is valid.'''
        raise NotImplementedError()
    
    @property
    def has_m(self) -> bool:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @has_m.setter
    def has_m(self, value : bool) -> None:
        '''Gets a value indicating whether this instance has M coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_z(self) -> bool:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @has_z.setter
    def has_z(self, value : bool) -> None:
        '''Gets a value indicating whether this instance has Z coordinate.'''
        raise NotImplementedError()
    
    @property
    def has_curve_geometry(self) -> bool:
        '''Gets a value indicating whether this geometry is or contains curve (not linear) geometry.'''
        raise NotImplementedError()
    
    @property
    def geometry_type(self) -> aspose.gis.geometries.GeometryType:
        '''Gets the type of the geometry.'''
        raise NotImplementedError()
    
    @property
    def spatial_reference_system(self) -> aspose.gis.spatialreferencing.SpatialReferenceSystem:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , is SpatialReferenceSystem is unknown.
        Assigning new SpatialReferenceSystem will not perform any coordinate transformation, only reference will change.'''
        raise NotImplementedError()
    
    @spatial_reference_system.setter
    def spatial_reference_system(self, value : aspose.gis.spatialreferencing.SpatialReferenceSystem) -> None:
        '''Gets SpatialReferenceSystem of this instance.
        This property can be , is SpatialReferenceSystem is unknown.
        Assigning new SpatialReferenceSystem will not perform any coordinate transformation, only reference will change.'''
        raise NotImplementedError()
    

class GeometryDimension:
    '''Topological dimension of a :py:class:`aspose.gis.geometries.Geometry`.'''
    
    POINT : GeometryDimension
    '''0-dimensional (a point).'''
    LINE : GeometryDimension
    '''1-dimensional (a line).'''
    SURFACE : GeometryDimension
    '''2-dimensional (a surface).'''

class GeometryType:
    '''The type of a geometry in a layer.'''
    
    NULL : GeometryType
    '''The geometry type is not set.'''
    MIXED : GeometryType
    '''The geometry type is mixed.'''
    POINT : GeometryType
    '''The geometry is an :py:class:`aspose.gis.geometries.IPoint`.'''
    LINE_STRING : GeometryType
    '''The geometry is an :py:class:`aspose.gis.geometries.ILineString`.'''
    LINEAR_RING : GeometryType
    '''The geometry is an :py:class:`aspose.gis.geometries.ILinearRing`.'''
    CIRCULAR_STRING : GeometryType
    '''The geometry is an :py:class:`aspose.gis.geometries.ICircularString`.'''
    COMPOUND_CURVE : GeometryType
    '''The geometry is an :py:class:`aspose.gis.geometries.ICompoundCurve`.'''
    CURVE_POLYGON : GeometryType
    '''The geometry is an :py:class:`aspose.gis.geometries.ICurvePolygon`.'''
    POLYGON : GeometryType
    '''The geometry is an :py:class:`aspose.gis.geometries.IPolygon`.'''
    MULTI_POINT : GeometryType
    '''The geometry is an :py:class:`aspose.gis.geometries.IMultiPoint`.'''
    MULTI_CURVE : GeometryType
    '''The geometry is an :py:class:`aspose.gis.geometries.IMultiCurve`.'''
    MULTI_LINE_STRING : GeometryType
    '''The geometry is an :py:class:`aspose.gis.geometries.IMultiLineString`.'''
    MULTI_SURFACE : GeometryType
    '''The geometry is an :py:class:`aspose.gis.geometries.IMultiSurface`.'''
    MULTI_POLYGON : GeometryType
    '''The geometry is an :py:class:`aspose.gis.geometries.IMultiPolygon`.'''
    GEOMETRY_COLLECTION : GeometryType
    '''The geometry is an :py:class:`aspose.gis.geometries.IGeometryCollection`.'''

class WkbVariant:
    '''The variant of Well-Known Binary'''
    
    SIMPLE_FEATURE_ACCESS_OUTDATED : WkbVariant
    '''Well-Known Binary compliant with Simple Feature Access specification, version 1.1.'''
    ISO : WkbVariant
    '''Well-Known Binary compliant with ISO standard "SQL Multimedia and application packages - Part 3: Spatial" and
    Simple Feature Access specification, version 1.2.'''
    EXTENDED_POST_GIS : WkbVariant
    '''Extended Well-Known Binary variant designed by PostGIS that exports Spatial Reference System identifier (EPSG code).'''

class WktVariant:
    '''The variant of Well-Known Text'''
    
    SIMPLE_FEATURE_ACCESS_OUTDATED : WktVariant
    '''Well-Known Text compliant with Simple Feature Access specification, version 1.1.'''
    ISO : WktVariant
    '''Well-Known Text compliant with ISO standard "SQL Multimedia and application packages - Part 3: Spatial" and
    Simple Feature Access specification, version 1.2.'''
    EXTENDED_POST_GIS : WktVariant
    '''Extended Well-Known Text variant designed by PostGIS that exports Spatial Reference System identifier (EPSG code).'''

